#
# HARMONIE/IFS namelist dictionary
#
# The first hashes defines options needed in all IFS runs
# The rest defines more configuration dependent settings
#
# Each namelist are generated by gen_namelist.pl. The rules
# for this generation are defined in the Makefile.
#
# To generate all possible namelists run "gmake all"
# in the current directory. Run "gmake clean" to clean.
#
# Note that changes may be done to the namelists in the scripts
#
#
############################################
# Namelist settings for all configurations #
############################################
######################
# Global settings
######################
#
######################
# Technical settings
######################
# Host specific settings
# MPP options
# File settings
#####################
# DYNAMICS SETTINGS #
#####################
# Main dynamics switches
# Non-hydrostatic settings
# Vertical finite element
# DFI
#####################################
# Main physics options
# NB! These may contain switches for
# dynamics as well
#####################################
# AROME
# Alaro
# Old surface
# SURFEX
# DDH
###############################
# E927 Interpolation settings #
###############################
# Main fullpos settings
# E927
# E927 nh
# ALARO e927
# Arome e927
###################################
# General postprocessing switches #
###################################
# Default fullpos settings
# NH postprocessing
# Switches for postprocessing with surfex
# Special cases for arome
################
# Assimilation #
################
# Canari
# Arome canari
# Varbc_rad
# Screening
# Arome screening
# Alaro screening
# Minimization
# Alaro minimization
#########
# 4DVAR #
#########
# 4DVAR minimization
# 4DVAR screening
# 4DVAR trajectory
######################
# Climate generation #
######################
# Climate generations (e923)
########
# Misc #
########
# General namelist settings for Tangent-Linear and Adjoint tests
# Extra Adjoint test options
# Oulan
# Bator

## Utility function to avoid some warnings about missing env. variables
sub Env_or {
    my($var,$default) = @_;
    if (exists $ENV{$var}) {
	return $ENV{$var} . ',';
    } else {
	$default = '0' unless $default;
	return "$default" . ',';
    }
}

############################################
# Namelist settings for all configurations #
############################################

######################
# Global settings
######################
%global = (
 NAMARG=>{
  'LELAM' => '.TRUE.,',
  'LECMWF'=> '.FALSE.',
 },
 NAMGRIB=>{
  'NENSFNB' => $ENV{ENSMBR},
 },
 NAMPAR0=>{
  'NPRINTLEV'   => '1,',
 },
);

######################
# Arguments for MASTERODB
######################
%args = (
  NAMARG=>{
   'NCONF' => 'NCONF,',
   'CNMEXP'=> 'CNMEXP,',
   'CUSTOP'=> 'CUSTOP',
   'UTSTEP' => 'UTSTEP',
   'LSLAG' => 'LSLAG',
 },
) ;

######################
# Technical settings
######################

# Host specific settings
%host_specific=(
 NAMDIM=>{
  'NPROMA' => $ENV{NPROMA},
},
 NAMFPSC2=>{
  'NFPROMA' => $ENV{NPROMA},
 },
 NAMFPSC2_DEP=>{
  'NFPROMA_DEP'=> $ENV{NPROMA},
 },
 NAMJFH=>{
  'N_VMASS' => '0,',
 },
 NAMPAR0=>{
  'MBX_SIZE' => &Env_or('MBX_SIZE','1000000000'),
  'LMPOFF'   => $ENV{LMPOFF},
  'LOPT_SCALAR' => '.TRUE.,',
 },
 NAMPAR1=>{
  'NCOMBFLEN' => '8000000,',
  'L_GATHERV_WRGP' => $ENV{L_GATHERV_WRGP},
 },
);

# MPP options
%mpp=(
 NAMPAR0=>{
  'LSTATS'   => '.TRUE.',
  'LMPDIAG'  => '.FALSE.,',
  'MP_TYPE'  => '2,',
  'NOUTPUT'  => '1,',
  'NPRGPEW'  => 'NPROCX,',
  'NPRGPNS'  => 'NPROCY,',
  'NPROC'    => 'NBPROC,',
  'NPRTRV'   => 'NPROCX,',
  'NPRTRW'   => 'NPROCY,',
 },
 NAMPAR1=>{
  'LSPLIT'    => '.TRUE.,',
  'NSTRIN'    => 'NBPROC,',
  'NSTROUT'   => 'NBPROC,',
 },
 NAMIO_SERV=>{
  'NPROC_IO'             => "$ENV{NPROC_IO}",
  'NIO_SERV_METHOD'      => '2',
  'NIO_SERV_BUF_MAXSIZE' => '20',
  'NMSG_LEVEL_SERVER'    => '0',
  'NMSG_LEVEL_CLIENT'    => '0',
  'LMSG_FLUSH_SERVER'    => '.FALSE.',
  'LMSG_FLUSH_CLIENT'    => '.FALSE.',
  'NPROCESS_LEVEL'       => '5',
  'CIFDIR'               => "$ENV{CIFDIR}",
 },
);

# File settings
%file=(
 NAMAFN=>{
  'GFP_ST%IANO' => '0,',
  'GFP_X10U%IANO' => '0,',
  'GFP_X10V%IANO' => '0,',
  'GFP_X2RH%IANO' => '0,',
  'GFP_X2T%IANO' => '0,',
  'GFP_XUGST%IANO' => '0,',
  'GFP_XVGST%IANO' => '0,',
 },
 NAMFA=>{
  'NBITCS' => '-1,',
  'NBITPG' => '-1,',
  'NSTRON' => '-1,',
  'YFACLF%NBITS' => '16,',
  'YFAG%NBITS' => '16,',
  'YFAI%NBITS' => '16,',
  'YFAL%NBITS' => '16,',
  'YFAR%NBITS' => '16,',
  'YFAS%NBITS' => '16,',
  'YFATKE%NBITS' => '16,',
  'YFACLF' => '\'CLOUD_FRACTI\',',
  'YFAG' => '\'GRAUPEL\',',
  'YFAI' => '\'SOLID_WATER\',',
  'YFAL' => '\'LIQUID_WATER\',',
  'YFAR' => '\'RAIN\',',
  'YFAS' => '\'SNOW\',',
  'YFAG' => '\'GRAUPEL\',',
  'YFATKE' => '\'TKE\',',
 },
 NAMGFL=>{
  'YG_NL%CNAME' => '\'GRAUPEL\',',
  'YI_NL%CNAME' => '\'SOLID_WATER\',',
  'YL_NL%CNAME' => '\'LIQUID_WATER\',',
  'YQ_NL%CNAME' => '\'HUMI.SPECIFI\',',
  'YR_NL%CNAME' => '\'RAIN\',',
  'YS_NL%CNAME' => '\'SNOW\',',
 },
 NAMSFXCMP=>{
  'NVGRIBSFX' => '0,', # Turn off compression for SURFEX fields to keep undef values
 },
);

###############################
# CLIMATE SIMULATION SETTINGS #
###############################
%cc01_mse=(
 NAMMCC=>{
  'LMCC01_MSE' => '.TRUE.',
  'LMCCECSST'  => '.TRUE.',
 },
),


#####################
# DYNAMICS SETTINGS #
#####################
# Main dynamics switches
%dynamics=(
 NAMCT0=>{
  'NFPOS' => 'NFPOS',
  'LTWOTL' => '.TRUE.,',
  'NFRDHFD' => '1,',
  'NFRGDI' => '15,',
  'NFRHIS' => '1,',
  'NFRSDI' => '15,',
  'NHISTS' => 'WRITELIST',
  'NPOSTS' => 'NPOSTS',
  'CNPPATH' => '\'.\',',
 },
 NAMCT1=>{
  'LRFILAF' => '.FALSE.,',
  'N1POS' => '1,',
  'N1RES' => '0,',
  },
 NAMDYNA=>{
  'NDLNPR' => '0,',
  'LSETTLS' => '.TRUE.,',
 },
 NAMDYN=>{
  'LADVF' => '.TRUE.,',
  'NTLAG' => '3,',
  'NVLAG' => '3,',
  'NWLAG' => '3,',
  'REPS1' => '0.,',
  'REPS2' => '0.,',
  'REPSM1' => '0.,',
  'REPSM2' => '0.,',
  'REPSP1' => '0.,',
  'SITR' => '350.,',
  'VESL' => '0.,',
  'XIDT' => '0.05,',
 },
 NAMINI=>{
  'LDFI' => '.FALSE.,',
 },
 NAMOPH=>{
  'LINC' => 'LLINC,',
 },
 NAMPHY0=>{
 'REFLKUO' => '5000.,',
 },
 NAMINTFLEX=>{
 'LINTFLEX' => $ENV{LINTFLEX},
 'LRADFLEX' => $ENV{LRADFLEX}, 
 },
 NAMTOPH=>{
  'ETCVIM' => '5000.,',
  'ETNEBU' => '5000.,',
  'ETPLUI' => '5000.,',
  'XDRMTK' => '2.E-08,',
  'XDRMTP' => '800.,',
  'XDRMTX' => '4.E-07,',
  'XDRMUK' => '1.E-07,',
  'XDRMUP' => '800.,',
  'XDRMUX' => '2.E-06,',
 },
 NEMELBC0A=>{
  'NBICOP' => '2,',
  'NBICOT' => '2,',
  'NBICOU' => '2,',
  'NECRIPL' => '1,',
 },
 NEMELBC0A=>{
  'LUNBC' => 'LUNBC,',
 },
 NEMELBC0B=>{
  'TEFRCL' => $ENV{TEFRCL},
 },
 #NEMDIM=>{
  #'NNOEXTZX' => '0,',
  #'NNOEXTZY' => '0,',
 #},
 NAMSPBD=>{
  'LSPBDC' => '.FALSE.,',
 },
);

# Non-hydrostatic settings
%nh=(
 NEMELBC0A=>{
  'NBICPD' => '2,',
  'NBICVD' => '2,',
 },
 NAMDYNA=>{
  'LGWADV' => '.TRUE.,',
  'LRDBBC' => '.FALSE.,',
  'NPDVAR' => '2,',
  'NVDVAR' => '4,',
  'NDLNPR' => '1,',
  'LGRADSP' => 'LGRADSP,',
  'LNESC' => '.FALSE.,',
  'LPC_FULL' => '.FALSE.,',
 },
 NAMDYN=>{
  'XIDT' => '0.0,',
  'SITR' => '350.,',
  'SITRA' => '70.,',
  'NSITER' => '0,',
  'NSPDLAG' => '3,',
  'NSVDLAG' => '3,',
  'LBOUND_D3' => '.FALSE.,',
 },
 NAMCT0=>{
  'LNHDYN'   => '.TRUE.,',
 },
 NAMRIP=>{
  'NFOST'  => '0,',
 },
);

%nh_alaro=(
 NAMDYNA=>{
  'LGWADV' => '.TRUE.,',
  'LRDBBC' => '.FALSE.,',
 },
);

# Vertical finite element
%vfe=(
 NAMCVER=>{
  'LVERTFE' =>'.TRUE.',
  'NVSCH'   =>'3',
 },
 NAMDYNA=>{
  'LAPRXPK' =>'.TRUE.',
 },
);

# DFI
%dfi=(
 NAMCFU=>{
  'LCUMFU'  => '.FALSE.,',
  'LNEBPAR' => '.FALSE.,',
 },
 NAMCT0=>{
  'LSPRT'     =>'.TRUE.',
 },
 NAMDDH=>{
  'LHDDOP' => '.FALSE.,',
  'LHDEFD' => '.FALSE.,',
  'LHDHKS' => '.FALSE.,',
 },
 NAMDFI=>{
  'TAUS' => 'TAUS,',
  'TAUC' => 'TAUC,',
  'RTDFI' => 'RTDFI,',
  'NSTDFI' => 'NSTDFI,',
 },
 NAMINI=>{
  'LDFI' => '.TRUE.,',
  'LBIAS' => 'LBIAS',
  'LINCR' => 'LINCR',
 },
 NAMXFU=>{
  'LXFU'   => '.FALSE.,',
  'LXSOIL' => '.FALSE.,',
 },
 NEMCT0=>{
  'LEQLIMSAT' =>'LEQLIMSAT',
 },
 NEMELBC0A=>{
  'LQCPL' => '.FALSE.,',
 },
);


#####################################
# Main physics options
# NB! These may contain switches for
# dynamics as well
#####################################

# AROME
%arome=(
 NAERAD=>{
  'LRRTM' => $ENV{LRRTM},
  'LSRTM' => '.FALSE.,',
  'NAER' => '1,',
  'NOVLP' => '6,',
  'NOZOCL' => '2,',
  'NRADFR' => 'ZNRADFR,',
  'NSW' => $ENV{NSW},
 },
 NAMAFN=>{
  'TFP_U%CLNAME' => '\'WIND.U.PHYS\',',
  'TFP_V%CLNAME' => '\'WIND.V.PHYS\',',
  'TFP_I%CLNAME' => '\'SOLID_WATER\',',
  'TFP_L%CLNAME' => '\'LIQUID_WATER\',',
  'GFP_CLSS%CLNAME' => '\'SURFACCNEIGE\'',
  'GFP_CLSP%CLNAME' => '\'SURFACCPLUIE\'',
  'GFP_CLSG%CLNAME' => '\'SURFACCGRAUPEL\'',
  'GFP_XLSS%CLNAME' => '\'SURFINSNEIGE\'',
  'GFP_XLSP%CLNAME' => '\'SURFINSPLUIE\'',
  'GFP_XLSG%CLNAME' => '\'SURFINSGRAUPEL\'',
 },
 NAMARPHY=>{
  'LKFBCONV' => '.FALSE.,',
  'LKFBD' => '.FALSE.,',
  'LKFBS' => '.FALSE.,',
  'LMFSHAL' => '.TRUE.,',
  'LMICRO' => '.TRUE.,',
  'LMPA' => '.TRUE.,',
  'LMSE' => '.TRUE.,',
  'LTURB' => '.TRUE.,',
 },
 NAMCFU=>{
  'LCUMFU' => '.TRUE.,',
  'LFPLS' => '.TRUE.,',
  'LFPLSG' => '.TRUE.,',
  'LFR' => '.TRUE.,',
  'LFRRC' => '.TRUE.,',
  'LFSF' => '.TRUE.,',
  'LNEBPAR' => '.TRUE.,',
  'LNEBTT' => '.TRUE.,',
  'LRAYD' => '.TRUE.,',
  'LRAYS' => '.TRUE.,',
 },
 NAMCHK=>{
  'LECHKEVO' => '.FALSE.,',
  'LECHKTND' => '.FALSE.,',
  'LECHKPS' => '.FALSE.,',
 },
 NAMCT0=>{
  'LAROME' => '.TRUE.,',
  'LMSGINIT' => '.FALSE.',
  'LNHDYN' => '.TRUE.,',
  'LSPRT' => '.TRUE.,',
  'LTWOTL' => '.TRUE.,',
  'NFRHIS' => '1,',
  'NFRSDI' => '15,',
 },
 NAMDYN=>{
  'LADVF' => '.TRUE.,',
  'LQMPD' => '.FALSE.,',
  'LQMT' => '.FALSE.,',
  'LQMVD' => '.FALSE.,',
  'NSITER' => '0,',
  'NSPDLAG' => '3,',
  'NSVDLAG' => '3,',
  'NTLAG' => '3,',
  'NVLAG' => '3,',
  'NWLAG' => '3,',
  'RDAMPDIV' => '20.,',
  'RDAMPPD' => '200000.,',
  'RDAMPQ' => '20.,',
  'RDAMPT' => '20.,',
  'RDAMPVD' => '20.,',
  'RDAMPVOR' => '20.,',
  'REPS1' => '0.,',
  'REPS2' => '0.,',
  'REPSM1' => '0.,',
  'REPSM2' => '0.,',
  'REPSP1' => '0.,',
  'SIPR' => '90000.,',
  'SLHDA0' => '0.25,',
  'SLHDD00' => '0.000065,',
  'VESL' => '0.,',
  'XIDT' => '0.0,',
  'ZSLHDP1' => '1.7,',
  'ZSLHDP3' => '0.6,',
 },
 NAMDYNA=>{
  'LCOMADH' => '.TRUE.,',
  'LCOMADV' => '.FALSE.,',
  'LCOMAD_W' => '.TRUE.,',
  'LCOMAD_T' => '.TRUE.,',
  'LCOMAD_SPD' => '.TRUE.,',
  'LCOMAD_SVD' => '.TRUE.,',
  'LCOMAD_SP' => '.TRUE.,',
  'LCOMAD_GFL' => '.TRUE.,',
  'LGRADSP' => 'LGRADSP,',
  'LGWADV' => '.TRUE.,',
  'LNESC' => '.FALSE.,',
  'LPC_FULL' => '.FALSE.,',
  'LRDBBC' => '.FALSE.,',
  'LSETTLS' => '.TRUE.,',
  'LSETTLST' => '.TRUE.,',
  'LSLHD_OLD' => '.TRUE.,',
  'LSLHD_SPD' => '.FALSE.,',
  'LSLHD_SVD' => '.FALSE.,',
  'LSLHD_T' => '.FALSE.,',
  'LSLHD_W' => '.FALSE.,',
  'LSLHD_GFL' => '.FALSE.,',
  'NDLNPR' => '1,',
  'NPDVAR' => '2,',
  'NVDVAR' => '4,',
  'SLHDEPSH' => '0.0025,',
 },
 NAMGFL=>{
  'NGFL_EZDIAG' => '4,',
  'YA_NL%LPT' => '.FALSE.,',
  'YA_NL%LREQOUT' => 'LCLOUDFRACTI,',
  'YA_NL%NREQIN' => 'ICLOUDFRACTI,',
  'YEZDIAG_NL(1)%CNAME' => '\'EZDIAG01\',',
  'YEZDIAG_NL(1)%LREQOUT' => '.FALSE.,',
  'YEZDIAG_NL(2)%CNAME' => '\'EZDIAG02\',',
  'YEZDIAG_NL(2)%LREQOUT' => '.FALSE.,',
  'YEZDIAG_NL(3)%CNAME' => '\'EZDIAG03\',',
  'YEZDIAG_NL(3)%LREQOUT' => '.FALSE.,',
  'YEZDIAG_NL(4)%CNAME' => '\'WFPOWER\',',
  'YEZDIAG_NL(4)%LREQOUT' => $ENV{LWINDFARM},
  'YG_NL%LCOMAD'=> '.TRUE.,',
  'YG_NL%LINTLIN'=> '.TRUE.,',
  'YG_NL%LPT' => '.FALSE.,',
  'YG_NL%LQM' => '.TRUE.,',
  'YG_NL%LSLHD' => '.FALSE.,',
  'YG_NL%NCOUPLING' => '-1,',
  'YG_NL%REFVALC' => '0.,',
  'YG_NL%NREQIN' => '1,',
  'YI_NL%LCOMAD'=> '.TRUE.,',
  'YI_NL%LINTLIN'=> '.TRUE.,',
  'YI_NL%LPT' => '.FALSE.,',
  'YI_NL%LQM' => '.TRUE.,',
  'YI_NL%LSLHD' => '.FALSE.,',
  'YI_NL%NCOUPLING' => '-1,',
  'YI_NL%REFVALC' => '0.,',
  'YI_NL%NREQIN' => '1,',
  'YL_NL%LCOMAD'=> '.TRUE.,',
  'YL_NL%LINTLIN'=> '.TRUE.,',
  'YL_NL%LPT' => '.FALSE.,',
  'YL_NL%LQM' => '.TRUE.,',
  'YL_NL%LSLHD' => '.FALSE.,',
  'YL_NL%NCOUPLING' => '-1,',
  'YL_NL%REFVALC' => '0.,',
  'YL_NL%NREQIN' => '1,',
  'YQ_NL%LCOMAD'=> '.TRUE.,',
  'YQ_NL%LPT' => '.FALSE.,',
  'YQ_NL%LQM' => '.TRUE.,',
  'YQ_NL%LSLHD' => '.FALSE.,',
  'YQ_NL%NCOUPLING' => '1,',
  'YQ_NL%NREQIN' => '1,',
  'YR_NL%LCOMAD'=> '.TRUE.,',
  'YR_NL%LINTLIN'=> '.TRUE.,',
  'YR_NL%LPT' => '.FALSE.,',
  'YR_NL%LQM' => '.TRUE.,',
  'YR_NL%LSLHD' => '.FALSE.,',
  'YR_NL%NCOUPLING' => '-1,',
  'YR_NL%REFVALC' => '0.,',
  'YR_NL%NREQIN' => '1,',
  'YSRC_NL%LPT' => '.FALSE.,',
  'YS_NL%LCOMAD'=> '.TRUE.,',
  'YS_NL%LINTLIN'=> '.TRUE.,',
  'YS_NL%LPT' => '.FALSE.,',
  'YS_NL%LQM' => '.TRUE.,',
  'YS_NL%LSLHD' => '.FALSE.,',
  'YS_NL%NCOUPLING' => '-1,',
  'YS_NL%REFVALC' => '0.,',
  'YS_NL%NREQIN' => '1,',
  'YTKE_NL%LPT' => '.FALSE.,',
  'YTKE_NL%NCOUPLING' => '0,',
  'YTKE_NL%NREQIN' => 'ITKE,',
 },
 NAMPARAR=>{
  'CMF_UPDRAFT' => '\'DUAL\'',
  'CMF_CLOUD'   => '\'STAT\'',
  'LMIXUV'      => '.FALSE.',
  'LLCRIT'      => '.TRUE.',
  'LTOTPRECL'    => '.TRUE.',
  'LTOTPREC'    => '.FALSE.',
  'LOLSMC' => '.TRUE.,',
  'LOTOWNC' => '.TRUE.,',
  'LOSEDIC' => '.TRUE.',
  'LOSIGMAS' => '.TRUE.,',
  'LOSUBG_COND' => '.TRUE.,',
  'NPRINTFR' => '10000,',
  'NPTP' => '1,',
  'VSIGQSAT' => '0.02,',
  'LOCND2'   => '.TRUE.',
  'RFRMIN(1)' => '1.0E-5',
  'RFRMIN(2)' => '1.0E-8',
  'RFRMIN(3)' => '3.0E-9',
  'RFRMIN(4)' => '3.0E-9',
  'RFRMIN(7)' => '0.',
  'RFRMIN(12)' => '0.05',
  'RFRMIN(22)' => '0.25',
  'RFRMIN(24)' => '2.5',
  'RFRMIN(26)' => '250.E6',
  'RFRMIN(29)' => '1000.',
  'LKOGAN' => '.TRUE.',
  'RADSN' => $ENV{RADSN},
  'RADGR' => $ENV{RADGR},
  'LSTATNW' => $ENV{LSTATNW},
  'LHARATU' => $ENV{LHARATU},
  'LHGT_QS' => $ENV{LHGT_QS},
  'NSWB_MNH' => $ENV{NSW},
  'LICERAD' => '.TRUE.',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LMPHYS' => '.TRUE.,',
  'LO3ABC' => '.TRUE.,',
  'LRAYFM' => $ENV{LRAYFM},
  'LHLRADUPD' => $ENV{LHLRADUPD},
  'LRAY' => $ENV{LRAY},
  'NRAY' => '2,',
  'LRNUMX' => $ENV{LRNUMX},
  'LRPROX' => '.FALSE.,',
  'NSORAYFR' => $ENV{NSORAYFR},
  'NTHRAYFR' => '-1,',
  'NRAUTOEV' => $ENV{NRAUTOEV},
  'LCLSATUR' => $ENV{LCLSATUR}, 
  'LVOIGT' => $ENV{LVOIGT},
  'LWINDFARM' => $ENV{LWINDFARM},
  'NWINDFARM' => $ENV{NWINDFARM},
 },
 NAMPHY0=>{
'ALMAV' => '300.,',
'BEDIFV' => '0.05,',
'ECMNP' => '3000.,',
'GCCSV' => '0.,',
'GCVADS' => '0.8,',
'GCVALFA' => '4.5E-05,',
'GCVBETA' => '0.2,',
'GCVMLT' => '0.00016,',
'GCVNU' => '2.5E-05,',
'GCVPSI' => '1.,',
'GCVPSIE' => '1.,',
'GDDEVA' => '0.25,',
'GDDSDE' => '0.5,',
'GWDCD' => '6.,',
'HUCOE' => '0.5,',
'HUTIL' => '1.8,',
'QSSC' => '400.,',
'QSSUSC' => '0.75,',
'QSSUSS' => '0.4,',
'QSSUSV' => '250.,',
'QSUSXC' => '0.0002,',
'QSUSXS' => '0.0003,',
'QXRAL' => '130.,',
'QXRDEL' => '0.49,',
'QXRHX' => '0.99,',
'QXRR' => '0.25,',
'RCVEVAP' => '0.25,',
'REVGSL' => '15.,',
'SCO' => '-20.,',
'TDDGP' => '0.8,',
'TENTR' => '2.5E-06,',
'TENTRX' => '8.E-05,',
'TUDGP' => '0.8,',
'UHDIFV' => '8.E-04,',
'USURIC' => '0.175,',
'USURICE' => '0.5,',
'USURICL' => '1.,',
'USURID' => '0.1,',
'USURIDE' => '0.25,',
'VZ0CM' => '1.5E-04,',
'XMAXLM' => '5000.,',
'XMINLM' => '10.,',
},
 NAMPHY1=>{
'ALBMIN' => '0.65,',
'ALCRIN' => '0.75,',
'GCGEL' => '3.E-5,',
'GCGELS' => '5.E-5,',
'GNEIMX' => '1.8,',
'GNEIMXS' => '1.8,',
'RCTVEG(3)' => '1.2E-05,',
'RCTVEG(4)' => '1.0E-05,',
},
 NAMPHY2=>{
'FACRAF' => '3.5,',
'HTKERAF' => '20.0,',
'LMULAF' => '.TRUE.,',
'LRAFTKE' => '.TRUE.,',
'LRAFTUR' => '.TRUE.,',
'XDAMP' => '1.,',
'XMULAF' => '-1.85,',
'LWMOCLOUD' => '.TRUE.,',
'HWMOLOW' => '2000.,',
},
 NAMPHY3=>{
'FCM_NU_DI' => $ENV{FCM_NU_DI},     
'FCM_NU_DL' => $ENV{FCM_NU_DL},     
'RLAMB_SOLID' => $ENV{RLAMB_SOLID},  
},
 NAMSPP=>{
  'LSPP' => &Env_or('LSPP','.FALSE.'),
  'TAU' => &Env_or('TAU_SPP','21600'),
  'SDEV' => &Env_or('SDEV_SPP','1.0'),
  'XLCOR' => &Env_or('XLCOR_SPP','0.10000E+07'),
  'NPATFR' => &Env_or('NPATFR_SPP','1'),
  'LSPG_SPP' => '.TRUE.',
  'SPGMU' => &Env_or('SPGMU_SPP','-999.0'),
  'SPGLAMBDA' => &Env_or('SPGLAMBDA_SPP','-999.0'),
  'SPGSIGMA' => &Env_or('SPGSIGMA_SPP','-999.0'),
  'SPGQ' => &Env_or('SPGQ_SPP','0.5'),
  'SPGADTMIN' => &Env_or('SPGADTMIN_SPP','0.1'),
  'SPGADTMAX' => &Env_or('SPGADTMAX_SPP','3.0'),
  'LLNN_MEAN1' => '.FALSE.,',
  'LPERT_PSIGQSAT' => '.TRUE.,',
  'LPERT_CLDDPTH' => '.FALSE.,',
  'LPERT_CLDDPTHDP' => '.TRUE.,',
  'LPERT_ICE_CLD_WGT' => '.TRUE.,',
  'LPERT_ICENU' => '.TRUE.,',
  'LPERT_KGN_ACON' => '.TRUE.,',
  'LPERT_KGN_SBGR' => '.TRUE.,',
  'LPERT_RADGR' => '.TRUE.,',
  'LPERT_RADSN' => '.TRUE.,',
  'LPERT_RFAC_TWOC' => '.TRUE.,',
  'LPERT_RZC_H' => '.TRUE.,',
  'LPERT_RZL_INF' => '.TRUE.,',
  'LPERT_RSWINHF' => '.FALSE.,',
  'LPERT_RLWINHF' => '.FALSE.,',
  'LLNN_MEAN1_PSIGQSAT' => '.TRUE.,',
  'LLNN_MEAN1_CLDDPTH' => '.TRUE.,',
  'LLNN_MEAN1_CLDDPTHDP' => '.TRUE.,',
  'LLNN_MEAN1_ICE_CLD_WGT' => '.TRUE.,',
  'LLNN_MEAN1_KGN_ACON' => '.TRUE.,',
  'LLNN_MEAN1_KGN_SBGR' => '.TRUE.,',
  'LLNN_MEAN1_ICENU' => '.TRUE.,',
  'LLNN_MEAN1_RADGR' => '.TRUE.,',
  'LLNN_MEAN1_RADSN' => '.TRUE.,',
  'LLNN_MEAN1_RFAC_TWOC' => '.TRUE.,',
  'LLNN_MEAN1_RZC_H' => '.TRUE.,',
  'LLNN_MEAN1_RZL_INF' => '.TRUE.,',
  'LLNN_MEAN1_RSWINHF' => '.TRUE.,',
  'LLNN_MEAN1_RLWINHF' => '.TRUE.,',
  'CMPERT_PSIGQSAT' => '0.1,',
  'CMPERT_CLDDPTH' => '0.1,',
  'CMPERT_CLDDPTHDP' => '0.1,',
  'CMPERT_ICE_CLD_WGT' => '0.1,',
  'CMPERT_ICENU' => '0.35,',
  'CMPERT_KGN_ACON' => '0.25,',
  'CMPERT_KGN_SBGR' => '0.1,',
  'CMPERT_RADGR' => '0.15,',
  'CMPERT_RADSN' => '0.15,',
  'CMPERT_RFAC_TWOC' => '0.1,',
  'CMPERT_RZC_H' => '0.1,',
  'CMPERT_RZL_INF' => '0.1,',
  'CMPERT_RSWINHF' => '0.1,',
  'CMPERT_RLWINHF' => '0.1,',
  'IEZDIAG_POS' => '1,',
  'CLIP_RADSN' => '0.,2.',
  'CLIP_RADGR' => '0.,2.',
  'CLIP_KGN_SBGR' => '0.,1.',
 },
 NAMSPSDT=>{
  'LSPSDT' => &Env_or('LSPSDT','.FALSE.'),
  'NSCALES_SDT' => '1,',
  'SDEV_SDT(1)' => &Env_or('SDEV_SDT','0.50'),
  'TAU_SDT(1)' => &Env_or('TAU_SDT','28800'),
  'XLCOR_SDT(1)' => &Env_or('XLCOR_SDT','500000'),
  'XCLIP_RATIO_SDT' => &Env_or('XCLIP_RATIO_SDT','2.0'),
  'CSPEC_SHAPE_SDT' => "'WeaverCourtier1',",
  'LWRITE_ARP' => '.FALSE.',
  'LSPG_SDT' => &Env_or('LSPG_SDT','.FALSE.'),
  'SPGQ_SDT' => &Env_or('SPGQ_SDT','0.5'),
  'SPGLAMBDA_SDT' => &Env_or('SPGLAMBDA_SDT','-999.0'),
  'SPGMU_SDT' => &Env_or('SPGMU_SDT','-999.0'),
  'SPGSIGMA_SDT' => &Env_or('SPGSIGMA_SDT','-999.0'),
  'SPGADTMIN_SDT' => &Env_or('SPGADTMIN_SDT','0.1'),
  'SPGADTMAX_SDT' => &Env_or('SPGADTMAX_SDT','3.0'),
 },
 NAMSTOPH=>{
  'LFORCENL' => 'LFORCENL,',
  'NFORCESTART' => '0,',
  'NFORCEEND' => '1,',
  'AMAGSTOPH' => '1.0,',
 },
 NAMTOPH=>{
'ETCVIM' => '5000.,',
'ETNEBU' => '5000.,',
'ETPLUI' => '5000.,',
'XDRMTK' => '6.E-07,',
'XDRMTP' => '800.,',
'XDRMUK' => '3.E-07,',
'XDRMUP' => '800.,',
},
 NAMTRANS0=>{
'RDISTR_E' => '1.,',
},
#Eoin: 'LGUSTBYPOS' => '.TRUE.,', removed
#Eoin: LGUSTBYPOS replaced by LRESET_GST and LRESET_GST2 (src/arpifs/module/yomxfu.F90)
#Eoin: Option to use LRESET to reset extreme temperatures to zero (src/arpifs/module/yomxfu.F90)
 NAMXFU=>{
'LXCLP' => '.TRUE.,',
'LXCLS' => '.TRUE.,',
'LXFU' => '.TRUE.,',
'LXNEBPA' => '.TRUE.,',
'LXNEBTT' => '.TRUE.,',
'LXNUVCLS' => '.TRUE.,',
'LXPLS' => '.TRUE.,',
'LXPLSG' => '.TRUE.,',
'LXQCLS' => '.TRUE.,',
'LXR' => '.TRUE.,',
'LXXGST' => '.TRUE.,',
'LXTHW' => '.TRUE.,',
'LXTRT' => '.TRUE.,',
'LXXDIAGH' => '.TRUE.,',
'LXTTCLS' => '.TRUE.,',
'NXGSTPERIOD' => $ENV{NXGSTPERIOD},
'NFRRAZ' => '1,',
'NRAZTS' => 'NRAZTSLIST',
},
 NEMELBC0A=>{
  'LESPCPL' => '.FALSE.',
 },
 NAMCHK=>{
  'LECHKEVO' => '.FALSE.,',
  'LECHKTND' => '.FALSE.,',
  'LECHKPS' => '.FALSE.,',
 },
);

# EDKF switches, to be applied after AROME
 %edkf=(
  NAMPARAR=>{
   'CMF_UPDRAFT' => '\'EDKF\'',
   'CMF_CLOUD'   => '\'DIRE\'',
  },
 );

 %tend_diag=(
  NAMGFL=>{
    'NGFL_EZDIAG' => '6,',
    'YEZDIAG_NL(1)%CNAME' => '\'PTENDU\',',
    'YEZDIAG_NL(1)%LREQOUT' => '.TRUE.,',
    'YEZDIAG_NL(2)%CNAME' => '\'PTENDV\',',
    'YEZDIAG_NL(2)%LREQOUT' => '.TRUE.,',
    'YEZDIAG_NL(3)%CNAME' => '\'PTENDT\',',
    'YEZDIAG_NL(3)%LREQOUT' => '.TRUE.,',
    'YEZDIAG_NL(4)%CNAME' => '\'PTENDR\',',
    'YEZDIAG_NL(4)%LREQOUT' => '.TRUE.,',
    'YEZDIAG_NL(5)%CNAME' => '\'MULNOISE\',',
    'YEZDIAG_NL(5)%LREQOUT' => '.TRUE.,',
    'YEZDIAG_NL(6)%CNAME' => '\'SPP_PATTERN\',',
    'YEZDIAG_NL(6)%LREQOUT' => '.TRUE.,',
  },
  NAMPHY=>{
    'NTEND_DIAG_FREQ_RESET' => '10800,',
    'NTEND_DIAG_POS' => '1,',
  },
  NAMSPSDT=>{
    'NMULNOISE_POS' => '5,',
  },
  NAMSPP=>{
    'IEZDIAG_POS' => '6,',
  },
 );


# Alaro-0
%alaro=(
 NAERAD=>{
  'LRRTM' => '.FALSE.,',
  'LSRTM' => '.FALSE.,',
  'NMCICA' => '0,',
  'NSW'    => '1,',
 },
 NAMAFN=>{
  'TFP_U%CLNAME' => '\'WIND.U.PHYS\',',
  'TFP_V%CLNAME' => '\'WIND.V.PHYS\',',
 },
 NAMARPHY=>{
  'CCOUPLING' => '\'V\',',
 },
 NAMCA=>{
  'CA_PROB' => '\'GOL\',',
  'LCA_ADVECT' => '.FALSE.,',
  'LCA_EXTRACT' => '.FALSE.,',
  'LCA_GLOBAL' => '.FALSE.,',
  'LCA_RANTROP' => '.FALSE.,',
  'LCA_SMOOTH' => '.FALSE.,',
  'LCA_TEST' => '.FALSE.,',
  'LCUCONV_CA' => '.FALSE.,',
  'NFERTYRS' => '30,',
  'NFRCASEED' => '1,',
  'NLIVES' => '30,',
  'NSPINUP' => '1000,',
  'RCA_SEEDPROB' => '0.5,',
 },
 NAMCFU=>{
  'LCUMFU' => '.TRUE.,',
  'LFPLC' => '.TRUE.,',
  'LFPLS' => '.TRUE.,',
  'LFR' => '.TRUE.,',
  'LFRRC' => '.TRUE.,',
  'LFSF' => '.TRUE.,',
  'LNEBPAR' => '.TRUE.,',
  'LRAYD' => '.TRUE.,',
  'LRAYS' => '.FALSE.,',
  'LSTRD' => '.TRUE.,',
  'LSTRT' => '.TRUE.,',
 },
 NAMCT0=>{
  'LSPRT' => '.TRUE.,',
  'LTWOTL' => '.TRUE.,',
  'NFRDHFD' => '1,',
  'NFRGDI' => '1,',
  'NFRHIS' => '1,',
  'NFRSDI' => '15,',
  'NHISTS' => 'WRITELIST,',
 },
 NAMDYN=>{
  'LADVF' => '.TRUE.,',
  'LQMHT' => '.FALSE.,',
  'LQMHW' => '.FALSE.,',
  'LQMP' => '.FALSE.,',
  'NITMP' => '2,',
  'NTLAG' => '3,',
  'NVLAG' => '3,',
  'NWLAG' => '3,',
  'RDAMPDIV' => '1.,',
  'RDAMPDIVS' => '10.,',
  'RDAMPQ' => '0.,',
  'RDAMPT' => '1.,',
  'RDAMPVOR' => '1.,',
  'RDAMPVORS' => '10.,',
  'REPS1' => '0.,',
  'REPS2' => '0.,',
  'REPSM1' => '0.,',
  'REPSM2' => '0.,',
  'REPSP1' => '0.,',
  'REXPDH' => '2.,',
  'SDRED' => '1.,',
  'SLEVDH' => '0.1,',
  'SLEVDHS' => '1.,',
  'SLHDA0' => '0.25,',
  'SLHDB' => '4.,',
  'SLHDD00' => '6.5E-05,',
  'VESL' => '0.,',
  'VMAX2' => '280.,',
  'XIDT' => '0.0,',
  'ZSLHDP1' => '1.7,',
  'ZSLHDP3' => '0.6,',
 },
 NAMDYNA=>{
  'LSLHD_GFL' => '.TRUE.,',
  'LSLHD_OLD' => '.FALSE.,',
  'LSLHD_SPD' => '.FALSE.,',
  'LSLHD_SVD' => '.TRUE.,',
  'LSLHD_T'   => '.TRUE.,',
  'LSLHD_W'   => '.TRUE.,',
  'SLHDEPSH'  => '0.016,',
  'SLHDEPSV'  => '0.0,',
  'SLHDKMAX'  => '6.,',
  'SLHDKMIN'  => '-0.6,',
  'LGRADSP' => '.FALSE.,',
 },
 NAMGFL=>{
  'YCPF_NL%NREQIN' => '0,',
  'YDAL_NL%LADV' => '.TRUE.,',
  'YDAL_NL%LGP' => '.TRUE.,',
  'YDAL_NL%LQM' => '.TRUE.,',
  'YDAL_NL%LQMH' => '.FALSE.,',
  'YDAL_NL%LREQOUT' => '.FALSE.,',
  'YDAL_NL%LSLHD' => '.FALSE.,',
  'YDAL_NL%NREQIN' => '0,',
  'YDOM_NL%LADV' => '.TRUE.,',
  'YDOM_NL%LGP' => '.TRUE.,',
  'YDOM_NL%LQM' => '.TRUE.,',
  'YDOM_NL%LQMH' => '.FALSE.,',
  'YDOM_NL%LREQOUT' => '.FALSE.,',
  'YDOM_NL%LSLHD' => '.FALSE.,',
  'YDOM_NL%NREQIN' => '0,',
  'YI_NL%LADV' => '.TRUE.,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LGPINGP' => '.FALSE.,',
  'YI_NL%LQM' => '.FALSE.,',
  'YI_NL%LQMH' => '.FALSE.,',
  'YI_NL%LREQOUT' => '.TRUE.,',
  'YI_NL%LSLHD' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NCOUPLING' => '-1,',
  'YI_NL%NREQIN' => '1,',
  'YI_NL%REFVALC' => '0.,',
  'YL_NL%LADV' => '.TRUE.,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LGPINGP' => '.FALSE.,',
  'YL_NL%LQM' => '.FALSE.,',
  'YL_NL%LQMH' => '.FALSE.,',
  'YL_NL%LREQOUT' => '.TRUE.,',
  'YL_NL%LSLHD' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NCOUPLING' => '-1,',
  'YL_NL%NREQIN' => '1,',
  'YL_NL%REFVALC' => '0.,',
  'YQ_NL%LADV' => '.TRUE.,',
  'YQ_NL%LGP' => '.FALSE.,',
  'YQ_NL%LGPINGP' => '.FALSE.,',
  'YQ_NL%LHV' => '.FALSE.,',
  'YQ_NL%LQM' => '.FALSE.,',
  'YQ_NL%LQMH' => '.FALSE.,',
  'YQ_NL%LREQOUT' => '.TRUE.,',
  'YQ_NL%LSLHD' => '.TRUE.,',
  'YQ_NL%LSP' => '.TRUE.,',
  'YQ_NL%LVSPLIP' => '.FALSE.,',
  'YQ_NL%NCOUPLING' => '1,',
  'YQ_NL%NREQIN' => '1,',
  'YRKTH_NL%LGP' => '.TRUE.,',
  'YRKTH_NL%LREQOUT' => '.FALSE.,',
  'YRKTH_NL%NREQIN' => '-1,',
  'YRKTH_NL%REFVALI' => '0,',
  'YRKTQC_NL%LGP' => '.TRUE.,',
  'YRKTQC_NL%LREQOUT' => '.FALSE.,',
  'YRKTQC_NL%NREQIN' => '-1,',
  'YRKTQC_NL%REFVALI' => '0,',
  'YRKTQV_NL%LGP' => '.TRUE.,',
  'YRKTQV_NL%LREQOUT' => '.FALSE.,',
  'YRKTQV_NL%NREQIN' => '-1,',
  'YRKTQV_NL%REFVALI' => '0,',
  'YR_NL%LADV' => '.TRUE.,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LGPINGP' => '.FALSE.,',
  'YR_NL%LQM' => '.FALSE.,',
  'YR_NL%LQMH' => '.FALSE.,',
  'YR_NL%LREQOUT' => '.TRUE.,',
  'YR_NL%LSLHD' => '.FALSE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NCOUPLING' => '-1,',
  'YR_NL%NREQIN' => '1,',
  'YR_NL%REFVALC' => '0.,',
  'YSPF_NL%NREQIN' => '0,',
  'YS_NL%LADV' => '.TRUE.,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LGPINGP' => '.FALSE.,',
  'YS_NL%LQM' => '.FALSE.,',
  'YS_NL%LQMH' => '.FALSE.,',
  'YS_NL%LREQOUT' => '.TRUE.,',
  'YS_NL%LSLHD' => '.FALSE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NCOUPLING' => '-1,',
  'YS_NL%NREQIN' => '1,',
  'YS_NL%REFVALC' => '0.,',
  'YTKE_NL%LADV' => '.TRUE.,',
  'YTKE_NL%LCDERS' => '.FALSE.,',
  'YTKE_NL%LGP' => '.TRUE.,',
  'YTKE_NL%LGPINGP' => '.FALSE.,',
  'YTKE_NL%LHV' => '.FALSE.,',
  'YTKE_NL%LQM' => '.FALSE.,',
  'YTKE_NL%LQMH' => '.FALSE.,',
  'YTKE_NL%LREQOUT' => '.TRUE.,',
  'YTKE_NL%LSLHD' => '.TRUE.,',
  'YTKE_NL%LSP' => '.FALSE.,',
  'YTKE_NL%LT5' => '.FALSE.,',
  'YTKE_NL%LVSPLIP' => '.FALSE.,',
  'YTKE_NL%NCOUPLING' => '0,',
  'YTKE_NL%NREQIN' => '0,',
  'YUAL_NL%LADV' => '.TRUE.,',
  'YUAL_NL%LGP' => '.TRUE.,',
  'YUAL_NL%LQM' => '.FALSE.,',
  'YUAL_NL%LQMH' => '.FALSE.,',
  'YUAL_NL%LREQOUT' => '.FALSE.,',
  'YUAL_NL%LSLHD' => '.FALSE.,',
  'YUAL_NL%NREQIN' => '0,',
  'YUEN_NL%LADV' => '.FALSE.,',
  'YUEN_NL%LGP' => '.TRUE.,',
  'YUEN_NL%LREQOUT' => '.FALSE.,',
  'YUEN_NL%NREQIN' => '0,',
  'YUNEBH_NL%LADV' => '.TRUE.,',
  'YUNEBH_NL%LGP' => '.TRUE.,',
  'YUNEBH_NL%LREQOUT' => '.FALSE.,',
  'YUNEBH_NL%NREQIN' => '0,',
  'YUOM_NL%LADV' => '.TRUE.,',
  'YUOM_NL%LGP' => '.TRUE.,',
  'YUOM_NL%LQM' => '.FALSE.,',
  'YUOM_NL%LQMH' => '.FALSE.,',
  'YUOM_NL%LREQOUT' => '.FALSE.,',
  'YUOM_NL%LSLHD' => '.FALSE.,',
  'YUOM_NL%NREQIN' => '0,',
 },
 NAMOPH=>{
  'LINC' => 'LLINC,',
 },
 NAMPARAR=>{
  'NSWB_MNH' => '1,',
 },
 NAMPHY=>{
  'CGMIXLEN' => '\'AY\',',
  'L3MT' => '.TRUE.,',
  'LA0MPS' => '.TRUE.,',
  'LACPANMX' => '.TRUE.,',
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LARPMPS' => '.FALSE.,',
  'LCDDPRO' => '.TRUE.,',
  'LCLSATUR' => '.TRUE.,',
  'LCOMOD' => '.FALSE.,',
  'LCONDWT' => '.TRUE.,',
  'LCVGQM' => '.TRUE.,',
  'LCVPPKF' => '.FALSE.,',
  'LCVPRO' => '.TRUE.,',
  'LCVRA' => '.FALSE.,',
  'LDIFCONS' => '.TRUE.,',
  'LENTCH' => '.TRUE.,',
  'LFPCOR' => '.TRUE.,',
  'LFSFIX' => '.FALSE.,',
  'LFSVAR' => '.TRUE.,',
  'LGLT' => '.TRUE.,',
  'LHUCN' => '.TRUE.,',
  'LNEBCV' => '.TRUE.,',
  'LNEBNXR' => '.TRUE.,',
  'LNEB_FP' => '.FALSE.,',
  'LNEWD' => '.TRUE.,',
  'LNEWSTAT' => '.TRUE.,',
  'LNOIAS' => '.TRUE.,',
  'LO3ABC' => '.TRUE.,',
  'LPHSPSH' => '.TRUE.,',
  'LPRGML' => '.TRUE.,',
  'LPTKE' => '.TRUE.,',
  'LQXRTGH' => '.TRUE.,',
  'LRAY' => '.TRUE.,',
  'LRAYFM' => '.FALSE.,',
  'LRAYLU' => '.FALSE.,',
  'LREWS' => '.TRUE.,',
  'LRMIX' => '.TRUE.,',
  'LRNUMX' => '.TRUE.,',
  'LRPROX' => '.TRUE.,',
  'LRRGUST' => '.TRUE.,',
  'LRSTAB' => '.TRUE.,',
  'LRSTAER' => '.FALSE.,',
  'LRTDL' => '.TRUE.,',
  'LRTPP' => '.TRUE.,',
  'LSCMF' => '.TRUE.,',
  'LSEDCL' => '.TRUE.,',
  'LSEDLAG' => '.FALSE.,',
  'LSEDSTA' => '.TRUE.,',
  'LSTRA' => '.FALSE.,',
  'LSTRAPRO' => '.FALSE.,',
  'LVFULL' => '.FALSE.,',
  'LVGSN' => '.TRUE.,',
  'LVOIGT' => '.TRUE.,',
  'LXRCDEV' => '.TRUE.,',
  'NPHYREP' => '-4,',
 },
 NAMPHY0=>{
  'ALMAV' => '200.,',
  'BEDIFV' => '0.1,',
  'EDD' => '1.,',
  'GCISMIN' => '5.5E-04,',
  'GCVACHI' => '20.,',
  'GCVALFA' => '4.5E-05,',
  'GCVNU' => '1.E-05,',
  'GCVPSI' => '1.,',
  'GCVPSIE' => '1.,',
  'GCVTAUDE' => '900.,',
  'GDDEVF' => '0.12,',
  'GENVSRH' => '1.,',
  'GPEFDC' => '0.18,',
  'GWDCD' => '5.4,',
  'GWDLT' => '1.,',
  'GWDSE' => '0.02,',
  'GWDVALI' => '0.5,',
  'HUCOE' => '1.4,',
  'HUCRED' => '1.,',
  'NCAPEMAX' => '0.,',
  'NCATAU' => '9000.,',
  'NUPTKE' => '0.52,',
  'QSSC' => '400.,',
  'QSSUSC' => '0.75,',
  'QSSUSS' => '0.4,',
  'QSSUSV' => '250.,',
  'QSUSXC' => '0.0002,',
  'QSUSXS' => '0.0003,',
  'QXRAL' => '130.,',
  'QXRDEL' => '0.5,',
  'QXRR' => '0.25,',
  'QXRTGH' => '1.6,',
  'RAUTEFR' => '1.E-03,',
  'RAUTEFS' => '1.E-03,',
  'RCIN' => '1.,',
  'RCVEVAP' => '0.25,',
  'REFLKUO' => '5000.,',
  'REVASX' => '2.E-07,',
  'REVGSL' => '15.,',
  'RMULACVG' => '-25.,',
  'RPHI0' => '1250.,',
  'RQICRMAX' => '5.E-05,',
  'RQICRMIN' => '8.E-07,',
  'RQLCR' => '3.E-04,',
  'RWBF1' => '1600.,',
  'TDDFR' => '0.0012,',
  'TDDGP' => '0.8,',
  'TENTR' => '5.E-06,',
  'TENTRD' => '1.6E-04,',
  'TENTRX' => '1.6E-04,',
  'TFVI' => '0.08,',
  'TFVL' => '0.02,',
  'USURIC' => '1.,',
  'USURICE' => '0.5,',
  'USURICL' => '4.,',
  'USURID' => '0.048,',
  'USURIDE' => '0.25,',
  'VZ0CM' => '1.0E-04,',
  'VZIUSTAR0' => '12.,',
  'WMXOV' => '0.8,',
  'XMAXLM' => '5000.,',
  'XMINLM' => '10.,',
 },
 NAMPHY1=>{
  'RCTVEG(3)' => '1.1E-05,',
 },
 NAMPHY2=>{
  'FACRAF' => '10.,',
  'LMULAF' => '.TRUE.,',
  'LRAFTKE' => '.TRUE.,',
  'LWMOCLOUD' => '.TRUE.,',
  'HWMOLOW' => '2000.,',
  'XDAMP' => '1.,',
  'XMULAF' => '-1.85,',
 },
 NAMTOPH=>{
  'ETCVIM' => '0.,',
  'ETNEBU' => '0.,',
  'ETPLUI' => '0.,',
  'XDRMTK' => '6.E-08,',
  'XDRMTP' => '800.,',
  'XDRMUK' => '3.E-07,',
  'XDRMUP' => '800.,',
  'XDRMTX' => '0.,',
  'XDRMUX' => '0.,',
 },
 NAMXFU=>{
  'LXCLP' => '.TRUE.,',
  'LXCLS' => '.TRUE.,',
  'LXFU' => '.TRUE.,',
  'LXHHCLS' => '.TRUE.,',
  'LXICV' => '.TRUE.,',
  'LXNEBPA' => '.TRUE.,',
  'LXNEBTT' => '.TRUE.,',
  'LXPLC' => '.TRUE.,',
  'LXPLS' => '.TRUE.,',
  'LXQCLS' => '.TRUE.,',
  'LXR' => '.TRUE.,',
  'LXSOIL' => '.TRUE.,',
  'LXTGST' => '.TRUE.,',
  'LXTRC' => '.TRUE.,',
  'LXTRD' => '.TRUE.,',
  'LXTRT' => '.TRUE.,',
  'LXTTCLS' => '.TRUE.,',
  'LXXGST' => '.TRUE.,',
  'NXGSTPERIOD' => '3600,',
  'NFRRAZ' => '1,',
  'NRAZTS' => 'NRAZTSLIST',
 },
 NEMELBC0A=>{
  'LQCPL' => '.FALSE.,',
  'NBICOP' => '2,',
  'NBICOT' => '2,',
  'NBICOU' => '2,',
  'NECRIPL' => '1,',
 },
);

# ALARO-1
%alaro1=(
 NAMGFL=>{
  'YFQTUR_NL%LADV' => '.FALSE.',
  'YFQTUR_NL%LGP' => '.TRUE.',
  'YFQTUR_NL%LREQOUT' => '.FALSE.',
  'YFQTUR_NL%NREQIN' => '0',
  'YFSTUR_NL%LADV' => '.FALSE.',
  'YFSTUR_NL%LGP' => '.TRUE.',
  'YFSTUR_NL%LREQOUT' => '.FALSE.',
  'YFSTUR_NL%NREQIN' => '0',
  'YSHTUR_NL%LADV' => '.FALSE.',
  'YSHTUR_NL%LGP' => '.TRUE.',
  'YSHTUR_NL%LREQOUT' => '.FALSE.',
  'YSHTUR_NL%NREQIN' => '0',
  'YTTE_NL%LADV' => '.TRUE.',
  'YTTE_NL%LGP' => '.TRUE.',
  'YTTE_NL%LREQOUT' => '.FALSE.',
  'YTTE_NL%NREQIN' => '0',
 },
 NAMPHY=>{
  'CGMIXLEN' => '\'EL0\'',
  'CGTURS' => '\'MD2\'',
  'LAB12' => '.TRUE.',
  'LCOEFKSURF' => '.TRUE.',
  'LCOEFKTKE' => '.TRUE.',
  'LCOEFK_F1' => '.TRUE.',
  'LCOEFK_FLX' => '.TRUE.',
  'LCOEFK_PTTE' => '.TRUE.',
  'LCOEFK_SCQ' => '.TRUE.',
  'LCOEFK_TOMS' => '.TRUE.',
  'LDIFCONS' => '.TRUE.',
  'LPTKE' => '.TRUE.',
  'LREWS' => '.FALSE.',
  'LRMIX' => '.FALSE.',
  'LRPROX' => '.FALSE.',
  'LRSTAB' => '.FALSE.',
  'LRTDL' => '.FALSE.,',
  'LRTPP' => '.TRUE.',
  'NDIFFNEB' => '1',
  'NRAUTOEV' => '3',
  'NRAY' => '2',
  'NSORAYFR' => '-1',
  'NTHRAYFR' => '-1',
 },
 NAMPHY0=>{
  'C3TKEFREE' => '1.183',
  'C_EPSILON' => '0.871',
  'ETKE_BETA_EPS' => '0.05',
  'ETKE_LAM0' => '0.29',
  'ETKE_OLAM' => '0.29',
  'NUPTKE' => '0.5265',
  'QSMODC' => '4.',
  'QXRAL' => '150.',
  'QXRAL_ADJ' => '150.',
  'RAUTEFR' => '0.5E-03',
  'RAUTEFS' => '2.E-03',
  'TKEMULT' => '1.,',
 },
 NAMPHY2=>{
  'XDAMP' => '1.',
 },
 NAMPHY3=>{
  'FCM_NU_DI' => '0.',
  'FCM_NU_DL' => '0.',
  'RLAMB_SOLID' => '0.6',
 },
);

# SURFEX
%surfex=(
 NAMARPHY=>{
  'LMSE' => '.TRUE.,',
 },
 NAMCT0=>{
  'NSFXHISTS' => 'WRITESLIST',
 },
 NAMCT1=>{
  'N1SFXHIS' => 'N1SFXHIS',
 },
 NAMXFU=>{
  'LXSOIL' => '.FALSE.,',
 },
 NAMPHMSE=>{
  'LPGDFWR' => '.FALSE.,',
  'LHISFWR' => '.TRUE.,',
   NSTEP_DUMP_STATE => 'NSTEP_DUMP_STATE,',
 },
);

# DDH
%ddh=(
 NAMDDH=>{
  'BDEDDH(1,01)' => '4.,',
  'BDEDDH(1,02)' => '4.,',
  'BDEDDH(1,03)' => '4.,',
  'BDEDDH(1,04)' => '4.,',
  'BDEDDH(1,05)' => '4.,',
  'BDEDDH(1,06)' => '4.,',
  'BDEDDH(1,07)' => '4.,',
  'BDEDDH(1,08)' => '4.,',
  'BDEDDH(1,09)' => '4.,',
  'BDEDDH(2,01)' => '1.,',
  'BDEDDH(2,02)' => '1.,',
  'BDEDDH(2,03)' => '1.,',
  'BDEDDH(2,04)' => '1.,',
  'BDEDDH(2,05)' => '1.,',
  'BDEDDH(2,06)' => '1.,',
  'BDEDDH(2,07)' => '1.,',
  'BDEDDH(2,08)' => '1.,',
  'BDEDDH(2,09)' => '1.,',
  'BDEDDH(3,01)' => '0014.124,',
  'BDEDDH(3,02)' => '0004.927,',
  'BDEDDH(3,03)' => '-001.437,',
  'BDEDDH(3,04)' => '0002.208,',
  'BDEDDH(3,05)' => '-000.692,',
  'BDEDDH(3,06)' => '0004.407,',
  'BDEDDH(3,07)' => '0001.374,',
  'BDEDDH(3,08)' => '0000.370,',
  'BDEDDH(3,09)' => '0015.750,',
  'BDEDDH(4,01)' => '0052.167,',
  'BDEDDH(4,02)' => '0051.971,',
  'BDEDDH(4,03)' => '0051.145,',
  'BDEDDH(4,04)' => '0048.713,',
  'BDEDDH(4,05)' => '0044.832,',
  'BDEDDH(4,06)' => '0043.858,',
  'BDEDDH(4,07)' => '0043.575,',
  'BDEDDH(4,08)' => '0043.128,',
  'BDEDDH(4,09)' => '0040.590,',
  'LHDDOP' => '.FALSE.,',
  'LHDEFD' => '.FALSE.,',
  'LHDHKS' => '.FALSE.,',
},
);

###############################
# E927 Interpolation settings #
###############################

# Main fullpos settings
%fullpos=(
 NAMAFN=>{
  'TFP_U%CLNAME' => '\'WIND.U.PHYS\',',
  'TFP_V%CLNAME' => '\'WIND.V.PHYS\',',
  'TFP_I%CLNAME' => '\'SOLID_WATER\',',
  'TFP_L%CLNAME' => '\'LIQUID_WATER\',',
 },
 NAMCT0=>{
  'NFPOS' => '1,',
  'NSPPR' => '0,',
 },
 NAMCT1=>{
  'LRFILAF' => '.FALSE.,',
  'N1HIS' => '0,',
 },
 NAMFPC=>{
  'CFPFMT' => '\'LELAM\',',
  'LTRACEFP' => '.TRUE.,',
  'LCRITSNOWTEMP' => '.FALSE.',
 },
) ;

# E927
%e927=(
 NAMGFL=>{
  'YQ_NL%LGP' => 'YQ_NL_LGP,',
  'YQ_NL%LSP' => 'YQ_NL_LSP,',
 },
 NAMCT0=>{
  'LSPRT' => 'LSPRT,',
  'LNHDYN' => 'LNHDYN,',
 },
 NAMFPC=>{
  'FPRHMAX' => '1.0,',
 },
 NEMFPEZO=>{
  'RCO_EZO'=> '5.0,',
 },
);

# E927 nh
%e927_nh=(
 NAMDYNA=>{
  'NDLNPR' => '1,',
  'NVDVAR' => '4,',
 },
);

# ALARO e927
%e927_alaro=(
 NAMAFN=>{
  'TFP_RR%LLGP' => '.TRUE.,',
  'TFP_I%LLGP' => '.TRUE.,',
  'TFP_SN%LLGP' => '.TRUE.,',
  'TFP_L%LLGP' => '.TRUE.,',
 },
 NAMARPHY=>{
  'LMSE' => '.FALSE.,',
 },
 NAMCT0=>{
  'NFPOS' => '2',
 },
 NAMFPC=>{
  'CFP2DF(1)' => '\'SURFPRESSION\',',
  'CFP2DF(2)' => '\'SPECSURFGEOPOTENTIEL\',',
  'CFP3DF' => 'CFP3DF',
  'CFPPHY(1)' => '\'SURFTEMPERATURE\',',
  'CFPPHY(10)' => '\'SURFIND.TERREMER\',',
  'CFPPHY(11)' => '\'SURFPROP.VEGETAT\',',
  'CFPPHY(12)' => '\'SURFVAR.GEOP.ANI\',',
  'CFPPHY(13)' => '\'SURFVAR.GEOP.DIR\',',
  'CFPPHY(14)' => '\'SURFIND.VEG.DOMI\',',
  'CFPPHY(15)' => '\'SURFRESI.STO.MIN\',',
  'CFPPHY(16)' => '\'SURFPROP.ARGILE\',',
  'CFPPHY(17)' => '\'SURFPROP.SABLE\',',
  'CFPPHY(18)' => '\'SURFEPAIS.SOL\',',
  'CFPPHY(19)' => '\'SURFIND.FOLIAIRE\',',
  'CFPPHY(2)' => '\'PROFTEMPERATURE\',',
  'CFPPHY(20)' => '\'SURFRES.EVAPOTRA\',',
  'CFPPHY(21)' => '\'SURFGZ0.THERM\',',
  'CFPPHY(22)' => '\'SURFRESERV.INTER\',',
  'CFPPHY(23)' => '\'PROFRESERV.GLACE\',',
  'CFPPHY(24)' => '\'SURFRESERV.GLACE\',',
  'CFPPHY(25)' => '\'SURFALBEDO NEIGE\',',
  'CFPPHY(26)' => '\'SURFDENSIT.NEIGE\',',
  'CFPPHY(27)' => '\'SURFALBEDO.SOLNU\',',
  'CFPPHY(28)' => '\'SURFALBEDO.VEG\',',
  'CFPPHY(29)' => '\'SURFGEOPOTENTIEL\',',
  'CFPPHY(3)' => '\'PROFRESERV.EAU\',',
  'CFPPHY(30)' => '\'SURFA.OF.OZONE  \',',
  'CFPPHY(31)' => '\'SURFB.OF.OZONE  \',',
  'CFPPHY(32)' => '\'SURFC.OF.OZONE  \',',
  'CFPPHY(4)' => '\'SURFRESERV.NEIGE\',',
  'CFPPHY(5)' => '\'SURFRESERV.EAU\',',
  'CFPPHY(6)' => '\'SURFZ0.FOIS.G\',',
  'CFPPHY(7)' => '\'SURFALBEDO\',',
  'CFPPHY(8)' => '\'SURFEMISSIVITE\',',
  'CFPPHY(9)' => '\'SURFET.GEOPOTENT\',',
  'LFPMOIS' => '.FALSE.,',
  'LFPQ' => '.FALSE.,',
  'NFPCLI' => '3,',
  'NRFP3S' => 'NRFP3S,',
 },
 NAMGFL=>{
  'YI_NL%NREQIN' => "$ENV{NREQIN}",
  'YL_NL%NREQIN' => "$ENV{NREQIN}",
  'YR_NL%NREQIN' => "$ENV{NREQIN}",
  'YS_NL%NREQIN' => "$ENV{NREQIN}",
 },
 NAMPHY=>{
  'LO3ABC' => '.TRUE.,',
  'LVGSN' => '.TRUE.,',
 },
);


# Arome e927
%e927_arome=(
 NAMAFN=>{
'TFP_GR%LLGP' => '.TRUE.,',
'TFP_Q%LLGP' => '.TRUE.,',
'TFP_RR%LLGP' => '.TRUE.,',
'TFP_I%LLGP' => '.TRUE.,',
'TFP_SN%LLGP' => '.TRUE.,',
'TFP_TKE%LLGP' => '.TRUE.,',
'TFP_L%LLGP' => '.TRUE.,',
},
 NAMCT0=>{
  'LAROME' => '.TRUE.,',
  'NFPOS' => '2',
 },
 NAMFPC=>{
  'CFP2DF(1)' => '\'SURFPRESSION\',',
  'CFP2DF(2)' => '\'SPECSURFGEOPOTENTIEL\',',
  'CFP3DF' => 'CFP3DF',
  'CFPPHY(1)' => '\'SURFTEMPERATURE\',',
  'CFPPHY(2)' => '\'SURFA.OF.OZONE  \',',
  'CFPPHY(3)' => '\'SURFB.OF.OZONE  \',',
  'CFPPHY(4)' => '\'SURFC.OF.OZONE  \',',
  'CFPPHY(5)' => '\'SURFAEROS.SEA   \',',
  'CFPPHY(6)' => '\'SURFAEROS.LAND  \',',
  'CFPPHY(7)' => '\'SURFAEROS.SOOT  \',',
  'CFPPHY(8)' => '\'SURFAEROS.DESERT\',',
  'CFPPHY(9)' => '\'SURFIND.TERREMER\',',
  'CFPPHY(10)'=> '\'SURFRESERV.NEIGE\',',
  'LFPQ' => '.FALSE.,',
  'NFPCLI' => '1,',
  'NFPSURFEX' => '0',
  'NRFP3S' => 'NRFP3S,',
 },
 NAMGFL=>{
  'YA_NL%NREQIN' => "$ENV{NREQIN_CLOUD_FRACTI}",
  'YG_NL%NREQIN' => "$ENV{NREQIN_GRAUPEL}",
  'YI_NL%NREQIN' => "$ENV{NREQIN}",
  'YL_NL%NREQIN' => "$ENV{NREQIN}",
  'YR_NL%NREQIN' => "$ENV{NREQIN}",
  'YS_NL%NREQIN' => "$ENV{NREQIN}",
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LFGEL' => '.FALSE.,',
  'LMPHYS' => '.TRUE.,',
  'LNEBN' => '.FALSE.,',
  'LO3ABC' => '.TRUE.,',
  'LSOLV' => '.FALSE.,',
  'LVGSN' => '.FALSE.,',
 },
);

###################################
# General postprocessing switches #
###################################

# Default fullpos settings
%pp_default=(
 NAMAFN=>{
'GFP_XCCC%IBITS' => '8,',
'GFP_XHCC%IBITS' => '8,',
'GFP_XLCC%IBITS' => '8,',
'GFP_XMCC%IBITS' => '8,',
'GFP_XTCC%IBITS' => '8,',
'TFP_ABS%ZFK' => '32.,',
'TFP_HU%IBITS' => '12,',
'TFP_MSL%IBITS' => '12,',
'TFP_PV%ZFK' => '64.,',
'TFP_Q%LLGP' => '.TRUE.,',
'TFP_RCLS%CLNAME' => '\'CLSHUMI.RELATIVE\',',
'TFP_RCLS%IBITS' => '12,',
'TFP_T%IBITS' => '12,',
'TFP_TCLS%CLNAME' => '\'CLSTEMPERATURE\',',
'TFP_TCLS%IBITS' => '12,',
'TFP_TH%IBITS' => '12,',
'TFP_THPW%IBITS' => '12,',
'TFP_TN%IBITS' => '12,',
'TFP_TWV%IBITS' => '12,',
'TFP_TX%IBITS' => '12,',
'TFP_U%CLNAME' => '\'WIND.U.PHYS\',',
'TFP_U%IBITS' => '12,',
'TFP_UCLS%CLNAME' => '\'CLSVENT.ZONAL\',',
'TFP_UCLS%IBITS' => '12,',
'TFP_UGST%IBITS' => '12,',
'TFP_V%CLNAME' => '\'WIND.V.PHYS\',',
'TFP_V%IBITS' => '12,',
'TFP_VCLS%CLNAME' => '\'CLSVENT.MERIDIEN\',',
'TFP_VCLS%IBITS' => '12,',
'TFP_VGST%IBITS' => '12,',
'TFP_VOR%ZFK' => '32.,',
'TFP_VV%ZFK' => '32.,',
},
 NAMCT0=>{
  'CNPPATH' => '\'.\',',
  'LSPRT' => '.FALSE.,',
 },
 NAMGEM=>{
 'REFLKUO' => '5000.,',
 },
 NAMGFL=>{
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '1,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NREQIN' => '1,',
  'YQ_NL%LGP' => '.FALSE.,',
  'YQ_NL%LSP' => '.TRUE.,',
  'YQ_NL%NREQIN' => '1,',
 },
 NAMPHY0=>{
   'XMAXLM' => '5000.,',
   'XMINLM' => '10.,',
 },
);


# NH postprocessing
%pp_nh=(
 NAMCT0=>{
  'LNHDYN' => '.TRUE.,',
  'LSPRT' => '.FALSE.,',
 },
 NAMDYNA=>{
  'NDLNPR' => '1,',
 },
);

# Switches for postprocessing with surfex
%pp_surfex=(
 NAMCT0=>{
  'LAROME' => '.TRUE.'
 },
 NAMPHY=>{
  'LFGEL' => '.FALSE.,',
  'LSOLV' => '.FALSE.,',
 },
 NAMGFL=>{
   'YQ_NL%LSP'   =>'.TRUE.',
   'YQ_NL%LGP'   =>'.FALSE.',
   'YL_NL%NREQIN'=>'0',
   'YI_NL%NREQIN'=>'0',
   'YR_NL%NREQIN'=>'0',
   'YS_NL%NREQIN'=>'0',
   'YG_NL%NREQIN'=>'0',
 },
) ;

# Special cases for arome
%pp_arome=(
 NAMAFN=>{
  'GFP_CLSG%CLNAME' => '\'SURFACCGRAUPEL\'',
  'GFP_CLSP%CLNAME' => '\'SURFACCPLUIE\'',
  'GFP_CLSS%CLNAME' => '\'SURFACCNEIGE\'',
  'TFP_Q%LLGP' => '.TRUE.,',
 },
 NAMCFU=>{
  'LFPLSG' => '.TRUE.,',
 },
 NAMCT0=>{
  'LAROME' => '.TRUE.,',
  'LNHDYN' => '.TRUE.,',
  'LSPRT' => '.TRUE.,',
 },
 NAMDYNA=>{
  'NDLNPR' => '1,',
 },
 NAMGFL=>{
  'YL_NL%NREQIN'=>'1',
  'YI_NL%NREQIN'=>'1',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NREQIN' => '1,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NREQIN' => '1,',
  'YG_NL%LGP' => '.TRUE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '1,',
  'YQ_NL%LGP' => '.TRUE.,',
  'YQ_NL%LSP' => '.FALSE.,',
 },
);



################
# Assimilation #
################

# Canari
%canari=(
 NACOBS=>{
'ORODIF' => '10000.,',
'OROLIM' => '10000.,',
 },
 NACTEX=>{
'LAECDS' => '.FALSE.,',
'LAECHK' => '.FALSE.,',
'LAEH2M' => '.TRUE.,',
'LAEHUM' => '.FALSE.,',
'LAEICS' => 'LAEICS,',
'LAEICS_SX' => 'LAEICS_SX,',
'LL_SODA'=> '.TRUE.,',
'LAEINC' => '.FALSE.,',
'LAEOMF' => '.TRUE.,',
'LAEOMN' => '.TRUE.,',
'LAEPDS' => '.FALSE.,',
'LAERFO' => '.TRUE.,',
'LAESNM' => 'LAESNM,',
'LAESST' => '.FALSE.,',
'LAESTA' => '.FALSE.,',
'LAESTU' => '.FALSE.,',
'LAET2M' => '.TRUE.,',
'LAEUPFLG' => '.FALSE.,',
'LAEUVT' => '.FALSE.,',
'LAEV1M' => '.FALSE.,',
'LAEWIO' => '.TRUE.,',
'LECSST' => 'ECMWF_SST,',
'NAEINC' => '0,',
'NSEAICE' => '0,',
'NSSTLIS' => '0,',
'RCLIMCA' => '0.0,',
'RCLISST' => '1.00,',
'RWPIB' => '2.,',
},
 NACVEG=>{
'ANEBUL' => '0.75,',
'LHUMID' => '.TRUE.,',
'LIMVEG' => '.TRUE.,',
'LISSEW' => '.FALSE.,',
'L_SM_WP' => '.TRUE.,',
'MINDJ' => '6,',
'NNEBUL' => '1,',
'NNEIGT' => '0,',
'NNEIGW' => '1,',
'NR_SM_WP' => '1,',
'RA_SM_WP' => '5000.0,',
'RCLIMN' => '0.,',
'RCLIMTP' => '1.,',
'RCLIMTS' => '0.,',
'RCLIMV' => '1.,',
'RCLIMWP' => '0.1,',
'RCLIMWS' => '0.,',
'SCOEFH' => '0.,',
'SCOEFT' => '0.,',
'SEVAP' => '0.,',
'SICE' => '5.,',
'SIGH2MO' => '.1,',
'SIGT2MO' => '1.,',
'SMU0' => '7.,',
'SNEIGT' => '1.,',
'SNEIGW' => '0.,',
'SPRECIP' => '.3,',
'SWFC' => '1.0,',
'V10MX' => '10.,',
},
 NADOCK=>{
'NMXGQA' => '100,30,10,10,6,6,5,0,0,0,',
'QCORMIN' => '0.05,0.05,0.05,0.05,0.05,0.05,0.05,0.05,0.01,0.,',
},
 NALORI=>{
'LCORRF' => '.TRUE.,',
'RCALPH' => '0.0,',
},
 NAMCOK=>{
'RCH2SY' => '2.5,',
'RCT2SY' => '10.,',
'RCSNSY' => '20.,',
},
 NAMCT0=>{
'LFDBOP' => '.FALSE.,',
'NSPPR' => '1,',
},
 NAMCT1=>{
'LRFILAF' => '.FALSE.,',
},
 NAMDPHY=>{
  'LDIRCLSMOD' => 'LDIRCLSMOD,',
 },
 NAMOBS=>{
'LCACHMT' => '.TRUE.,',
'LMKCMARPL' => '.FALSE.,',
'LSLREJ' => '.TRUE.,',
'L_F_SCR_WORK_TS' => '.FALSE.,',
},
 NAMPAR1=>{
  'LSPLIT'    => '.FALSE.,',
},
 NAMPHY=>{
'LCONDWT' => '.TRUE.,',
'LNEBN' => '.FALSE.,',
'LO3ABC' => '.TRUE.,',
'LRAY' => '.FALSE.,',
'LVGSN' => '.TRUE.,',
},
 NAMPHY2=>{
'LRAFTUR' => '.FALSE.,',
'XMULAF' => '0.,',
},
 NAMPRE=>{
  'IPRSA(:,1)' => '  1,  2,  3,  4,',
  'IPRSA(:,2)' => '      2,  3,  4, 41, 42, 39,',
  'IPRSA(:,4)' => ' 29, 58,',
  'IPRSA(:,5)' => ' 39,',
  'IPRSA(:,6)' => ' 58,',
  'IPRSA(:,7)' => ' 41, 42,',
  'IPRSA(:,8)' => ' 80, 92,',
  'IPRSA(:,9)' => ' 11,',
  'IPRSK(:,1)' => '  1,  3,  4,',
  'IPRSK(:,10)' => ' 41, 42,',
  'IPRSK(:,2)' => '  2,',
  'IPRSK(:,3)' => ' 29,',
  'IPRSK(:,4)' => '  1,  2, 57,',
  'IPRSK(:,5)' => ' 11,',
  'IPRSK(:,6)' => ' 80, 92,',
  'IPRSK(:,8)' => ' 39,',
  'IPRSK(:,9)' => ' 58,',
 },
 NAMVAR=>{
  'LCLDSINK' => '.FALSE.,',
 },
 NAMVARBC_RAD=>{
 },
 NAM_CANAPE=>{
'REF_A_H2' => '85000.,',
'REF_A_SST' => '300000.,',
'REF_A_T2' => '80000.,',
'REF_A_SN' => '30000.,',
'REF_S_H2' => '0.18,',
'REF_S_SST' => '0.8,',
'REF_S_T2' => '1.6,',
'REF_AP_SN' => '0.06,',
},
 NEMCT0=>{
  'LEQLIMSAT' => '.TRUE.',
 },
 NEMELBC0A=>{
  'NBICOP' => '2,',
  'NBICOT' => '2,',
  'NBICOU' => '2,',
  'NECRIPL' => '1,',
 },
);


%alaro_canari=(
 NAMGFL=>{
  'YCPF_NL%NREQIN' => '0,',
  'YDAL_NL%LADV' => '.TRUE.,',
  'YDAL_NL%LGP' => '.TRUE.,',
  'YDAL_NL%LQM' => '.FALSE.,',
  'YDAL_NL%LQMH' => '.FALSE.,',
  'YDAL_NL%LREQOUT' => '.FALSE.,',
  'YDAL_NL%LSLHD' => '.FALSE.,',
  'YDAL_NL%NREQIN' => '0,',
  'YDOM_NL%LADV' => '.TRUE.,',
  'YDOM_NL%LGP' => '.TRUE.,',
  'YDOM_NL%LQM' => '.FALSE.,',
  'YDOM_NL%LQMH' => '.FALSE.,',
  'YDOM_NL%LREQOUT' => '.FALSE.,',
  'YDOM_NL%LSLHD' => '.FALSE.',
  'YDOM_NL%NREQIN' => '0,',
  'YI_NL%LADV' => '.TRUE.,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LGPINGP' => '.FALSE.,',
  'YI_NL%LQM' => '.FALSE.,',
  'YI_NL%LQMH' => '.FALSE.,',
  'YI_NL%LREQOUT' => '.TRUE.,',
  'YI_NL%LSLHD' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NCOUPLING' => '0,',
  'YI_NL%NREQIN' => '1,',
  'YL_NL%LADV' => '.TRUE.,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LGPINGP' => '.FALSE.,',
  'YL_NL%LQM' => '.FALSE.,',
  'YL_NL%LQMH' => '.FALSE.,',
  'YL_NL%LREQOUT' => '.TRUE.,',
  'YL_NL%LSLHD' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NCOUPLING' => '0,',
  'YL_NL%NREQIN' => '1,',
  'YQ_NL%LADV' => '.TRUE.,',
  'YQ_NL%LGP' => '.FALSE.,',
  'YQ_NL%LGPINGP' => '.FALSE.,',
  'YQ_NL%LHV' => '.FALSE.,',
  'YQ_NL%LQM' => '.FALSE.,',
  'YQ_NL%LQMH' => '.FALSE.,',
  'YQ_NL%LREQOUT' => '.TRUE.,',
  'YQ_NL%LSLHD' => '.TRUE.,',
  'YQ_NL%LSP' => '.TRUE.,',
  'YQ_NL%LVSPLIP' => '.FALSE.,',
  'YQ_NL%NREQIN' => '1,',
  'YRKTH_NL%LGP' => '.TRUE.,',
  'YRKTH_NL%LREQOUT' => '.FALSE.,',
  'YRKTH_NL%NREQIN' => '-1,',
  'YRKTH_NL%REFVALI' => '0,',
  'YRKTQC_NL%LGP' => '.TRUE.,',
  'YRKTQC_NL%LREQOUT' => '.FALSE.,',
  'YRKTQC_NL%NREQIN' => '-1,',
  'YRKTQC_NL%REFVALI' => '0,',
  'YRKTQV_NL%LGP' => '.TRUE.,',
  'YRKTQV_NL%LREQOUT' => '.FALSE.,',
  'YRKTQV_NL%NREQIN' => '-1,',
  'YRKTQV_NL%REFVALI' => '0,',
  'YR_NL%LADV' => '.TRUE.,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LGPINGP' => '.FALSE.,',
  'YR_NL%LQM' => '.FALSE.,',
  'YR_NL%LQMH' => '.FALSE.,',
  'YR_NL%LREQOUT' => '.TRUE.,',
  'YR_NL%LSLHD' => '.FALSE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NCOUPLING' => '0,',
  'YR_NL%NREQIN' => '1,',
  'YSPF_NL%NREQIN' => '0,',
  'YS_NL%LADV' => '.TRUE.,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LGPINGP' => '.FALSE.,',
  'YS_NL%LQM' => '.FALSE.,',
  'YS_NL%LQMH' => '.FALSE.,',
  'YS_NL%LREQOUT' => '.TRUE.,',
  'YS_NL%LSLHD' => '.FALSE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NCOUPLING' => '0,',
  'YS_NL%NREQIN' => '1,',
  'YTKE_NL%LADV' => '.TRUE.,',
  'YTKE_NL%LCDERS' => '.FALSE.,',
  'YTKE_NL%LGP' => '.TRUE.,',
  'YTKE_NL%LGPINGP' => '.FALSE.,',
  'YTKE_NL%LHV' => '.FALSE.,',
  'YTKE_NL%LPT' => '.FALSE.,',
  'YTKE_NL%LQM' => '.FALSE.,',
  'YTKE_NL%LQMH' => '.FALSE.,',
  'YTKE_NL%LREQOUT' => '.TRUE.,',
  'YTKE_NL%LSLHD' => '.TRUE.,',
  'YTKE_NL%LSP' => '.FALSE.,',
  'YTKE_NL%LT5' => '.FALSE.,',
  'YTKE_NL%LVSPLIP' => '.FALSE.,',
  'YTKE_NL%NCOUPLING' => '0,',
  'YTKE_NL%NREQIN' => '0,',
  'YUAL_NL%LADV' => '.TRUE.,',
  'YUAL_NL%LGP' => '.TRUE.,',
  'YUAL_NL%LQM' => '.FALSE.,',
  'YUAL_NL%LQMH' => '.FALSE.,',
  'YUAL_NL%LREQOUT' => '.FALSE.,',
  'YUAL_NL%LSLHD' => '.FALSE.',
  'YUAL_NL%NREQIN' => '0,',
  'YUNEBH_NL%LGP' => '.TRUE.',
  'YUNEBH_NL%LREQOUT' => '.FALSE.,',
  'YUNEBH_NL%NREQIN' => '0,',
  'YUOM_NL%LADV' => '.TRUE.',
  'YUOM_NL%LGP' => '.TRUE.,',
  'YUOM_NL%LQM' => '.FALSE.,',
  'YUOM_NL%LQMH' => '.FALSE.,',
  'YUOM_NL%LREQOUT' => '.FALSE.,',
  'YUOM_NL%LSLHD' => '.FALSE.',
  'YUOM_NL%NREQIN' => '0,',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
 },
 NAMPHY0=>{
  'EDD' => '1.,',
  'USURIC' => '1.,',
  'USURICE' => '0.5,',
  'USURICL' => '4.,',
  'USURID' => '0.048,',
  'USURIDE' => '0.25,',
  'VZIUSTAR0' => '12.,',
 },
 NAMDYNA=>{
  'LSLHD_GFL' => '.TRUE.,',
 },
);

# Arome canari
%arome_canari=(
 NAMGFL=>{
  'YA_NL%NREQIN' => 'ICLOUDFRACTI,',
  'YA_NL%LREQOUT' => 'LCLOUDFRACTI,',
  'YQ_NL%LGPINGP' => '.TRUE.,',
  'YQ_NL%LGP' => '.TRUE.,',
  'YQ_NL%LSP' => '.FALSE.,',
  'YQ_NL%NREQIN' => '1,',
  'YQ_NL%LREQOUT' => '.TRUE.,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NREQIN' => '1,',
  'YL_NL%LREQOUT' => '.TRUE.,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '1,',
  'YI_NL%LREQOUT' => '.TRUE.,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NREQIN' => '1,',
  'YR_NL%LREQOUT' => '.TRUE.,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NREQIN' => '1,',
  'YS_NL%LREQOUT' => '.TRUE.,',
  'YG_NL%LGP' => '.TRUE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '1,',
  'YG_NL%LREQOUT' => '.TRUE.,',
  'YTKE_NL%LGP' => '.TRUE.,',
  'YTKE_NL%LSP' => '.FALSE.,',
  'YTKE_NL%NREQIN' => '1,',
  'YTKE_NL%LREQOUT' => '.TRUE.,',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
 },
);
# Varbc_rad
%varbc=(
 NAMVARBC=>{
 },
 NAMVARBC_RAD=>{
 'LBC_RAD' => '.TRUE.,',
 'yconfig(3,5)%nparam' => '10',
 'yconfig(3,5)%npredcs(1:10)' => '0,1,2,8,9,10,15,16,17,18',
 'yconfig(3,6)%nparam' => '5',
 'yconfig(3,6)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(3,7)%nparam' => '5',
 'yconfig(3,7)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(3,8)%nparam' => '5',
 'yconfig(3,8)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(3,9)%nparam' => '5',
 'yconfig(3,9)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(3,10)%nparam' => '5',
 'yconfig(3,10)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(4,2)%nparam' => '4',
 'yconfig(4,2)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(4,3)%nparam' => '5',
 'yconfig(4,3)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(4,4)%nparam' => '5',
 'yconfig(4,4)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(4,5)%nparam' => '5',
 'yconfig(4,5)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(15,2)%nparam' => '4',
 'yconfig(15,2)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(15,3)%nparam' => '5',
 'yconfig(15,3)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(15,4)%nparam' => '5',
 'yconfig(15,4)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(15,5)%nparam' => '5',
 'yconfig(15,5)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(16,5)%nparam' => '5',
 'yconfig(16,5)%npredcs(1:5)' => '0,1,8,9,10',
 'yconfig(73,1)%nparam' => '4',
 'yconfig(73,1)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,2)%nparam' => '4',
 'yconfig(73,2)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,3)%nparam' => '4',
 'yconfig(73,3)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,4)%nparam' => '4',
 'yconfig(73,4)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,5)%nparam' => '4',
 'yconfig(73,5)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,6)%nparam' => '4',
 'yconfig(73,6)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,7)%nparam' => '4',
 'yconfig(73,7)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,8)%nparam' => '4',
 'yconfig(73,8)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,9)%nparam' => '4',
 'yconfig(73,9)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,10)%nparam' => '4',
 'yconfig(73,10)%npredcs(1:4)' => '0,8,9,10',
 'yconfig(73,11)%nparam' => '6',
 'yconfig(73,11)%npredcs(1:6)' => '0,1,2,8,9,10',
 'yconfig(73,12)%nparam' => '6',
 'yconfig(73,12)%npredcs(1:6)' => '0,1,2,8,9,10',
 'yconfig(73,13)%nparam' => '6',
 'yconfig(73,13)%npredcs(1:6)' => '0,1,2,8,9,10',
 'yconfig(73,14)%nparam' => '6',
 'yconfig(73,14)%npredcs(1:6)' => '0,1,2,8,9,10',
 'yconfig(73,15)%nparam' => '6',
 'yconfig(73,15)%npredcs(1:6)' => '0,1,2,8,9,10',
 'NBG_AMSUA' => '2000',
 'NBG_AMSUB' => '2000',
 'NBG_MHS'   => '2000',
 'NBG_IASI'  => '2000',
 'NBG_ATMS'  => '2000',
 'NBG_CRIS'  => '2000',
 'NBG_MWHS2' => '2000',
 },
 NAMVARBC_AIREP=>{
'LBC_AIREP' => '.FALSE.,',
'LBC_AMDAR' => '.FALSE.,',
'LBC_ACARS' => '.FALSE.,',
'LBC_COLBA' => '.FALSE.,',
'LBC_CODAR' => '.FALSE.,',
},
    NAMVARBC_SFCOBS=>{
'LBC_SFCOBS_PS' => '.FALSE.,',
'LBC_SFCOBS_APD' => '.TRUE.,',
'nbg_sfcobs_min_apd'=> '15,',
'nbg_sfcobs_ndays_apd'  => '15,',
'nbg_sfcobs_min_ps'=> '15,',
'nbg_sfcobs_ndays_ps'  => '15,',
    },
);

%varbc_gnss=(
 NAMVARBC_SFCOBS=>{
  'YCONFIG(2)%NPARAM' => '1,',
  'YCONFIG(2)%NPREDCS(1:1)' => '0,',
 },
);

# Screening
%screening=(
 NAMCT0=>{
'NFPOS' => '0,',
'LOBS' => '.TRUE.,',
'LOBSC1' => '.TRUE.,',
'LSCREEN' => '.TRUE.,',
'LSIMOB' => '.FALSE.,',
'NCNTVAR' => '2,',
'NFRGDI' => '10000,',
'NFRHIS' => '10000,',
'NFRPOS' => '10000,',
'NFRSDI' => '10000,',
'NGDITS(0)' => '1,',
'NGDITS(1)' => '1,',
'NHISTS(0)' => '1,',
'NHISTS(1)' => '1,',
'NPOSTS(0)' => '1,',
'NPOSTS(1)' => '1,',
'NSDITS(0)' => '0,',
'NSDITS(1)' => '0,',
},
 NAMEMIS_CONF=>{
'LDYN_AMSU' => '.FALSE.,',
'LUSE_TELSEM' => '.FALSE.,',
},
 NAMINI=>{
'LBIAS' => '.FALSE.,',
'LINCR' => '.FALSE.,',
'LDFI'  => '.FALSE.,',
},
 NAMCOSJO=>{
'LTC' => '.FALSE.,',
'ROERR_RAD1C(16,2701)' => '4.0',
'ROERR_RAD1C(16,2910)' => '4.0',
'ROERR_RAD1C(16,2951)' => '4.0',
'ROERR_RAD1C(16,2958)' => '4.0',
'ROERR_RAD1C(16,2991)' => '4.0',
'ROERR_RAD1C(16,2993)' => '4.0',
'ROERR_RAD1C(16,3002)' => '4.0',
'ROERR_RAD1C(16,3008)' => '4.0',
'ROERR_RAD1C(16,3014)' => '4.0',
'ROERR_RAD1C(16,3027)' => '4.0',
'ROERR_RAD1C(16,3049)' => '4.0',
'ROERR_RAD1C(16,3058)' => '4.0',
'ROERR_RAD1C(16,3105)' => '4.0',
'ROERR_RAD1C(16,3577)' => '4.0',
},
 NAMMKODB=>{
'LBIASCV' => '.false.,',
'LSCATINT' => '.FALSE.,',
'LTBIASBUFR' => '.FALSE.,',
'LTBIASC' => '.false.,',
'L_SCAT_BIASSIG' => '.FALSE.,',
'NBIASCOR' => '0,',
'L_NEW_T_BIAS' => '.FALSE.,',
'L_NEW_RH_BIAS' => '.FALSE.,',
'L_T_REF_SONDE_BIAS_ADJUST' => '.FALSE.,',
'L_RH_REF_SONDE_BIAS_ADJUST' => '.FALSE.,',
'L_NEW_RH_BIAS_SOLAR_vs_night_m' => '.FALSE.,',
'L_NEW_T_BIAS_SOLAR_vs_night_m' => '.FALSE.,',
},
 NAMNN=>{
'LNNBC' => '.FALSE.,',
'LNNHC' => '.FALSE.,',
'LNNJAC' => '.FALSE.,',
'LNNLEARN' => '.FALSE.,',
'LNNM1QN3' => '.FALSE.,',
'LNNOUT' => '.FALSE.,',
'LNNPCA' => '.FALSE.,',
'LNNREAD' => '.TRUE.,',
'LNNSELECT' => '.FALSE.,',
'LNNWRI' => '.FALSE.,',
'NHIDDEN' => '2,',
'NINPUTS' => '4,',
},
 NAMOBS=>{
'LCACHMT' => '.TRUE.,',
'LCAPACH' => '.TRUE.,',
'LRSTBIAS_ODB' => '.FALSE.',
'LSLRW10' => '.TRUE.,',
'L_F_SCR_WORK_TS' => '.FALSE.,',
'NOBSHOR' => '201,',
'LAMSUB_FULL' => '.TRUE.,',
},
 NAMPAR1=>{
  'LSPLIT'    => '.FALSE.,',
},
 NAMSATS=>{
'LCO2_DIAG_AIRS' => '.FALSE.,',
'MEMIS_SW' => '1,',
},
 NAMSCC=>{
'LPERTURB' => 'LPERTURB,',
'NAENSEMBLE' => '1,',
'NAEMEMBER' => 'NAEMEMBER,',
'NBTEMDUP' => '0,',
'RFIND_AIREP' => '25000.,',
'RFIND_RAD1C(0)' => '80000.,',
'RFIND_RAD1C(1)' => '80000.,',
'RFIND_RAD1C(19)' => '80000.,',
'RFIND_RAD1C(15)' => '80000.,',
'RFIND_RAD1C(16)' => '80000.,',
'RFIND_RAD1C(27)' => '80000.,',
'RFIND_RAD1C(73)' => '80000.,',
'RFIND_RAD1C(2)' => '80000.,',
'RFIND_RAD1C(3)' => '80000.,',
'RFIND_RAD1C(4)' => '80000.,',
'RFIND_SATAM' => '45000.,',
'RFIND_SATOB' => '45000.,',
'RFIND_SCATT_ERS' => '50000.,',
'RMIND_RAD1C(0)' => '60000.,',
'RMIND_RAD1C(1)' => '60000.,',
'RMIND_RAD1C(19)' => '60000.,',
'RMIND_RAD1C(15)' => '40000.,',
'RMIND_RAD1C(2)' => '60000.,',
'RMIND_RAD1C(3)' => '60000.,',
'RMIND_RAD1C(4)' => '40000.,',
'RMIND_RAD1C(16)' => '60000.,',
'RMIND_RAD1C(27)' => '60000.,',
'RMIND_RAD1C(73)' => '60000.,',
'RMIND_SATAM' => '25000.,',
'RMIND_SATOB' => '25000.,',
'RMIND_RADAR' => '8000.,',
'RFIND_RADAR' => '15000.,',
'RMIND_SCATT_ERS' => '25000.,',
 },
 NAMTHLIM=>{
  'NASCAWVC' => '82,',
 },
 NAMVAR=>{
'LTOVSCV' => '.TRUE.,',
'LVARBC' => 'LVARBC,',
'L_CHECK_CONVERGENCE' => '.FALSE.,',
'NFRANA' => '10000,',
'NGRATS(0)' => '1,',
'NGRATS(1)' => '1,',
'NITER' => '1,',
'NSIMU' => '1,',
'NUPTRA' => '-1,',
'RCVGE' => '1.E-3,',
'LCLDSINK' => '.FALSE.,',
},
 NEMELBC0A=>{
  'NBICOP'  => '2,',
  'NBICOT'  => '2,',
  'NBICOU'  => '2,',
  'NECRIPL' => '0,',
},
 NEMVAR=>{
'ENIL1' => '300000.,',
'ENIL2' => '500000.,',
'ENILHBAL1' => '600000.,',
'ENILHBAL2' => '1000000.,',
'EVAREPSILON' => '1.E-2,',
'EXPVAR' => '1.0,',
'LCORCOSU_AUTO' => '.FALSE.,',
'LCORCOSU_HBAL' => '.FALSE.,',
'LCORCOSU_STAT' => '.FALSE.,',
'LEVARGP' => '.FALSE.,',
'LPERTRELAX' => '.FALSE.,',
'NBZONVAR_EW' => 'NBZONVAR_EW,',
'LMODEPS' => '.FALSE.,',
},
 NAMENKF=>{
  'LENKF' => 'LENKF,',
},
);

# Arome screening
%arome_screening=(
 NAMAFN=>{
  'TFP_I%LLGP' => '.TRUE.,',
  'TFP_L%LLGP' => '.TRUE.,',
 },
 NAMCT0=>{
  'LSPRT'     =>'.TRUE.',
 },
 NAMDPHY=>{
  'LDIRCLSMOD' => '.TRUE.,',
 },
 NAMDYNA=>{
  'NDLNPR' => '1,',
 },
 NAMGFL=>{
  'YA_NL%NREQIN' => 'ICLOUDFRACTI,',
  'YG_NL%LGP' => '.TRUE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '1,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '0,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NREQIN' => '0,',
  'YQ_NL%LGP' => '.TRUE.,',
  'YQ_NL%LSP' => '.FALSE.,',
  'YQ_NL%NREQIN' => '1,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NREQIN' => '1,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NREQIN' => '1,',
 },
 NAMMKODB=>{
   'LSCATINT' => '.FALSE.,',
   'NTBMAR' => &Env_or('NTBMAR',-90),
   'NTFMAR' => &Env_or('NTFMAR', 90),
 },
 NAMNPROF=>{
  'NOBSPROFS(13)' => '81,',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LO3ABC' => '.TRUE.,',
  'LVGSN' => '.TRUE.,',
 },
 NAMPHY0=>{
  'EDK' =>'5.,',
  'USURIC' => '0.175,',
  'USURICE' => '0.5,',
  'USURICL' => '1.,',
  'USURID' => '0.1,',
 },
 NAERAD=>{
  'LSRTM' => '.FALSE.,',
 },
 NAMSCC=>{
  'RFIND_RAD1C(1)' => '278000.,',
  'RFIND_RAD1C(2)' => '278000.,',
  'RMIND_RAD1C(1)' => '139000.,',
  'RMIND_RAD1C(2)' => '139000.,',
 },
);


# Alaro screening
%alaro_screening=(
 NAMCOSJO=>{
'SIGMAO_COEF' => '0.9,',
},
 NAMOBS=>{
  'LSCATT_NEUTRAL' => '.TRUE.,',
  'LSOE' => '.TRUE.,',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LECT' => '.FALSE.,',
  'LO3ABC' => '.TRUE.,',
  'LO3FL' => '.TRUE.,',
  'LVGSN' => '.TRUE.,',
 },
 NAMVAR=>{
  'LREADGPTRAJ' => '.FALSE.,',
 },
);

# LETKF particular options for screening
%letkf_screening=(
 NAMCOSJO=>{
  'NOTVAR(1:25,5)' => ' 0, 0,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,',
 },
 NAMSATS=>{
  'LRTCALC_HRETR(0)' => '.TRUE.,',
  'LRTCALC_HRETR(3)' => '.TRUE.,',
  'LRTCALC_HRETR(4)' => '.TRUE.,',
  'LRTCALC_HRETR(11)' => '.TRUE.,',
  'LRTCALC_HRETR(15)' => '.TRUE.,',
  'LRTCALC_HRETR(16)' => '.TRUE.,',
 },
);

# Minimization
%minimization=(
 NAMCT0=>{
'LFDBOP' => '.FALSE.,',
'NFPOS' => '0,',
'LOBS' => 'LBOBS,',
'LNHDYN'   => 'LBNHDYN,',
'LSIMOB' => '.FALSE.,',
'NCNTVAR' => '2,',
'NFRGDI' => '10000,',
'NFRHIS' => '10000,',
'NFRPOS' => '10000,',
'NFRSDI' => '10000,',
'NGDITS(0)' => '1,',
'NGDITS(1)' => '1,',
'NHISTS(0)' => '1,',
'NHISTS(1)' => '1,',
'NPOSTS(0)' => '1,',
'NPOSTS(1)' => '0,',
'NSDITS(0)' => '0,',
'NSDITS(1)' => '0,',
},
 NAMDYN=>{
'SIPR' => '100000.,',
'SITR' => '350.,',
},
 NAMEMIS_CONF=>{
'LDYN_AMSU' => '.FALSE.,',
'LUSE_TELSEM' => '.FALSE.,',
},
 NAMIOMI=>{
'CFVATRA' => '\'VATRH\',',
'NMUPD' => '5,',
},
 NAMJG=>{
   'CONFIG%L3DBGERR' => '.TRUE.,',
   'CONFIG%LCLMSFCE' => '.TRUE.,',
   'CONFIG%LCORCOSU' => '.FALSE.,',
   'CONFIG%LJB_NONLINEAR_BALANCE' => '.FALSE.,',
   'CONFIG%LJB_NONLINEAR_CVHUM' => '.FALSE.,',
   'CONFIG%LJB_NONLINEAR_CVO3' => '.FALSE.,',
   'CONFIG%LJB_NONLINEAR_BALANCE_RELAX' => '.FALSE.,',
   'CONFIG%LJB_OMEGA_BALANCE_RELAX' => '.FALSE.,',
   'CONFIG%LJB_OMEGA_BALANCE' => '.FALSE.,',
   'CONFIG%ELC' => '300000.,',
   'CONFIG%LJBBALBETA' => '.FALSE.,',
   'CONFIG%LSPFCE' => '.TRUE.,',
   'CONFIG%LSBQ_STRATOLOW' => '.FALSE.,',
   'CONFIG%LRDQERR' => '.FALSE.,',
   'CONFIG%LREDNMCQ' => '.FALSE.,',
   'CONFIG%LSBLATLONG' => '.FALSE.,',
   'CONFIG%REDNMC' => 'NREDNMC,',
 },
 NAMCOSJO=>{
'LQSCATT' => '.TRUE.,',
'LVARQC' => '.FALSE.',
'LTC' => '.FALSE.,',
'NOTVAR(1:27,1)' => ' 0, 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,',
'NOTVAR(1:25,2)' => ' 0, 0,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,3)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,4)' => ' 0, 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,5)' => ' 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,6)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,7)' => '-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,8)' => '-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,9)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,10)' =>'-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
},
 NAMNMI=>{
'FILTR(1)' => '.5,',
'FILTR(2)' => '.5,',
'FILTR(3)' => '.5,',
'FILTR(4)' => '.5,',
'LCOIMP' => '.TRUE.,',
'LCONMO' => '.TRUE.,',
'LGPROJ' => '.FALSE.,',
'LICONV' => '.FALSE.,',
'LNLNMI' => '.TRUE.,',
'LNMIFF' => '.FALSE.,',
'LRGENE' => '.TRUE.,',
'LRPIMP' => '.TRUE.,',
'LRSPSL' => '.FALSE.,',
'LSTDNMI' => '.FALSE.,',
'NVMODF' => '4,',
'NVMODF1' => '27,',
'NVMODF2' => '28,',
},
 NAMOBS=>{
'LCACHMT' => '.TRUE.,',
'LCAPACH' => '.FALSE.,',
'LMKCMARPL' => '.FALSE.,',
'L_F_SCR_WORK_TS' => '.FALSE.,',
'NOBSHOR' => '201,',
'LAMSUB_FULL' => '.TRUE.,',
},
 NAMPAR1=>{
  'LSPLIT'    => '.FALSE.,',
},
 NAMSATS=>{
'LCO2_DIAG_AIRS' => '.TRUE.,',
'MEMIS_SW' => '1,',
},
 NAMLCZ=>{
'LFORCE' => 'LFORCE,',
},
 NAMVAR=>{
'LANOBS' => '.FALSE.,',
'LBGOBS' => '.FALSE.,',
'LCLDSINK' => '.FALSE.,',
'LCONGRAD' => '.FALSE.,',
'LINITCV' => '.TRUE.,',
'LJC' => '.FALSE.,',
'LREADGPTRAJ' => '.FALSE.,',
'LSTATMERR' => '.FALSE.,',
'LTEST' => '.FALSE.,',
'LTOVSCV' => 'LTOVSCV,',
'LBGPERT' => 'LBGPERT',
'DELTA' => 'DELTA',
'NBGVECS' => 'NBGVECS',
'LQBAR' => 'LQBAR',
'LCNTBAL' => 'LCNTBAL',
'NWQBAR' => 'NWQBAR',
'LCVALPHA' => 'LCVALPHA',
'LJAZERO' => '.FALSE.',
'LUNIHOM' => '.TRUE.',
'NSPD_INDEX' => '2,',
'N_SCALES' => '1,',
'LSCALE' => '100000.,',
'LVARBC' => 'LBVARBC',
'L_CHECK_CONVERGENCE' => '.FALSE.,',
'NFRANA' => '10000,',
'NGRATS(0)' => '1,',
'NGRATS(1)' => '1,',
'NITER' => '50,',
'NSIMU' => '60,',
'MUPTRA' => '0,',
'NUPTRA' => 'NBUPTRA,',
'RCVGE' => '1.E-3,',
'LSKIPMIN' => 'LBSKIPMIN,',
'LCHRESINCR' => 'LBCHRESINCR,',
},
 NAMVARBC=>{
 },
 NAMVARBC_RAD=>{
'LBC_RAD' => '.TRUE.,',
 },
 NAMVRTL=>{
'L131TL' => '.TRUE.,',
'LOBSTL' => '.TRUE.,',
},
 NEMELBC0A=>{
  'NBICOP' => '2,',
  'NBICOT' => '2,',
  'NBICOU' => '2,',
 },
 NEMVAR=>{
'ENIL1' => '300000.,',
'ENIL2' => '500000.,',
'ENILHBAL1' => '600000.,',
'ENILHBAL2' => '1000000.,',
'EVAREPSILON' => '1.E-2,',
'EXPVAR' => '1.0,',
'LCORCOSU_AUTO' => '.FALSE.,',
'LCORCOSU_HBAL' => '.FALSE.,',
'LCORCOSU_STAT' => '.FALSE.,',
'LEVARGP' => '.FALSE.,',
'LPERTRELAX' => 'LPERTRELAX,',
'NBZONVAR_EW' => 'NBZONVAR_EW,',
'LMODEPS' => 'LMODEPS,',
'LSTBALB' => '.TRUE.,',
'LSTBALC' => '.TRUE.,',
'LSTBALD' => '.TRUE.,',
'LSTBALE' => '.TRUE.,',
'LSTBALF' => '.TRUE.,',
'LSTBALG' => '.TRUE.,',
},
);


%arome_minimization=(
 NAMAFN=>{
  'TFP_I%LLGP' => '.TRUE.,',
  'TFP_L%LLGP' => '.TRUE.,',
 },
 NAMCT0=>{
  'LSPRT'     =>'.FALSE.',
 },
 NAMDYN=>{
  'SITR' => '270.,',
 },
 NAMGFL=>{
  'YA_NL%NREQIN' => 'ICLOUDFRACTI,',
  'YCPF_NL%LGP' => '.FALSE.,',
  'YG_NL%LGP' => '.FALSE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '0,',
  'YI_NL%LGP' => '.FALSE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '0,',
  'YL_NL%LGP' => '.FALSE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NREQIN' => '0,',
  'YQ_NL%LGP' => 'LQGPIN,',
  'YQ_NL%LSP' => 'LQSPIN,',
  'YQ_NL%NREQIN' => '1,',
  'YR_NL%LGP' => '.FALSE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NREQIN' => '0,',
  'YS_NL%LGP' => '.FALSE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NREQIN' => '0,',
 },
 NAMCOSJO=>{
  'NOTVAR(1:44,13)' => '-1,-1,-1,-1, 0, -1, 0, 0,-1,-1, -1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,',
 },
 NAMMKODB=>{
   'NTBMAR' => &Env_or('NTBMAR',-90),
   'NTFMAR' => &Env_or('NTFMAR', 90),
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LBLVAR' => '.TRUE.,',
  'LNEBN' => '.FALSE.,',
  'LO3ABC' => '.TRUE.,',
  'LRAY' => '.FALSE.,',
  'LVGSN' => '.TRUE.,',
 },
 NAMPHY0=>{
  'EDK' =>'5.,',
  'USURIC' => '0.175,',
  'USURICE' => '0.5,',
  'USURICL' => '1.,',
  'USURID' => '0.1,',
 },
 NAMVAR=>{
  'LREADGPTRAJ' => '.TRUE.,',
  'LTRAJGP' => '.TRUE.,',
 },
);

# Alaro minimization
%alaro_minimization=(
 NAMSATS=>{
  'LCLD_RTCALC_ASSIM(0)' => '.FALSE.,',
  'LCLD_RTCALC_ASSIM(11)' => '.FALSE.,',
  'LCLD_RTCALC_ASSIM(3)' => '.FALSE.,',
  'LCLD_RTCALC_ASSIM(4)' => '.FALSE.,',
  'LCLD_RTCALC_ASSIM(6)' => '.FALSE.,',
 },
 NAMPHY=>{
  'LAERODES' => '.TRUE.,',
  'LAEROLAN' => '.TRUE.,',
  'LAEROSEA' => '.TRUE.,',
  'LAEROSOO' => '.TRUE.,',
  'LECT' => '.FALSE.,',
  'LO3ABC' => '.TRUE.,',
  'LO3FL' => '.TRUE.,',
  'LRAY' => '.FALSE.,',
  'LVGSN' => '.TRUE.,',
 },
 NAMPHY0=>{
  'EDD' => '1.,',
  'USURIC' => '1.,',
  'USURICE' => '0.5,',
  'USURICL' => '4.,',
  'USURID' => '0.048,',
  'USURIDE' => '0.25,',
  'VZIUSTAR0' => '12.,',
 },
 NAMVAR=>{
  'LREADGPTRAJ' => '.TRUE.,',
  'LTRAJGP' => '.TRUE.,',
 },
);


#########
# 4DVAR #
#########

# 4DVAR minimization
%minim4d=(
NAMTESTVAR=>{
  'NTESTVAR' => '2,',
  'LADTEST' => '.TRUE.,',
  'LTLTEST' => '.FALSE.,',
  'LINTEST' => '.FALSE.,',
  'LGRTEST' => '.FALSE.,',
 },
 NAMARPHY=>{
  'LKFBCONV' => '.FALSE.,',
  'LKFBD' => '.FALSE.,',
  'LKFBS' => '.FALSE.,',
  'LMFSHAL' => '.TRUE.,',
  'LMICRO' => '.TRUE.,',
  'LMPA' => '.FALSE.,',
  'LMSE' => '.FALSE.,',
  'LTURB' => '.TRUE.,',
 },
 NAMCFU=>{
  'LCUMFU' => '.FALSE.,',
  'LRAYS' => '.FALSE.,',
 },
 NAMCT0=>{
  'LAROME' => '.FALSE.,',
  'LOBS' => '.TRUE.',
  'NFRHIS' => '1000,',
  'NHISTS' => '0,',
  'LNHDYN'   => 'LBNHDYN,',
  'NFRSDI'   => '1,',
  'NFRGDI'   => '1,',
  'LFBDAP' => '.FALSE.,',
  'NSPPR' => '0,',
 },
 NAMCT1=>{
  'N1POS' => '0,',
 },
 NAMRIP=>{
  'TSTEP_TRAJ' => 'TSTEPTRAJ4D,',
 },
 NAMDYNA=>{
  'LGRADSP'  => '.FALSE.,',
  'NDLNPR'   => '0,',
 },
 NAMGFL=>{
  'NGFL_EZDIAG' => '3,',
  'YCPF_NL%LGP' => '.FALSE.,',
  'YG_NL%LGP' => '.TRUE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '0,',
  'YG_NL%NCOUPLING' => '0,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '0,',
  'YI_NL%LREQOUT' => '.FALSE.,',
  'YI_NL%NCOUPLING' => '0,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%LREQOUT' => '.FALSE.,',
  'YL_NL%NREQIN' => '0,',
  'YL_NL%NCOUPLING' => '0,',
  'YQ_NL%LGP' => '.FALSE.,',
  'YQ_NL%LSP' => '.TRUE.,',
  'YQ_NL%LGPINGP' => '.TRUE.,',
  'YQ_NL%NREQIN' => '1,',
  'YQ_NL%NCOUPLING' => '1,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%LREQOUT' => '.FALSE.,',
  'YR_NL%NREQIN' => '0,',
  'YR_NL%NCOUPLING' => '0,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%LREQOUT' => '.FALSE.,',
  'YS_NL%NREQIN' => '0,',
  'YS_NL%NCOUPLING' => '0,',
  'YTKE_NL%LGP' => '.TRUE.,',
  'YTKE_NL%LREQOUT' => '.FALSE.,',
  'YTKE_NL%NREQIN' => '-1,',
  'YTKE_NL%NCOUPLING' => '0,',
  'YTKE_NL%REFVALI' => '0.000001,',
 },
 NAMCOSJO=>{
'LQSCATT' => '.TRUE.,',
'LTC' => '.FALSE.,',
'NOTVAR(1:27,1)' => ' 0, 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,',
'NOTVAR(1:25,2)' => ' 0, 0,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,3)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,4)' => ' 0, 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,5)' => ' 0,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,6)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,7)' => '-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,8)' => '-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,9)' => ' 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
'NOTVAR(1:25,10)' =>'-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,',
 },
 NAMPAR0=>{
  'NPRGPEW' => 'NPROCX,',
  'NPRGPNS' => 'NPROCY,',
  'NPROC'   => 'NBPROC,',
  'NPRTRV'  => 'NPROCX,',
  'NPRTRW'  => 'NPROCY,',
 },
 NAMXFU=>{
  'LXFU'      =>'.FALSE.,',
  'LXTHW'      =>'.FALSE.,',
    },
 NAMPAR1=>{
  'LSLONDEM' => '.FALSE.,',
  'LSPLIT' => '.FALSE.,',
 },
 NAMPHY=>{
 'LMPHYS' => '.TRUE.,',
 'LRAYFM' => '.TRUE.,',
 'LNEIGE' => '.TRUE.,',
 'LFGEL' => '.FALSE.,',
 'NRAY' => '1,',
 },
 NAMSATS=>{
  'LCO2_DIAG_AIRS' => '.FALSE.,',
  'MEMIS_SW' => '1,',
 },
 NAMSIMPHL=>{
  'LVDIFSP' => '.TRUE.,',
  'LVDIFSPNL' => '.TRUE.,',
  'LSIMPH' => '.FALSE.,',
  'LGWDSP' => '.TRUE.,',
  'LSMOOTHA' => '.TRUE.,',
  'LSMOOTHB' => '.TRUE.,',
  'LSMOOTHD' => '.TRUE.,',
  'LTRAJPS' => '.TRUE.,',
  'LTRAJPST' => '.TRUE.,',
  'LPROCLDTL' => '.FALSE.,',
  'LGWDSPNL' => '.TRUE.,',
  'LSTRASPN' => '.TRUE.,',
  'RHCRIT1S' => '0.7,',
  'RHCRIT2S' => '0.7,',
 },
 NAMRES=>{
  'NFRRES' => '10000,',
 },
 NAMLCZ=>{
  'LFORCE' => 'LFORCE,',
 },
 NAMSTOPH=>{
  'LFORCENL' => 'LFORCENL,',
  'NFORCESTART' => '0,',
  'NFORCEEND' => '2,',
  'AMAGSTOPH' => '1.0,',
},
 NAMVAR=>{
  'LTOVSCV' => '.FALSE.,',
  'ALPHAG' => '1.0000000000,',
  'L3DFGAT' => '.FALSE.,',
  'LANOBS' => '.FALSE.,',
  'LCOLBCBEG' => '.TRUE.,',
  'LCOLBCEND' => '.FALSE.,',
  'LCONGRAD' => '.TRUE.,',
  'LJC' => '.FALSE.,',
  'LJCDFI' => '.FALSE.,',
  'LUSEJCDFI' => '.FALSE.,',
  'NITER' => 'NBITER4D,',
  'NSIMU' => 'NBSIMU4D,',
  'NUPTRA' => 'NBUPTRA,',
  'MUPTRA' => '3,',
  'NGRATS(0)' => '1,',
  'NFRGRA'   => '1000,',
  'LSKIPMIN' => '.FALSE.,',
  'LVARBC' => 'LBVARBC,',
  'RCVGE' => '0.001,',
 },
 NAMDFI=>{
  'TAUS' => '5400.,',
  'TAUC' => '10800.,',
  'QNORM_ADJUST_VOR' => '1.0,',
  'QNORM_ADJUST_DIV' => '1.0,',
  'QNORM_ADJUST_T' => '0.0,',
  'QNORM_ADJUST_Q' => '0.0,',
  'QNORM_ADJUST_LNSP' => '1.0,',
 },
 NAMVRTL=>{
  'LDRYTL' => '.TRUE.,',
 },
 NEMELBC0A=>{
  'LE0COTA' => '.TRUE.,',
  'NECOAD' => '-1,',
  'NECOTL' => '-1,',
  'NECRIPL' => '1,',
  'LQCPL' => '.FALSE.',
 },
 NAMIOMI=>{
  'LWARM_RD' => '.FALSE.,',
  'LWARM_WR' => '.FALSE.,',
 },
 NAMOBS=>{
 'LCACHMT' => '.TRUE.,',
 },
);


# 4DVAR screening
%screen4d=(
 NAMCFU=>{
  'LCUMFU' => '.FALSE.,',
 },
 NAMCT0=>{
  'NHISTS' => '0,',
 },
 NAMGFL=>{
  'NGFL_EZDIAG' => '3,',
 },
 NAMINI=>{
  'LDFI' => '.FALSE.,',
 },
 NAMCOSJO=>{
  'SIGMAO_COEF' => '0.9,',
 },
 NAMPAR0=>{
  'NPRGPEW' => 'NPROCX,',
  'NPRGPNS' => 'NPROCY,',
  'NPROC'   => 'NBPROC,',
  'NPRTRV'  => 'NPROCX,',
  'NPRTRW'  => 'NPROCY,',
 },
 NAMPAR1=>{
  'LSLONDEM' => '.TRUE.,',
  'LSPLIT' => '.FALSE.,',
 },
 NAMRES=>{
  'NFRRES' => '10000,',
 },
 NAMSCC=>{
  'LSCRE4D' => '.TRUE.,',
 },
 NAMXFU=>{
  'LXFU'      =>'.FALSE.,',
 },
 NAMVAR=>{
  'LVARBC' => 'LVARBC',
  'LTOVSCV' => '.FALSE.,',
  'NFRGRA'   => '1000,',
  'NUPTRA' => '-1,',
  'MUPTRA' => '3,',
 },
 NEMELBC0A=>{
  'NECRIPL' => '1,',
 },
 NAMENKF=>{
  'LENKF' => 'LENKF,',
 },
);


# 4DVAR trajectory
%traj4d=(
 NAMCFU=>{
  'LCUMFU' => '.TRUE.,',
 },
 NAMCT0=>{
  'LSPRT' => '.TRUE.,',
  'LOBS' => '.TRUE.,',
  'LOBSC1' => '.TRUE.,',
  'NCNTVAR' => '2,',
  'NFPOS' => '0,',
  'NFRGDI' => '10000,',
  'NFRPOS' => '1000,',
  'NFRSDI' => '10000,',
  'NGDITS' => '0,0',
  'NHISTS' => '-3,-0,-1,-2',
  'NPOSTS' => '3,0,1,2',
  'NSDITS' => '0,0',
  'NSFXHISTS' => '-3,-0,-1,-2',
 },
 NAMINI=>{
  'LBIAS' => '.FALSE.,',
  'LINCR' => '.FALSE.,',
  'LDFI'  => '.FALSE.,',
 },
 NAMCOSJO=>{
  'LTC' => '.FALSE.,',
  'ROERR_RAD1C(16,2701)' => '4.0',
  'ROERR_RAD1C(16,2910)' => '4.0',
  'ROERR_RAD1C(16,2951)' => '4.0',
  'ROERR_RAD1C(16,2958)' => '4.0',
  'ROERR_RAD1C(16,2991)' => '4.0',
  'ROERR_RAD1C(16,2993)' => '4.0',
  'ROERR_RAD1C(16,3002)' => '4.0',
  'ROERR_RAD1C(16,3008)' => '4.0',
  'ROERR_RAD1C(16,3014)' => '4.0',
  'ROERR_RAD1C(16,3027)' => '4.0',
  'ROERR_RAD1C(16,3049)' => '4.0',
  'ROERR_RAD1C(16,3058)' => '4.0',
  'ROERR_RAD1C(16,3105)' => '4.0',
  'ROERR_RAD1C(16,3577)' => '4.0',
  'SIGMAO_COEF' => '0.9,',
 },
 NAMOBS=>{
  'LCACHMT' => '.TRUE.,',
  'LCAPACH' => '.TRUE.,',
  'LSLRW10' => '.TRUE.,',
  'LSLRW10' => '.TRUE.,',
  'L_F_SCR_WORK_TS' => '.FALSE.,',
  'NOBSHOR' => '201,',
  'LAMSUB_FULL' => '.TRUE.,',
  'LRSTBIAS_ODB' => '.FALSE.',
 },
 NAMPAR0=>{
  'NPRGPEW' => 'NPROCX,',
  'NPRGPNS' => 'NPROCY,',
  'NPROC'   => 'NBPROC,',
  'NPRTRV'  => 'NPROCX,',
  'NPRTRW'  => 'NPROCY,',
 },
 NAMPAR1=>{
  'LSPLIT' => '.TRUE.,',
 },
 NAMRES=>{
  'NFRRES' => '10000,',
 },
 NAMSATS=>{
  'LCO2_DIAG_AIRS' => '.FALSE.,',
  'MEMIS_SW' => '1,',
 },
 NAMSTOPH=>{
  'LFORCENL' => 'LFORCENL,',
  'NFORCESTART' => '0,',
  'NFORCEEND' => '1,',
  'AMAGSTOPH' => '1.0,',
 },
 NAMXFU=>{
  'LXFU'      =>'.TRUE.,',
 },
 NAMVAR=>{
  'LCLDSINK' => '.FALSE.,',
  'LTOVSCV' => '.FALSE.,',
  'LVARBC' => 'LVARBC,',
  'MUPTRA' => '3,',
  'NFRGRA' => '1000,',
  'NUPTRA' => 'NBUPTRA,',
 },
 NEMVAR=>{
  'ENIL1' => '300000.,',
  'ENIL2' => '500000.,',
  'ENILHBAL1' => '600000.,',
  'ENILHBAL2' => '1000000.,',
  'EVAREPSILON' => '1.E-2,',
  'EXPVAR' => '1.0,',
  'LCORCOSU_AUTO' => '.FALSE.,',
  'LCORCOSU_HBAL' => '.FALSE.,',
  'LCORCOSU_STAT' => '.FALSE.,',
  'LEVARGP' => '.FALSE.,',
  'LMODEPS' => '.FALSE.,',
  'NBZONVAR_EW' => '20,',
 },
 NAMENKF=>{
  'LENKF' => 'LENKF,',
  'NSIZE_ENSEMBLE' => '-1,',
  'MYMEMBER' => '-1,',
 },
 NAMGFL=>{
  'YA_NL%LREQOUT' => '.FALSE.,',
  'YA_NL%NREQIN' => 'ICLOUDFRACTI,',
  'YG_NL%LGP' => '.TRUE.,',
  'YG_NL%LSP' => '.FALSE.,',
  'YG_NL%NREQIN' => '1,',
  'YI_NL%LGP' => '.TRUE.,',
  'YI_NL%LSP' => '.FALSE.,',
  'YI_NL%NREQIN' => '0,',
  'YL_NL%LGP' => '.TRUE.,',
  'YL_NL%LSP' => '.FALSE.,',
  'YL_NL%NREQIN' => '0,',
  'YQ_NL%LGP' => '.TRUE.,',
  'YQ_NL%LSP' => '.FALSE.,',
  'YQ_NL%NREQIN' => '1,',
  'YR_NL%LGP' => '.TRUE.,',
  'YR_NL%LSP' => '.FALSE.,',
  'YR_NL%NREQIN' => '1,',
  'YS_NL%LGP' => '.TRUE.,',
  'YS_NL%LSP' => '.FALSE.,',
  'YS_NL%NREQIN' => '1,',
  'NGFL_EZDIAG' => '3,',
 },
 NAMPHY=>{
'LVGSN' => '.TRUE.,',
 },
 NAMPHY0=>{
  'EDK' =>'5.,',
 },
 NAMDPHY=>{
  'LDIRCLSMOD' => '.TRUE.,',
 },
 NAMEMIS_CONF=>{
 'LDYN_AMSU' => '.FALSE.,',
 'LUSE_TELSEM' => '.FALSE.,',
 },
 NAMSCC=>{
 'LPERTURB' => '.FALSE.,',
 'NAENSEMBLE' => '1,',
 'NAEMEMBER' => '1,',
 'NBTEMDUP' => '0,',
 'RFIND_AIREP' => '25000.,',
 'RFIND_RAD1C(0)' => '80000.,',
 'RFIND_RAD1C(1)' => '80000.,',
 'RFIND_RAD1C(15)' => '80000.,',
 'RFIND_RAD1C(16)' => '80000.,',
 'RFIND_RAD1C(2)' => '80000.,',
 'RFIND_RAD1C(3)' => '80000.,',
 'RFIND_RAD1C(4)' => '80000.,',
 'RFIND_SATAM' => '45000.,',
 'RFIND_SATOB' => '45000.,',
 'RFIND_SCATT_ERS' => '50000.,',
 'RMIND_RAD1C(0)' => '60000.,',
 'RMIND_RAD1C(1)' => '60000.,',
 'RMIND_RAD1C(15)' => '40000.,',
 'RMIND_RAD1C(2)' => '60000.,',
 'RMIND_RAD1C(3)' => '60000.,',
 'RMIND_RAD1C(4)' => '40000.,',
 'RMIND_RAD1C(16)' => '60000.,',
 'RMIND_SATAM' => '25000.,',
 'RMIND_SATOB' => '25000.,',
 'RMIND_RADAR' => '8000.,',
 'RFIND_RADAR' => '15000.,',
 'RMIND_SCATT_ERS' => '25000.,',
 },
 NAMTHLIM=>{
  'NASCAWVC' => '82,',
 },
);

#########
# LETKF #
#########

# First guess error
%fgerror=(
 NAMCONTROL=>{
  'YCONTROL%NENSSIZE' => 'LETKF_NENS,',
  'YCONTROL%CXBFNAME' => '"fcerr_in",',
  'YCONTROL%CXAFNAME' => '"stdev_vars",',
  'YCONTROL%CREF_SP_FNAME' => '"fcerr_in",',
  'YCONTROL%NPROC' => $ENV{NPROC},
  'YCONTROL%N3DVARS' => '6,',
  'YCONTROL%IGRIB3D' => '6,11,33,34,51,52,',
  'YCONTROL%N2DVARS' => '1,',
  'YCONTROL%IGRIB2D' => '1,',
  'YCONTROL%NLEVS' => $ENV{NLEV},
  'YCONTROL%IANTIME' => 'LETKF_IANTIME,',
  'YCONTROL%LCONVLNPS2PS' => '.false.,',
  'YCONTROL%INFL_METHOD' => '"obs_inc",',
  'YCONTROL%LCYCLE_INFLATION' => '.false.,',
  'YCONTROL%LELAM' => '.true.,',
  'YCONTROL%LOPER_ENS' => '.true.,',
  'YCONTROL%LRADIANCE_ERR' => '.false.,',
 },
);

# LETKF
%letkf=(
 NAMCONTROL=>{
  'YCONTROL%NENSSIZE' => 'LETKF_NENS,',
  'YCONTROL%CXBFNAME' => '"XB",',
  'YCONTROL%CXAFNAME' => '"analysis",',
  'YCONTROL%CREF_SP_FNAME' => '"XB",',
  'YCONTROL%NPROC' => $ENV{NPROC},
  'YCONTROL%N3DVARS' => '4,',
  'YCONTROL%IGRIB3D' => '11,33,34,51,',
  'YCONTROL%N2DVARS' => '1,',
  'YCONTROL%IGRIB2D' => '1,',
  'YCONTROL%NLEVS' => $ENV{NLEV},
  'YCONTROL%CANAL_METHOD' => '"letkf",',
  'YCONTROL%INFL_METHOD' => '"jeff",',
  'YCONTROL%COVLOCALH' => 'LCOVLOCALH,',
  'YCONTROL%COVLOCALV' => 'LCOVLOCALV,',
  'YCONTROL%INFLATION' => 'LINFLATION,',
  'YCONTROL%POST_INFLATION' => '0.0,',
  'YCONTROL%INFL_FG_VAR' => '0.1,',
  'YCONTROL%ZREDLIM' => '0.99,',
  'YCONTROL%IANTIME' => 'LETKF_IANTIME,',
  'YCONTROL%LCYCLE_INFLATION' => '.false.,',
  'YCONTROL%LADDITIVE_INFLATION' => 'ADD_INFL,',
  'YCONTROL%ALPHA_ADDINFL' => '0.25,',
  'YCONTROL%LVARQC' => '.false.,',
  'YCONTROL%NITER_OBSAN' => '1,',
  'YCONTROL%COV_LOC_METHOD' => '"standard",',
  'YCONTROL%ALPHA_COV_LOC' => '0.50,',
  'YCONTROL%CBALANCE' => '"none",',
  'YCONTROL%LELAM' => '.true.,',
  'YCONTROL%LSMIX' => 'LSMIXBC,',
  'YCONTROL%HYBRID' => 'LHYBRID,',
 },
);

######################
# Climate generation #
######################

# Climate generations (e923)
%climate=(
 NAMARG=>{
  'CNMEXP'    => '\'CLIM\',',
  'NCONF'     => '923,',
  'CUSTOP'    => '\'t0\',',
  'TSTEP'     => '600.,',
  'LSLAG'     => '.TRUE.,',
  'NSUPERSEDE'=> '0,',
 },
 NAMCT0=>{
  'LRPLANE' => '.TRUE.,',
  'LALLOPR' => '.FALSE.,',
 },
 NAMMCC=>{
  'N923' => '0,',
 },
 NAMPHY=>{
  'LMPHYS' => '.TRUE.,',
  'LSOLV' => '.TRUE.,',
  'LVGSN' => '.TRUE.,',
 },
 NAMPHY0=>{
  'GCVPSI' => '0.,',
 },
 NEMDIM=>{
  'NBZONG' => '8,',
  'NBZONL' => '8,',
 },
);

########
# Misc #
########

# General namelist settings for Tangent-Linear and Adjoint tests
%TLAD_tests=(
 NAMCFU=>{
  'LCUMFU' => '.FALSE.,',
 },
 NAMCT0=>{
  'NFRHIS'    =>'1,',
  'NFRPOS'    =>'1,',
  'NFRSDI'    =>'1,',
  'NFRGDI'    =>'1,',
  'NFRDHFZ'   =>'1,',
  'NPISPS(0)' =>'-1,',
  'NPISPS(1)' =>'-48,',
  'LFBDAP'    =>'.TRUE.,',
  'NSPPR'     =>'1,',
  'CFPATH'    =>'\'ICMSH\',',
  'LARPEGEF'  =>'.TRUE.,',
  'LTWOTL'    =>'.TRUE.,',
  'LVERCOR'   =>'.FALSE.,',
  'LVECADIN'  =>'.FALSE.,',
 },
 NAMCT1=>{
  'LRFILAF'   =>'.FALSE.,',
 },
 NAMDYN=>{
  'LDRY_ECMWF'=>'.FALSE.,',
  'NITMP'     =>'2,',
  'RCMSLP0'   =>'1.,',
  'LADVF'     =>'.TRUE.,',
  'XIDT'      =>'0.00,',
 },
 NAMDYNA=>{
  'LSETTLS'   =>'.TRUE.,',
 },
 NAMPHY=>{
  'LVGSN'     =>'.FALSE.,',
  'LMPHYS'    =>'.FALSE.,',
  'LO3ABC'    =>'.FALSE.,',
 },
 NAMPHY0=>{
  'RCVEVAP'   =>'0.25,',
 },
 NAMINI=>{
  'LDFI'     => '.FALSE.,',
 },
 NEMELBC0A=>{
  'NECOTL'    =>'-1,',
  'LE0COTA'   =>'.TRUE.,',
  'NBICOP'    =>'2,',
  'NBICOT'    =>'2,',
  'NBICOU'    =>'2,',
  'NECRIPL'   =>'1,',
 },
 NEMELBC0B=>{
  'TEFRCL' => $ENV{TEFRCL},
 },
 NAMXFU=>{
  'LXFU'      =>'.FALSE.,',
 },
);

# Extra Adjoint test options
%e401=(
 NEMELBC0A=>{
  'NECOAD'=>'-1,',
 },
);

# Oulan
%oulan=(
NADIRS=>{
   'NDATE'       =>   'DDATE,',
   'NRESO'       =>   'HHOUR,',
   'LZONEA'      =>  '.TRUE.,',
   'ALANZA'      =>   'SALANZA,',
   'ALASZA'      =>   'SALASZA,',
   'ALOOZA'      =>   'SALOOZA,',
   'ALOEZA'      =>   'SALOEZA,',
   'LNEWSYNOPBUFR' => 'SLNEWSYNOPBUFR,',
   'LNEWSHIPBUFR'  => 'SLNEWSHIPBUFR,',
   'LNEWBUOYBUFR'  => 'SLNEWBUOYBUFR,',
   'LNEWTEMPBUFR'  => 'SLNEWTEMPBUFR,',
   'NDIFFM1'     =>      '30,',
   'NDIFFP1'     =>      '30,',
   'NDIFFM2'     =>     '300,',
   'NDIFFP2'     =>     '259,',
   'NINIT'       =>       '0,',
   'LTOVSAMSUA'  => '.FALSE.,',
   'LTOVSAMSUB'  => '.FALSE.,',
   'LTOVSHIRS'   => '.FALSE.,',
   'LTEMP'       =>  '.TRUE.,',
   'LTEMPDROP'   =>  '.TRUE.,',
   'LTEMPSHIP'   =>  '.TRUE.,',
   'LSYNOP'      =>  '.TRUE.,',
   'LSHIP'       =>  '.TRUE.,',
   'LBUOY'       =>  '.TRUE.,',
   'LPILOT'      =>  '.TRUE.,',
   'LAMDAR'      =>  '.TRUE.,',
   'LAIREP'      =>  '.TRUE.,',
   'LMODES'      =>  '.TRUE.,',
   'LACAR'       =>  '.FALSE.,',
   'LEUROPROFIL' =>  '.FALSE.,',
   'LRH2Q'       =>  '.TRUE.,',
   'LTACBUOYPREF'     =>  '.FALSE.,',
   'LTACSHPPREF'      =>  '.FALSE.,',
   'LTACSYNPREF'      =>  '.FALSE.,',
 },
NANBOB=>{
   'NBTOVSAMSUA'  => ' 80000,',
   'NBTOVSAMSUB'  => ' 80000,',
   'NBTOVSHIRS'   => '  8000,',
   'NBTEMP'       => '  2000,',
   'NBTEMPDROP'   => '  1000,',
   'NBTEMPSHIP'   => '  1000,',
   'NBPILOT'      => '  2000,',
   'NBSYNOP'      => ' 60000,',
   'NBSHIP'       => ' 30000,',
   'NBBUOY'       => '  4000,',
   'NBAMDAR'      => '750000,',
   'NBAIREP'      => '750000,',
   'NBACAR'       => '750000,',
   'NBMODES'      => '750000,',
   'NBEUROPROFIL' => ' 15000,',
 },
);

# Bator
%bator=(
  NADIRS=>{
  },
  NAMSCEN=>{
  },
  NAMDYNCORE=>{
  },
);


# MUSC
%musc=(
 NAMDIM=>{
  'NPROMA' => '-4,',
 },
 NAMCT0=>{
  'LSFORC' => '.TRUE.,',
 },
 NAMFA=>{
  'NVGRIB' => '0,',
 },
 NAMFPSC2=>{
  'NFPROMA' => '-4,',
 },
 NAMFPSC2_DEP=>{
  'NFPROMA_DEP'=> '-4,',
 },
 NAMGFL=>{
  'NGFL_FORC'=>'3,',
  'YFORC_NL(1)%CNAME'=>'\'FORC001\',',
  'YFORC_NL(2)%CNAME'=>'\'FORC002\',',
  'YFORC_NL(3)%CNAME'=>'\'FORC003\',',
  'YG_NL%NCOUPLING' => '0,',
  'YI_NL%NCOUPLING' => '0,',
  'YL_NL%NCOUPLING' => '0,',
  'YQ_NL%NCOUPLING' => '0,',
  'YR_NL%NCOUPLING' => '0,',
  'YS_NL%NCOUPLING' => '0,',
 },
 NAMLSFORC=>{
  'LMUSCLFA'=>'.TRUE.,',
  'LGEOST_UV_FRC'=>'.FALSE.,',
  'LT_ADV_FRC'=>'.FALSE.,',
  'LQV_ADV_FRC'=>'.FALSE.,',
  'LUV_ADV_FRC'=>'.FALSE.,',
  'LSW_FRC'=>'.FALSE.,',
  'LT_NUDG'=>'.FALSE.,',
  'LUV_NUDG'=>'.FALSE.,',
  'LQV_NUDG'=>'.FALSE.,',
  'RELAX_TAUT'=>'3600.',
  'RELAX_TAUU'=>'3600.',
  'RELAX_TAUQ'=>'3600.',
 },
 NAMOPH=>{
  'NCADFORM' => '1',
 },
 NAMPAR0=>{
  'LMPOFF'   => '.TRUE.',
 },
 NAMPAR1=>{
  'L_GATHERV_WRGP'=>'.FALSE.,',
 },
 NEMELBC0A=>{
  'LESPCPL' => '.FALSE.',
 },
 NEMGEO=>{
   'RLAT_ACAD'=> $ENV{LAT0},
   'RLON_ACAD'=> $ENV{LON0},
 },
) ;

# Femars

%femars=(
 NAMVAR=>{
  'LFEMARSD' => '.TRUE.,',
  'LFEMARSD_WRITERAW' => '.FALSE.,',
 },
 NAMCT0=>{
  'LSPRT'     =>'.FALSE.',
  'NFPOS' => '0,',
  'NSFXHISTS' => '0,',
  'NHISTS' => '0,',
  'NPOSTS' => '0,',
 },
 NAMARPHY=>{
  'LMSE' => '.FALSE.,',
 },
 NEMELBC0B=>{
  'NEK0' => '0,',
  'NEK1' => '0,',
  'NEN1' => '0,',
  'NEN2' => '0,',
  'TEFRCL' => 0.,
 },
 NAMOPH=>{
  'LINC' => '.FALSE.,',
 },
 NAMCT1=>{
  'N1SFXHIS' => '0,',
 },
 NAMSTOPH=>{
 'LFORCENL' => '.FALSE.,',
 },
 NAMXFU=>{
  'NRAZTS' => '-1,',
 },
 NAERAD=>{
  'NRADFR' => '0,',
 },
 #NEMDIM=>{
  #'NNOEXTZX' => '0,',
  #'NNOEXTZY' => '0,',
 #},
 NAMPHMSE=>{
  'LFMREAD' => '.FALSE.',
  'LFMWRIT' => '.FALSE.',
 },
) ;
%femars_alaro=(
 NAMPHY=>{
  'LMPHYS' => '.FALSE.,',
 },
) ;

