# Settings for hourly based and minute (time-step) based output
if [ "$TFLAG" = min ] ; then
  LLINC=".FALSE."
else
  LLINC=".TRUE."
fi

# Frequency of AROME radiation call in time steps (15 min)
ZNRADFR=$(( 900 / TSTEP ))

# Domain dependent settings for transition zones in AROME spectral nudging
# horizontally it is approximately 50 and 100 km in wavelength
# vertically a height correspnding to around 50 and 100 hpa

gs=$( echo "$GSIZE" | cut -f 1 -d . )
ZNEK0=$( expr \( "$NLON" \* "$gs" \) / 100000 || echo "" )
ZNEK1=$( expr \( "$NLON" \* "$gs" \) / 50000 || echo "" )

if [ "$VLEV" = MF_60 ]; then
  ZNEN1=6
  ZNEN2=9
else
  ZNEN1=3
  ZNEN2=6
fi

# vorticity dealiasing
if [ "${LGRADSP-no}" = yes ]; then
  lgradsp=.TRUE.
else
  lgradsp=.FALSE.
fi

# upper boundary condition
if [ "${LUNBC-no}" = yes ]; then
  lunbc=.TRUE.
else
  lunbc=.FALSE.
fi

if [ "$LSPBDC" = yes ]; then
  NNOEXTZX=0
  NNOEXTZY=0
  lspbdc=.TRUE.
else
  lspbdc=.FALSE.
fi

export LSTATNW=.FALSE.
if [ "$STATNW" = yes ]; then
  LSTATNW=.TRUE.
fi

export LHARATU=.FALSE.
if [ "$HARATU" = yes ]; then
  LHARATU=.TRUE.
fi

export LHGT_QS=.FALSE.
if [ "$HGT_QS" = yes ]; then
  LHGT_QS=.TRUE.
fi

# wind turbine parametrization
export LWINDFARM=.FALSE.
export NWINDFARM=0
# Fitch et al. (2012)
if [ "$WINDFARM" = 1 ]; then
  NWINDFARM=1
  LWINDFARM=.TRUE. # To allocate power variable
fi
# Volker et al. (2015)
if [ "$WINDFARM" = 2 ]; then
  NWINDFARM=2
  LWINDFARM=.TRUE. # To allocate power variable
fi

# Link ECOCLIMAP param files
if [ "$ECOCLIMAP_VERSION" != "SG" ] ; then
 ln -sf $ECOCLIMAP_PARAM_BINDIR/*.bin .
fi

export LRRTM=.TRUE.
export LRAY=.FALSE.
export LINTFLEX=.FALSE.
export LRADFLEX=.FALSE.
export NSW=6
export RADSN=0.5
export RADGR=0.25
export LRAYFM=.TRUE.
export LHLRADUPD=.TRUE.
export LRNUMX=.FALSE.
export NSORAYFR=1
export NRAUTOEV=0
export FCM_NU_DI=1.972E-01
export FCM_NU_DL=4.286E-01
export RLAMB_SOLID=0.0
export LCLSATUR=.FALSE.
export LVOIGT=.FALSE.
 
if [ "$RADSCHEME" = ACRA ]; then
   LRRTM=.FALSE.
   LRAY=.TRUE.
   LINTFLEX=.TRUE.
   LRADFLEX=.TRUE.
   NSW=1
   RADSN=0.0
   RADGR=0.0
   LRAYFM=.FALSE.
   LHLRADUPD=.FALSE.
   LRNUMX=.TRUE.
   NSORAYFR=-1
   NRAUTOEV=3
   FCM_NU_DI=0.0
   FCM_NU_DL=0.0
   RLAMB_SOLID=0.6
   LCLSATUR=.TRUE.
   LVOIGT=.TRUE.
fi


