MODULE WINDFARM_MOD
USE PARKIND1, ONLY : JPIM,JPRB

IMPLICIT NONE

PUBLIC :: WINDFARM, WINDFARM_EWP

SAVE 
  LOGICAL :: LINITIALISED = .FALSE.

  ! TODO rename WTT_RADIUS and WTT_HUBHEIGHT 
  ! Properties (coordinates, type) of all wind turbines
  ! on one MPI task. "MGPBLK_WT" and "MPROMA_WT" are the  
  ! i,j indices of each turbine in the NGPBLK and NPROMA dimensions
  REAL(KIND=JPRB),    ALLOCATABLE :: WT_LAT(:), WT_LON(:)
  INTEGER(KIND=JPIM), ALLOCATABLE :: MWT_TYPE(:), MGPBLK_WT(:), MPROMA_WT(:)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_HUBHEIGHT(:)   ! (m)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_RADIUS(:)      ! (m)
  INTEGER(KIND=JPIM) :: N_WT  ! number of turbines on this MPI task

  ! Same as above, but for all MPI tasks
  REAL(KIND=JPRB),    ALLOCATABLE :: WT_LAT_GLOB(:), WT_LON_GLOB(:)
  INTEGER(KIND=JPIM), ALLOCATABLE :: MWT_TYPE_GLOB(:)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_RADIUS_GLOB(:), WTT_HUBHEIGHT_GLOB(:)
  INTEGER(KIND=JPIM) :: N_WT_GLOB

  ! Characteristics of the individual wind turbine types
  INTEGER(KIND=JPIM)  :: N_WT_TYPES, MAX_WT_TYPE
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_CUTIN(:)       ! (m s-1)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_CUTOUT(:)      ! (m s-1)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_CT_CUTIN(:)    ! (m s-1)
  REAL(KIND=JPRB),    ALLOCATABLE :: WTT_CT_CUTOUT(:)   ! (m s-1)
  INTEGER(KIND=JPIM), ALLOCATABLE :: WTT_N_WSPEEDS(:)   ! 
  
  ! Tables with power production and thrust coefficient curves
  INTEGER(KIND=JPIM), ALLOCATABLE :: TYPE_LOOKUP(:)
  REAL(KIND=JPRB),    ALLOCATABLE :: TBL_WSPEED(:,:)  ! (m s-1)
  REAL(KIND=JPRB),    ALLOCATABLE :: TBL_CP(:,:)      ! (-)
  REAL(KIND=JPRB),    ALLOCATABLE :: TBL_CT(:,:)      ! (-)

  ! Max size of the user input tables for wind speed, cP, cT
  INTEGER(KIND=JPIM), PARAMETER :: N_MAX_WSPEEDS = 200

CONTAINS

SUBROUTINE WINDFARM (YDGEOMETRY, &
    & KBL, KST, KEND, NPROMA, NFLEVG, &
    & PHI0, PHIF0, POROG, PU , PV, PEZDIAG, PDT, &
    & PTENDU, PTENDV, PTENDTKE )

    ! TO DO documentation.. 

    USE PARKIND1, ONLY : JPIM,JPRB
    USE YOMHOOK,  ONLY : LHOOK,DR_HOOK
    USE YOMLUN ,  ONLY : NULOUT
    USE YOMCST,   ONLY : RPI, RG
    USE YOMFPD,   ONLY : RDELX, RDELY
    USE YOM_YGFL, ONLY : YGFL
    USE GEOMETRY_MOD , ONLY : GEOMETRY

    !  ----------------------------------------------------------------

    IMPLICIT NONE

    TYPE(GEOMETRY), INTENT(INOUT)    :: YDGEOMETRY
    INTEGER(KIND=JPIM), INTENT(IN)   :: KBL    ! Index in NGPBLEKS dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: KST    ! Start NPROMA dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: KEND   ! End NPROMA dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: NPROMA
    INTEGER(KIND=JPIM), INTENT(IN)   :: NFLEVG

    REAL(KIND=JPRB), INTENT(IN) :: PDT

    REAL(KIND=JPRB), INTENT(IN)  :: PHI0(NPROMA,0:NFLEVG)   ! Half level geop. height (m2/s2)
    REAL(KIND=JPRB), INTENT(IN)  :: PHIF0(NPROMA,NFLEVG)    ! Full level geop. height (m2/s2)
    REAL(KIND=JPRB), INTENT(IN)  :: POROG(NPROMA)           ! Orography (m2/s2)

    REAL(KIND=JPRB), INTENT(IN)  :: PU(NPROMA, NFLEVG)
    REAL(KIND=JPRB), INTENT(IN)  :: PV(NPROMA, NFLEVG)

    REAL(KIND=JPRB), INTENT(INOUT) :: PEZDIAG(NPROMA, NFLEVG, YGFL%NGFL_EZDIAG)

    REAL(KIND=JPRB), INTENT(INOUT) :: PTENDU  (NPROMA, NFLEVG)
    REAL(KIND=JPRB), INTENT(INOUT) :: PTENDV  (NPROMA, NFLEVG)
    REAL(KIND=JPRB), INTENT(INOUT) :: PTENDTKE(NPROMA, NFLEVG)

    INTEGER(KIND=JPIM), ALLOCATABLE :: JROF_BLK(:), JTYPE_BLK(:)
    REAL(KIND=JPRB), ALLOCATABLE :: RROF_BLK(:), HROF_BLK(:)

    REAL(KIND=JPRB) :: ZHOOK_HANDLE, ZU_INT, ZV_INT, ZU_HUB, ZU_ABS, &
                     & ZCP, ZCT, ZCTKE, ZA, ZFAC, ZDXDYI, ZPOWER1, ZPOWER2, &
                     & ZP_CORR, RADIUS, HUBHEIGHT
    INTEGER(KIND=JPIM) :: J, JROF, JLEV, I_WT
    INTEGER(KIND=JPIM) :: I_DIAG = 4  ! number of diagnostics in namelist
    
    CHARACTER(LEN=15) :: CI_WT ! wind turbine type to write on abort

    ! Wind turbine specifications are typically for a reference density
    REAL(KIND=JPRB), PARAMETER :: ZRHOREF = 1.23_JPRB
    
#include "abor1.intfb.h"

    !     ------------------------------------------------------------------
    IF (LHOOK) CALL DR_HOOK('WINDFARM', 0, ZHOOK_HANDLE)
    !     ------------------------------------------------------------------

    ! Reset instantaneous power production 
    PEZDIAG(:,1,I_DIAG) = 0._JPRB

    ! 
    !  Calculate wind farm drag tendencies U and V, and TKE production
    ! 
    
    JROF_BLK  = PACK(MPROMA_WT, MGPBLK_WT==KBL)
    JTYPE_BLK = PACK(MWT_TYPE,  MGPBLK_WT==KBL)
    RROF_BLK  = PACK(WTT_RADIUS, MGPBLK_WT==KBL)
    HROF_BLK  = PACK(WTT_HUBHEIGHT, MGPBLK_WT==KBL)


    ZDXDYI = 1._JPRB / (RDELX(1) * RDELY(1))
    
    IF (SIZE(JROF_BLK) > 0) THEN
        DO J=1,SIZE(JROF_BLK)
            ! short cuts
            JROF = JROF_BLK(J)
            I_WT = TYPE_LOOKUP(JTYPE_BLK(J))

            RADIUS = RROF_BLK(J)
            HUBHEIGHT = HROF_BLK(J)        

            ! ! should remove these limits and check input-files beforehand 
   
            IF ((RADIUS<1._JPRB).OR.(RADIUS>100._JPRB)) THEN
                WRITE(NULOUT,*) 'SOMETHING WRONG RADIUS', RADIUS,JROF,I_WT
                RADIUS = 50._JPRB
            ENDIF
            IF ((HUBHEIGHT<12._JPRB).OR.(HUBHEIGHT>300._JPRB)) THEN
                WRITE(NULOUT,*) 'SOMETHING WRONG HUBHEIGHT', HUBHEIGHT,JROF,I_WT
                HUBHEIGHT = 80._JPRB
            ENDIF


            ! 1. Find the absolute wind speed at hub height
            !
            DO JLEV=NFLEVG, 2, -1
                IF ( (PHIF0(JROF, JLEV)  -POROG(JROF))/RG <= HUBHEIGHT .AND. &  !
                   & (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG >  HUBHEIGHT ) EXIT   !
            END DO

            ZU_INT = INTERPOLATE( (PHIF0(JROF, JLEV)-POROG(JROF))/RG, (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG, &
            & HUBHEIGHT, PU(JROF, JLEV), PU(JROF, JLEV-1) )  !
            ZV_INT = INTERPOLATE( (PHIF0(JROF, JLEV)-POROG(JROF))/RG, (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG, &
            & HUBHEIGHT, PV(JROF, JLEV), PV(JROF, JLEV-1) )  !
            ZU_HUB = SQRT(ZU_INT**2_JPIM + ZV_INT**2_JPIM)


            !
            ! 2. Interpolate CP and CT to wind speed at hub height
            !

            CALL INTERPOLATE_CP_CT(ZCP, ZCT, ZU_HUB, I_WT)
            ZCTKE = ZCT - ZCP
            
            ! check if CTKE, CT and CP are realistic 
            IF (ZCTKE < 0._JPRB) THEN
               WRITE(CI_WT,"(I10)") I_WT
               CALL ABOR1('CP or CT incorrect for turbine '//CI_WT//'. Check input, CT < CP')
            END IF

            ! 
            ! 3. Calculate difference between power production based on the
            !    mean wind speed at hub-height ('ZPOWER1') and the vertical integral
            !    over the wind turbine ('ZPOWER2')
            !
            ZA = RPI * RADIUS**2_JPIM  !
            ZPOWER1 = 0.5_JPRB * ZRHOREF * ZU_HUB**3_JPIM * ZA * ZCP
            ZPOWER2 = 0._JPRB

            ! Store instantaneous and accumulated powerproduction (in MW)
            PEZDIAG(JROF,1,I_DIAG) = PEZDIAG(JROF,1,I_DIAG) + (ZPOWER1 * 1.E-6_JPRB)
            PEZDIAG(JROF,2,I_DIAG) = PEZDIAG(JROF,2,I_DIAG) + (ZPOWER1 * 1.E-6_JPRB) * PDT

            DO JLEV=NFLEVG, 1, -1
                ! stop above wind turbine 
                IF ((PHI0(JROF, JLEV)-POROG(JROF))/RG >= HUBHEIGHT + RADIUS) EXIT !

                ! calculate turbine area 
                ZA = TURBINE_AREA((PHI0(JROF, JLEV)-POROG(JROF))/RG, (PHI0(JROF, JLEV-1)-POROG(JROF))/RG, &
                       & HUBHEIGHT, RADIUS)  !

                ! calculate power production
                ZU_ABS = SQRT(PU(JROF, JLEV)**2 + PV(JROF, JLEV)**2)
                ZPOWER2 = ZPOWER2 + 0.5_JPRB * ZRHOREF * ZU_ABS**3_JPIM * ZA * ZCP
            ENDDO

            ! calculate correction factor 
            IF (ZPOWER1 > 0._JPRB .AND. ZPOWER2 > 0._JPRB) THEN
                ZP_CORR = ZPOWER1 / ZPOWER2
            ELSE
                ZP_CORR = 1._JPRB
            ENDIF


            ! 
            ! 4. Calculate tendencies
            ! 
            DO JLEV=NFLEVG, 1, -1
                ! Stop above wind turbine
                IF ((PHI0(JROF, JLEV)-POROG(JROF))/RG >= HUBHEIGHT + RADIUS) EXIT !

                ! calculate turbine area
                ZA = TURBINE_AREA((PHI0(JROF, JLEV)-POROG(JROF))/RG, (PHI0(JROF, JLEV-1)-POROG(JROF))/RG, &
                       & HUBHEIGHT, RADIUS) !
                ! Calculate drag tendencies and TKE production
                ZU_ABS = SQRT(PU(JROF, JLEV)**2 + PV(JROF, JLEV)**2)
                ZFAC   = 0.5_JPRB * ZU_ABS * ZA * ZDXDYI / ((PHI0(JROF, JLEV-1) - PHI0(JROF, JLEV))/RG)

                PTENDU(JROF, JLEV)   = PTENDU(JROF, JLEV)   - ZFAC * ZCT   * PU(JROF, JLEV) * ZP_CORR
                PTENDV(JROF, JLEV)   = PTENDV(JROF, JLEV)   - ZFAC * ZCT   * PV(JROF, JLEV) * ZP_CORR
                PTENDTKE(JROF, JLEV) = PTENDTKE(JROF, JLEV) + ZFAC * ZCTKE * ZU_ABS**2_JPIM * ZP_CORR
            END DO
        END DO
        
    END IF

    IF (ALLOCATED(JROF_BLK)) DEALLOCATE(JROF_BLK)
!    IF (ALLOCATED(HROF_BLK)) DEALLOCATE(HROF_BLK)
!    IF (ALLOCATED(RROF_BLK)) DEALLOCATE(RROF_BLK)

    !!CALL EXIT_WINDFARM

    !     ------------------------------------------------------------------
    IF (LHOOK) CALL DR_HOOK('WINDFARM', 1, ZHOOK_HANDLE)

END SUBROUTINE WINDFARM


SUBROUTINE WINDFARM_EWP (YDGEOMETRY, &
    & KBL, KST, KEND, NPROMA, NFLEVG, &
    & PHI0, PHIF0, POROG, PU , PV, PEZDIAG, PDT, PLENGTH_M, PTKE, &
    & PTENDU, PTENDV)

    ! TO DO documentation.. 

    USE PARKIND1, ONLY : JPIM,JPRB
    USE YOMHOOK,  ONLY : LHOOK,DR_HOOK
    USE YOMLUN ,  ONLY : NULOUT
    USE YOMCST,   ONLY : RPI, RG
    USE YOMFPD,   ONLY : RDELX, RDELY
    USE YOM_YGFL, ONLY : YGFL
    USE GEOMETRY_MOD , ONLY : GEOMETRY

    !  ----------------------------------------------------------------

    IMPLICIT NONE

    TYPE(GEOMETRY), INTENT(INOUT)    :: YDGEOMETRY
    INTEGER(KIND=JPIM), INTENT(IN)   :: KBL    ! Index in NGPBLEKS dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: KST    ! Start NPROMA dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: KEND   ! End NPROMA dimension
    INTEGER(KIND=JPIM), INTENT(IN)   :: NPROMA
    INTEGER(KIND=JPIM), INTENT(IN)   :: NFLEVG

    REAL(KIND=JPRB), INTENT(IN) :: PDT

    REAL(KIND=JPRB), INTENT(IN)  :: PHI0(NPROMA,0:NFLEVG)   ! Half level geop. height (m2/s2)
    REAL(KIND=JPRB), INTENT(IN)  :: PHIF0(NPROMA,NFLEVG)    ! Full level geop. height (m2/s2)
    REAL(KIND=JPRB), INTENT(IN)  :: POROG(NPROMA)           ! Orography (m2/s2)

    REAL(KIND=JPRB), INTENT(IN)  :: PU(NPROMA, NFLEVG)
    REAL(KIND=JPRB), INTENT(IN)  :: PV(NPROMA, NFLEVG)

    ! Inputs to derive KM (exchange coefficient for momentum [m^2/s])
    ! KM = SM*l*(ui'*ui')^(1/2)
    REAL(KIND=JPRB), INTENT(IN)  :: PLENGTH_M(NPROMA,1,NFLEVG) 
    REAL(KIND=JPRB), INTENT(IN)  :: PTKE(NPROMA, NFLEVG)

    REAL(KIND=JPRB), INTENT(INOUT) :: PEZDIAG(NPROMA, NFLEVG, YGFL%NGFL_EZDIAG)

    REAL(KIND=JPRB), INTENT(INOUT) :: PTENDU  (NPROMA, NFLEVG)
    REAL(KIND=JPRB), INTENT(INOUT) :: PTENDV  (NPROMA, NFLEVG)

    INTEGER(KIND=JPIM), ALLOCATABLE :: JROF_BLK(:), JTYPE_BLK(:)
    REAL(KIND=JPRB), ALLOCATABLE :: RROF_BLK(:), HROF_BLK(:)

    REAL(KIND=JPRB) :: ZHOOK_HANDLE, ZU_INT, ZV_INT, ZU_HUB, ZU_ABS, &
                     & ZCP, ZCT, ZA, ZFAC, ZDXDYI, ZPOWER1, ZPOWER2, &
                     & ZP_CORR, RADIUS, HUBHEIGHT,ZPHI,ZKM_HUB,ZKM1_HUB
    REAL(KIND=JPRB) :: ZINITZ !Initial length scale sigma_0 in Volker et al 2015
    REAL(KIND=JPRB) :: ZEFFECTZ !Effective length scale sigma_e in Volker et al 2015
    REAL(KIND=JPRB) :: ZEFFECTU !Effective velocity deficit profile u_e in Volker et al 2015
    REAL(KIND=JPRB) :: ZDEPTH ! Horizontal grid cell size
    REAL(KIND=JPRB) :: ZL ! Horizontal half grid spacing, since turbines are assumed in the center
    REAL(KIND=JPRB) :: ZXI ! Gaussian wake
    REAL(KIND=JPRB) :: ZTC ! Height dependent thrust 
    INTEGER(KIND=JPIM) :: J, JROF, JLEV, I_WT, JLEV1
    INTEGER(KIND=JPIM) :: I_DIAG = 4  ! number of diagnostics in namelist
    
    CHARACTER(LEN=15) :: CI_WT ! wind turbine type to write on abort

    ! Wind turbine specifications are typically for a reference density
    REAL(KIND=JPRB), PARAMETER :: ZRHOREF = 1.23_JPRB
    ! For minimal turbulence diffusion coefficient for momentum
    REAL(KIND=JPRB), PARAMETER :: ZKMMIN  = 0.1_JPRB
    REAL(KIND=JPRB), PARAMETER :: ZEPS    = 1e-3
    ! Factor of initial wake expansion relative to turbine radius
    ! TODO: should become an input parameter
    REAL(KIND=JPRB), PARAMETER :: ZRADIUSFRAC = 1.7
    !
    REAL(KIND=JPRB) :: ZKM1  (NPROMA, NFLEVG)
    
#include "abor1.intfb.h"

    !     ------------------------------------------------------------------
    IF (LHOOK) CALL DR_HOOK('WINDFARM_EWP', 0, ZHOOK_HANDLE)
    !     ------------------------------------------------------------------

    ! Reset instantaneous power production 
    PEZDIAG(:,1,I_DIAG) = 0._JPRB

    ! 
    !  Calculate wind farm drag tendencies U and V
    ! 
    
    JROF_BLK  = PACK(MPROMA_WT, MGPBLK_WT==KBL)
    JTYPE_BLK = PACK(MWT_TYPE,  MGPBLK_WT==KBL)
    RROF_BLK  = PACK(WTT_RADIUS, MGPBLK_WT==KBL)
    HROF_BLK  = PACK(WTT_HUBHEIGHT, MGPBLK_WT==KBL)

    ZDXDYI = 1._JPRB / (RDELX(1) * RDELY(1))

    ZKM1 = PLENGTH_M(:,1,:) * SQRT(2 * PTKE)
    
    IF (SIZE(JROF_BLK) > 0) THEN
        DO J=1,SIZE(JROF_BLK)
            ! short cuts
            JROF = JROF_BLK(J)
            I_WT = TYPE_LOOKUP(JTYPE_BLK(J))

            RADIUS = RROF_BLK(J)
            HUBHEIGHT = HROF_BLK(J)
            ZINITZ = ZRADIUSFRAC * RADIUS  
            IF ((RDELX(1) .GT. 2._JPRB * RDELY(1)) .OR. (RDELY(1) .GT. 2._JPRB * RDELX(1)) ) THEN
                !WRITE(CI_WT,"(I10)") RDELX(1)
                CALL ABOR1('Horizontal resolution is not the same in x and y. EWP might not work properly.')
            ENDIF
            ZDEPTH = RDELX(1)!TODO: This needs to be adjusted, if cells ar not square
            ZL = 0.5_JPRB * RDELX(1) !TODO: This needs to be adjusted, if cells ar not square

            !
            ! 1. Find the absolute wind speed at hub height
            !
            DO JLEV=NFLEVG, 2, -1
                IF ( (PHIF0(JROF, JLEV)  -POROG(JROF))/RG <= HUBHEIGHT .AND. &  !
                   & (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG >  HUBHEIGHT ) EXIT   !
            END DO

            ZU_INT = INTERPOLATE_LOG( (PHIF0(JROF, JLEV)-POROG(JROF))/RG, (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG, &
            & HUBHEIGHT, PU(JROF, JLEV), PU(JROF, JLEV-1) )  !
            ZV_INT = INTERPOLATE_LOG( (PHIF0(JROF, JLEV)-POROG(JROF))/RG, (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG, &
            & HUBHEIGHT, PV(JROF, JLEV), PV(JROF, JLEV-1) )  !
            ZU_HUB = SQRT(ZU_INT**2_JPIM + ZV_INT**2_JPIM)

            ! 1a. Find turbulence diffusion coefficient for momentum (Km) at hub height
            ZKM_HUB = INTERPOLATE_LOG( (PHI0(JROF, JLEV)-POROG(JROF))/RG, (PHIF0(JROF, JLEV-1)-POROG(JROF))/RG, &
            & HUBHEIGHT, ZKM1(JROF, JLEV), ZKM1(JROF, JLEV-1) )  !

            !
            ! 2. Interpolate CP and CT to wind speed at hub height
            !
            CALL INTERPOLATE_CP_CT(ZCP, ZCT, ZU_HUB, I_WT)

            ! 
            ! 3. Calculate power production based on the mean wind speed 
            !    at hub-height ('ZPOWER1')
            !
            ZA = RPI * RADIUS**2_JPIM  !
            ZPOWER1 = 0.5_JPRB * ZRHOREF * ZU_HUB**3_JPIM * ZA * ZCP

            ! Store instantaneous and accumulated powerproduction (in MW)
            PEZDIAG(JROF,1,I_DIAG) = PEZDIAG(JROF,1,I_DIAG) + (ZPOWER1 * 1.E-6_JPRB)
            PEZDIAG(JROF,2,I_DIAG) = PEZDIAG(JROF,2,I_DIAG) + (ZPOWER1 * 1.E-6_JPRB) * PDT

            ! 
            ! 4. Calculate tendencies
            !    Turbine wakes are defined around hub height and the EWP 
            !    uses the wind speed and turbulence diffusion at this height 
            !    to determine the grid-cell averaged wake extension in the 
            !    vertical direction. Therefore, the grid-cell averaged 
            !    velocity deficit is not necessarily bounded to the turbine's 
            !    blade. 
            ! 
            ZFAC = 2_JPRB * MAX(ZKM_HUB,ZKMMIN) / MAX(ZU_HUB,ZEPS)

            !Eq. (12) (uses fact in denominater therefore looks slightly different)
            ZEFFECTZ = 2._JPRB/3._JPRB * &
                    & ( (ZFAC*ZL + ZINITZ**2_JPIM)**(3._JPRB/2._JPRB) - ZINITZ**3_JPIM) / (ZFAC*ZL)

            !refers to Eq. (11) which was not a wind speed. Here it is:
            ZEFFECTU = ZCT * SQRT(RPI) * RADIUS**2_JPIM * ZU_HUB      & 
                    &            / (SQRT(8._JPRB) * ZEFFECTZ * ZDEPTH)

            DO JLEV=NFLEVG, 1, -1
                !gaussian wake similar to Eq.6, but with grid-cell averaged ZEFFECTZ
                ZXI = EXP(-0.5_JPRB * ( ( ((PHI0(JROF, JLEV)-POROG(JROF))/RG) - HUBHEIGHT) / ZEFFECTZ)**2_JPIM)

                !Prepare Eq. 14 and 15 
                !With ZDXDYI it is assumed that only one turbine is present per cell
                ZTC = - ZDXDYI * ZU_HUB * ZEFFECTU * ZXI * ZDEPTH

                ! Calculate wind direction
                ZPHI = ATAN2(PV(JROF, JLEV),PU(JROF, JLEV)) + 2_JPRB * RPI
                ZPHI = MOD(ZPHI,2_JPIM * RPI)

                PTENDU(JROF, JLEV)   = PTENDU(JROF, JLEV)   + COS(ZPHI) * ZTC
                PTENDV(JROF, JLEV)   = PTENDV(JROF, JLEV)   + SIN(ZPHI) * ZTC
             END DO
        END DO
        
    END IF

    IF (ALLOCATED(JROF_BLK)) DEALLOCATE(JROF_BLK)
!    IF (ALLOCATED(HROF_BLK)) DEALLOCATE(HROF_BLK)
!    IF (ALLOCATED(RROF_BLK)) DEALLOCATE(RROF_BLK)

    !!CALL EXIT_WINDFARM

    !     ------------------------------------------------------------------
    IF (LHOOK) CALL DR_HOOK('WINDFARM_EWP', 1, ZHOOK_HANDLE)

END SUBROUTINE WINDFARM_EWP

SUBROUTINE INTERPOLATE_CP_CT(PCP, PCT, PU_HUB, K_WT)
    !
    ! Interpolate the power and thrust curves onto the 
    ! requested wind speed, accounting for the cutin
    ! and cutout wind speeds of the wind turbine
    !
    IMPLICIT NONE

    REAL(KIND=JPRB), INTENT(OUT)   :: PCP, PCT
    REAL(KIND=JPRB), INTENT(IN)    :: PU_HUB
    INTEGER(KIND=JPIM), INTENT(IN) :: K_WT

    INTEGER(KIND=JPIM) :: I

    IF (PU_HUB < WTT_CUTIN(K_WT)) THEN
        PCP = 0.0_JPRB
        PCT = WTT_CT_CUTIN(K_WT)
    ELSE IF (PU_HUB >= WTT_CUTOUT(K_WT)) THEN
        PCP = 0.0_JPRB
        PCT = WTT_CT_CUTOUT(K_WT)
    ELSE
        DO I=1, WTT_N_WSPEEDS(K_WT)
            IF (TBL_WSPEED(I,K_WT) <= PU_HUB .AND. TBL_WSPEED(I+1,K_WT) > PU_HUB) EXIT
        END DO

        PCP = INTERPOLATE(TBL_WSPEED(I,K_WT), TBL_WSPEED(I+1,K_WT), PU_HUB, TBL_CP(I,K_WT), TBL_CP(I+1,K_WT))
        PCT = INTERPOLATE(TBL_WSPEED(I,K_WT), TBL_WSPEED(I+1,K_WT), PU_HUB, TBL_CT(I,K_WT), TBL_CT(I+1,K_WT))
    END IF

END SUBROUTINE INTERPOLATE_CP_CT

 
PURE FUNCTION SEGMENT_AREA(PR, PDZ) RESULT(ZA)
    !
    ! calculate area of circle segment
    !
    IMPLICIT NONE
    REAL(KIND=JPRB), INTENT(IN) :: PR, PDZ
    REAL(KIND=JPRB) :: ZTHETA, ZA

    ZTHETA = 2._JPRB*ACOS(PDZ/PR)
    ZA = 0.5_JPRB * PR**2_JPIM * (ZTHETA - SIN(ZTHETA))

END FUNCTION


PURE FUNCTION TURBINE_AREA(PZ1, PZ2, PZHUB, PR) RESULT(ZA)
    !
    ! Calculate turbine area height 'PZ1' and 'PZ2' 
    ! Given hub-height ('PZHUB') and radius('PR')
    !
    USE YOMCST, ONLY : RPI

    IMPLICIT NONE
    REAL(KIND=JPRB), INTENT(IN) :: PZ1, PZ2, PZHUB, PR
    REAL(KIND=JPRB) :: ZA, Z_LOW, Z_HIGH

    ! TOP AND BOTTOM OF TURBINE BLADES
    Z_LOW  = PZHUB - PR
    Z_HIGH = PZHUB + PR

    IF (PZ2 <= Z_LOW .OR. PZ1 >= Z_HIGH) THEN
        ZA = 0._JPRB
    ELSE IF (PZ2 >= Z_HIGH .AND. PZ1 <= Z_LOW) THEN
        ! FULL TURBINE WITHIN CURRENT GRID LEVEL
        ZA = RPI * PR**2_JPIM
    ELSE IF (PZ1 > Z_LOW .AND. PZ2 < Z_HIGH) THEN
        ! FULL TURBINE MINUS TOP AND BOTTOM SEGMENT
        ZA = RPI * PR**2_JPIM - SEGMENT_AREA(PR, PZ2-PZHUB) - SEGMENT_AREA(PR, PZHUB-PZ1)
    ELSE IF (PZ1 > Z_LOW .AND. PZ2 >= Z_HIGH) THEN
        ! TOP SEGMENT
        ZA = SEGMENT_AREA(PR, PZ1-PZHUB)
    ELSE IF (PZ2 < Z_HIGH .AND. PZ1 <= Z_LOW) THEN
        ! BOTTOM SEGMENT
        ZA = SEGMENT_AREA(PR, PZHUB-PZ2)
    END IF

END FUNCTION


PURE FUNCTION INTERPOLATE(PX1, PX2, PXG, PV1, PV2) RESULT(PVI)
    !
    ! Linear interpolation of values 'PV1' and 'PV2'
    ! at locations locations 'PX1' and 'PX2' to value 'PVI' at location 'PXG'
    !
    IMPLICIT NONE
    REAL(KIND=JPRB), INTENT(IN) :: PX1, PX2, PXG, PV1, PV2
    REAL(KIND=JPRB) :: ZFAC, PVI

    ZFAC = (PX2 - PXG) / (PX2 - PX1)
    PVI  = ZFAC*PV1 + (1._JPRB-ZFAC)*PV2

END FUNCTION

PURE FUNCTION INTERPOLATE_LOG(PX1, PX2, PXG, PV1, PV2) RESULT(PVI)
    !
    ! Linear interpolation of values 'PV1' and 'PV2'
    ! at locations locations 'PX1' and 'PX2' to value 'PVI' at location 'PXG'
    !
    IMPLICIT NONE
    REAL(KIND=JPRB), INTENT(IN) :: PX1, PX2, PXG, PV1, PV2
    REAL(KIND=JPRB) :: ZFAC, PVI

    ZFAC = (log(PXG) - log(PX2)) / (log(PX1) - log(PX2))
    PVI  = PV2 + (PV1 - PV2) * ZFAC

END FUNCTION


SUBROUTINE EXIT_WINDFARM
    IMPLICIT NONE

    DEALLOCATE( WT_LAT, WT_LON, MWT_TYPE )
    !DEALLOCATE( TAB_WSPEED, TAB_POWER, TAB_THRUST )

END SUBROUTINE EXIT_WINDFARM

END MODULE WINDFARM_MOD
