MODULE YOMPHY

USE PARKIND1  ,ONLY : JPIM

IMPLICIT NONE

SAVE

! Values that NPHY can obtain:
INTEGER(KIND=JPIM), PARAMETER  ::    JPHYEC =   1  ! for ECMWF physics
INTEGER(KIND=JPIM), PARAMETER  ::    JPHYMF =   2  ! for MF physics
INTEGER(KIND=JPIM), PARAMETER  ::   JPHYARO =   3  ! budget package initially introduced for AROME physics
INTEGER(KIND=JPIM), PARAMETER  ::   JPBP002 =   4  ! budget package initially introduced for ALARO physics

TYPE TPHY
!*
!     ------------------------------------------------------------------

!     VARIABLES DE CONTROLE DE LA PHYSIQUE :

! * GROUPE DES CLES GENERALES.
!        LMPHYS  : CLE GENERALE POUR LES PARAMETRISATIONS METEO-FRANCE.
!                : GLOBAL SWITCH FOR METEO-FRANCE PACKAGE.
!        LREASUR : TRUE, ON LIT LES CHAMPS DE SURFACE.
!                : TRUE, SURFACE FIELDS ARE READ.

! * GROUPE DES CLES NE COMMANDANT PAS L'APPEL AUX ROUTINES AM-----.
!        LCAPE   : CLE ACTIVANT LA FERMETURE EN CAPE SI LCVRA.
!                : KEY ACTIVATING THE CAPE CLOSURE IF LCVRA.
!        LCVGQD  : CLE ACTIVANT LA FERMETURE EN CVGQ DYNAMIQUE.
!                : KEY ACTIVATING THE DYNAMICAL CVGQ CLOSURE.
!        LCVGQM  : CLE ACTIVANT LA MODULATION DE LA FERMETURE CVGQ.
!                : KEY ACTIVATING THE MODULATION OF THE CVGQ CLOSURE.
!        LCVGQP  : CLE ACTIVANT L'UTILISATION DE CVGQ POSITIVES UNIQUEMENT.
!                : KEY ACTIVATING THE USE OF POSITIVE CVGQ ONLY.
!        LCONDWT : CLE ACTIVANT l'EAU LIQUIDE.
!                : KEY ACTIVATING LIQUID WATER.
!        LCVCAS  : CLE ACTIVANT LE CALCUL DES SEGMENTS CONVECTIFS ACTIFS.
!                : KEY ACTIVATING CONVECTIVE ACTIVE SEGMENTS COMPUTATION.
!        LSCMF   : CLE ACTIVANT LE CALCUL DE FRACTIONS MAILLE SIGNIFICATIVES
!                  KEY ACTIVATING SIGNIFICANT MESH FRACTIONS.
!        LCVDD   : CLE ACTIVANT LE CALCUL DES DOWNDRAFTS.
!                : KEY FOR DOWNDRAFT COMPUTATIONS.
!        LCVLIS  : LORS DU TRAITEMENT PAR LA CONVECTION
!                  DES FLUX DIFFUSIFS TURBULENTS SECS,
!                  CLE ACTIVANT LE TRAITEMENT CONSISTANT DE S ET Q.
!                : KEY TO COMPUTE CONSISTENTLY FOR S AND Q
!                  CONVECTION AND DRY TURBULENT PROCESSES INTERACTION.
!        LCVPGY  : CLE ACTIVANT LES CALCULS DE CONVECTION PROFONDE GY.
!                : KEY ACTIVATING GY CONVECTION CALCULATIONS.
!        LCVPP   : CLE ACTIVANT LES CALCULS DE CONVECTION PEU PROFONDE.
!                : KEY ACTIVATING SHALLOW-CONVECTION CALCULATIONS.
!        LCVPPKF : KEY ACTIVATING THE KFB SCHEME (SHALLOW-CONVECTION).
!        LEDKF   : KEY ACTIVATING THE EDKF SCHEME (SHALLOW-CONVECTION).
!        LEDMFI  : KEY ACTIVATING CONJOINT IMPLICIT FORMULATION FOR EDDY DIFUSIVITY AND MASS FLUX
!        LEDMFS  : KEY ACTIVATING SPLIT OF ED AND MF FLUX IN THE CASE LEDMFI=.T.
!        LCVGQKF : KEY FOR ADDING THE KFB (OR EDKF) IN THE MOISTURE CONVERGENCE.
!        LDIFCEXP: CLE ACTIVANT LA DIFFUSION EXPLICITE DES VARIABLES CONSERVATIVES.
!                : KEY ACTIVATING EXPLICIT VERTICAL DIFFUSION ON CONSERVATIVE VARIABLES.
!       LDIFCONS : CLE ACTIVANT LA DIFFUSION DES VARIABLES CONSERVATIVES.
!                : KEY ACTIVATING VERTICAL DIFFUSION ON CONSERVATIVE VARIABLES.
!        LFLUSO  : CLE ACTIVANT LES FLUX DE SURFACE OCEANIQUES "ECUME"
!                : KEY ACTIVATING SEA SURFACE EXCHANGE COEFFICIENTS "ECUME"
!        LECT    : CLE ACTIVANT LA DIFFUSION ECT.
!                : KEY ACTIVATING TKE DIFFUSION. (default : false)
!        NLEND   : CLE DE CHOIX DES LONGUEURS DE MELANGE POUR LE SCHEMA ECT
!                : CHOICE OF MIXING LENGTH USE IN TKE SCHEME
!        LEFB    : CLE ACTIVANT LE SCHEMA EFB
!                : KEY ACTIVATING LFB SCHEME  (default : false)
!        LECTFL  : CLE POUR PASSER LA TKE SUR LES FULL-LEVEL.
!                : KEY ACTIVATING THE TKE ON FULL-LEVEL.
!        LECTFL0 : CLE POUR AVOIR UNE DIFFUSION DE TKE NULLE EN SURFACE.
!                : KEY ACTIVATING FOR NO DIFFUSIION OF TKE AT THE SURFACE.
!        LECTQ1  : CLE ACTIVANT LA LIMITATION SUR Q1 DANS ACTURB.
!                : KEY ACTIVATING Q1 LIMITATION IN ACTURB.  (default : true)
!        LECTREP : CLE ACTIVANT LA REPRODUCTABILITE DE LA TKE DANS ACTURB.
!                : KEY ACTIVATING TKE REPRODUCTABILITY IN ACTURB. (default : false)
!        LPTKE   : CLE ACTIVANT LA DIFFUSION ECT PSEUDO PROGNOSTIQUE.
!                : KEY ACTIVATING PSEUDO PROGNOSTIC TKE DIFFUSION.
!        LCOEFKTKE   : KEY ACTIVATING eTKE SCHEME
!        LCOEFK_THS1  :   .FALSE. - 'moist' Ri computed after GELEYN 1987 - Ri*
!                     :  .TRUE. - 'moist' Ri* changed by P. Marquet's  pot. temperature
!        LCOEFK_RIS   :   Ri* or Ri** for SCC, .FALSE. - external SCC
!        LCOEFK_RIH   :   "HYBRID" Ri COMPUTATION.
!        LCOEFK_TOMS  : ACTIVATES TOMS COMPUTATION 
!        LCOEFK_PL    : PROGNOSTIC MIX. LENGTH
!        LCOEFK_ML    : 'MOIST' MIX. LENGTH
!        LCOEFK_PTTE  : PROGNOSTIC TTE
!        LCOEFK_SCQ   : Q^=C^F(Cn) in BVF(SCC,Q^)
!        LCOEFKSURF   : TOUCANS also on surface
!        LCOEFK_MSC   : MF approach for SCC diagnostics
!        LCOEFK_F1    : TOUCANS f(Ri)=1 on surface
!        CGTURS  : MNEMONIC DEFINING THE KIND OF TURBULENT SCHEME: CBR,MD1,MD2,QNSE,EFB
!        LAFGD_A : AF SCHEME FOR TURB. EXCHANGE COEF. IN FREE ATMOSPHERE
!        LPBLE   : CLE POUR ENTRAINEMENT AU SOMMET DE COUCHE LIMITE (IF LECT).
!                  KEY ACTIVATING THE PBL TOP-ENTRAINMENT RATE.
!        LFPCOR  : CLE POUR UTILISATION DU FLUX DE PRECIP. CONVECTIF LISSE POUR !                  LA NEBUL.
!                : KEY FOR THE USE OF A SMOOTH FLUX OF CONVECTIVE RAIN FOR THE
!                  CLOUD COVER.
!        LNEBNXR : CLE ACTIVANT LE CALCUL DE NEBULOSITE XU/RANDALL.
!                : KEY FOR USING XU/RANDALL CLOUDINESS FORMULATION.
!        LNEBECT : CLE ACTIVANT LES FONCTIONS DE F0,F1,F2 POUR LECT=T
!                : KEY FOR USING F0,F1,F2 FUNCTION FOR TKE SCHEME.
!        LNEB_FP : KEY FOR PROGNOSTIC CLOUDINESS (RESOLVED AND CONVECTION).
!        LHUCN   : CLE ACTIVANT LE NOUVEAU CALCUL D'HUMIDITE CRITIQUE.
!                : KEY FOR USING NEW FORMULATION OF CRITICAL HUMIDITY.
!        LMLH    : Nouvelle longueur de melange dans ACNEBR (Lenderink & Holtslag))
!        LNODIFQC: Desactivation de la reprojection des flux des variables
!                 "conservatifs humides" vers les variables "seches
!                  +eaux_condensees"a la fin de ACDIFUS (si LDIFCONS)
!        LQXRTGH : CLE ACTIVANT LE CALCUL DE LA COURBE TANGENT HYPERBOLIQUE
!                  DE RH DANS LE SCHEMA DE NEBULOSITE XU/RANDALL.
!                : KEY FOR USING TANGENS HYPERBOLIC FUNCTION OF RH PROFILE
!                  IN THE XU/RANDALL CLOUDINESS FORMULATION.
!        LNEIGE  : CLE POUR LA PRISE EN COMPTE DU CYCLE CRYOSCOPIQUE.
!                : KEY FOR THE CRYOSCOPIC CYCLE (PHYSICS AND THERMODS.).
!        LRNUMX  : CLE ACTIVANT LE RECOUVREMENT NUAGEUX MAX. EN RAYONMT.
!                : KEY FOR MAX. OVERLAP OF ADJACENT RADIATIVE CLOUDS.
!        LRNUEXP : KEY FOR EXPONENTIAL-RANDOM OVERLAP OF ADJACENT CLOUDS.
!        LRTRUEBBC: KEY FOR USING TRUE (NOT DELTA-SCALED) DIRECT
!                   SOLAR FLUX IN BOTTOM BOUNDARY CONDITION.
!        LRTRUEDIR: KEY FOR RETURNING TRUE (NOT DELTA-SCALED) DIRECT
!                   SOLAR FLUX.
!        LACPANMX: CLE ACTIVANT LE RECOUVREMENT NUAGEUX DANS ACNPART.
!                : KEY ACTIVATING NEAR MAXIMUM CLOUD OVERLAP IN ACNPART.
!        LCLSATUR: CLE ACTIVANT LA DEPENDANCE SUR LA SATURATION DE LA GLACE
!                  ET L'EAU LIQUIDE DANS LE NUAGE.
!                : KEY FOR DEPENDENCY ON IWC/LWC SATURATION.
!        LVOIGT  : CLE ACTIVANT L'EFFET DE VOIGT DANS ACRANEB
!                  KEY FOR VOIGT EFFECT IN ACRANEB.
!        LGLACIERS: CLE MODIFIANT L'INERTIE THERMIQUE DES GLACIERS
!                  KEY CHANGING SOIL INERTIA FOR ICE CAP
!        LVFULL  : CLE ACTIVANT LE CALCUL COMPLET D'EFFET VOIGT (PLUS CHER)
!                  KEY FOR COMPREHENSIVE COMPUTATION OF VOIGT EFFECT
!        LRRGUST : CLE ACTIVANT L'INFLUENCE DES "RAFALES HUMIDES" DANS LE
!                : CALCUL DES COEFFICIENTS TURBULENTS.
!                : KEY ACTIVATING "MOIST GUSTINESS" INFLUENCE IN TURBULENT
!                : COEFFICIENTS COMPUTATION.
!        LSLC    : CLE ACTIVANT LA CONVECTION EN PENTE
!                : KEY FOR SLANTWISE CONVECTION
!        LNOIAS  : CLE COUPANT LA CONVECTION POUR DE L INSTABILITE ABSOLUE SECHE.
!                : STOP CONVECTION IN THE CASE OF DRY ABSOLUT INSTABILITY.
!        LRAYLU  : CLE D'APPEL DU RAYONNEMENT LUNAIRE.
!                : KEY FOR CALLING THE MOON RADIATION.
!                  (IN ACRANEB ).
!        LREWS   : CLE D'APPEL DE L'OPTION ECHANGE AVEC LA SURFACE
!                : KEY FOR CALLING THE ECHANGE WITH SURFACE OPTION
!                  (IN ACRANEB)
!        LRPROX  : CLE D'APPEL DE L'OPTION D'ECHANGE INTER-NIVEAU APPROCHE

!        LRMIX   : ACTIVATION DU CALCUL DE ZMIX (SEE JFG POUR PLUS DE PRECISION)
!                  EPAISSEUR OPTIQUE QQ PART ENTRE MIN ET MAX (ZMIX=0 OU 1)
!                  (POUR LES ECHANGES INTER-NIVEAUX)
!        LRSTAB  : STABILISATION
!        LRSTAER : KEY TO USE STANDARD AEROSOLS (IN ACRANEB)
!        LRTPP   : SI .T. L'ECHANGE ENTRE COUCHES ADJACENTES TIENT COMPTE DU
!                  PROFIL CONTINU DE "T"
!                  IF .T. EXCHANGE TERMS BETWEEN ADJACENT LAYERS USE A
!                  CONTINUOUS "T" PROFILE
!        LRTDL   : SI .T. LES CALCULS D'ECHANGE ENTRE COUCHES ADJACENTES
!                  NE SONT PLUS LINEARISES
!                  IF .T. EXCHANGE TERMS BETWEEN ADJACENT LAYERS ARE TREATED
!                  FULLY NONLINEARLY
!        LRAYPL  : CLE DE RECHERCHE DES PLAGES JOUR/NUIT.
!                : KEY TO LOOK FOR DAY/NIGHT AREAS.
!                  (IN ACRANEB ).
!        LO3ABC  : CLE D'ACTIVATION DES PROFILES D'OZONE CLIMATOLOGIQUES
!                  KEY TO USE CLIMATOLOGICAL PROFILES FOR OZONE
!        LO3FL   : CLE D'ACTIVATION OZONE CLIMATOLOGIQUE (FORTUIN LANGEMATZ)
!                  KEY TO USE CLIMATOLOGICAL OZONE (FORTUIN LANGEMATZ)
!        LECSHAL : CLE D'ACTIVATION DE LA MODIFICATION DE LONGUEUR DE MELANGE DANS LES NUAGES SHALLOW
!                : KEY TO MODIFIE MIXING LENGTH INSIDE SHALLOW CLOUD
!        LECDEEP : CLE D'ACTIVATION DE LA MODIFICATION DE LONGUEUR DE MELANGE DANS LES NUAGES DEEP
!                : KEY TO MODIFIE MIXING LENGTH INSIDE DEEP CLOUD
!                : KEY TO MODIFIE MIXING LENGTH INSIDE SHALLOW CLOUD
!        LGLT    : CLE ACTIVANT L'UTILISATION DU VENT GEOSTROPHIQUE PLUTOT
!                  QUE LE VENT REEL DANS LE CALCUL DU LIFT
!                : KEY FOR USING GEOSTROPHIC WIND IN PLACE OF REAL WIND
!                  IN THE LIFT COMPUTATION
!        LNEWD   : CLE D'APPEL DE MODIFICATIONS RECENTES DANS LE G.W.D.
!                : KEY FOR CALLING NEW MODIFICATIONS IN THE G.W.D.
!        LPROCLD : KEY FOR CALLING PROGNOSTIC CLOUD PARAMETRIZATION
!        LENTCH  : KEY FOR PROGNOSTIC ENTRAINEMENT
!        LCDDEVPRO : KEY TO MODULATE THE PRECIPITATION COOLING CONTRIB.TO DD.TEMP.PROFILE
!        LEVAPP  : KEY FOR ACTIVATING PRECIPITATION EVAPORATION
!        LCOLLEC : KEY FOR ACTIVATING COLLECTION OF CLOUD CONDENSATE
!                  BY PRECIPITATION
!        LADJCLD : KEY FOR CALLING SMITH'S ADUJSTMENT AFTER DIFFUSION.
!        LAB12   : KEY FOR ACTIVATING MORE REALISTIC RAIN DROP SIZE DISTRIBUTION (Abel&Boutle 2012).
!        LSEDSTA : MICROPHYSICS: STATISTICAL SEDIMENTATION.
!        LSEDLAG : MICROPHYSICS: LAGRANGIAN SEDIMENTATION.
!        LFSVAR  : MICROPHYSICS: VARIABLE FALL SPEED.
!        LFSFIX  : MICROPHYSICS: FIXED FALL SPEED.
!        LSEDCL  : MICROPHYSICS: SEDIMENTATION OF CLOUD WATER AND ICE.
!        LA0MPS  : MICROPHYSICS: ALARO-0 PROCESSES.
!        LARPMPS : MICROPHYSICS: ARPEGE PROCESSES.
!        LAEROSEA: KEY TO USE SEA AEROSOLS
!        LAEROLAN: KEY TO USE LAND AEROSOLS
!        LAEROSOO: KEY TO USE SOOT (?) AEROSOLS
!        LAERODES: KEY TO USE DESERT AEROSOLS
!        LAEROVOL: KEY TO USE VOLCANOES AEROSOLS
!        LAEROSUL: KEY TO USE SULFATES AEROSOLS
!        LRELAXT : KEY TO USE TEMPERATURE RELAXATION
!        LRELAXW : KEY TO USE WATER CONTENT RELAXATION

!        LSSD    : KEY ACTIVATING STATISTICAL SEDIMENTATION
!        LZ0HSREL: CLE ACTIVANT L'UTILISATION DE Z0 THERMIQUE SANS RELIEF
!                  KEY TO USE THERMAL ROUGHNESS LENGTH WITHOUT OROGRAPHY
!        L3MT    : CLE ACTIVANT LE SCHEMA 3MT
!                : KEY FOR THE 3MT SCHEME
!        LGPCMT   : KEY FOR USING THE "PROGNOSTIC CONDENSATES MICROPHYSICS AND TRANSPORT" CONVECTION SCHEME
!        LNCVPGY : CLE ACTIVANT LES NUAGES CONVECTIFS D'ACCVIMPGY
!                : KEY FOR USING CONVECTIVE CLOUDS FROM ACCVIMPGY
!        LSQRML  : CLE ACTIVANT LA LONGUEUR DE MELANCE EN RACINE CARRE
!                : KEY FOR USING THE SQUARE ROOT MIXING LENGTH

! * GROUPE DES CLES COMMANDANT L'APPEL AUX ROUTINES AM-----.
!       CGMIXLEN : MNEMONIQUE PERMETTANT DE CHOISIR LE TYPE DE CALCUL DE LONGUEUR DE MELANGE.
!                : MNEMONIC DEFINING THE KIND OF TURBULENT MIXING LENGTH COMPUTATION.
!        LPRGML  : CLE ACTIVANT LA LONGUEUR PRONOSTIQUE DE MELANGE.
!                : KEY FOR PROGNOSTIC MIXING LENGTH.
!        LCVRA   : CLE D'APPEL DE LA CONVECTION PROFONDE.
!                : KEY FOR CALLING DEEP CONVECTION.
!                  ( ACCVIMP ).
!        LDAYD   : CLE D'APPEL DE LA DUREE DU JOUR FONCTION DE Z.
!                : KEY OF DAY DURATION DEPENDING ON Z.
!        LCVPRO  : CLE D'APPEL DE LA CONVECTION PRONOSTIQUE.
!                  KEY FOR CALLING PROGNOSTIC CONVECTION.
!                  ( ACCVUD  ).
!---------------------------
! * CSD UPDRAUGHT SCHEME:
!        LCVCSD  : CLE D'APPEL DE LA CONVECTION PRONOSTIQUE CSD
!                : KEY FOR CALLING PROGNOSTIC CONVECTION CSD(COMPLEMENTARY
!                  SUBGRID (UP)DRAFT)
!                  LCVCSD=.T. =>  ACCSU ; LCVCSD=.F.=>  ACCVUD
!        LCVSHCU : CLE POUR AUTORISER LES CUMULUS PEU PROFONDS DANS ACCSU
!                : KEY FOR ALLOWING SHALLOW UPDRAFTS IN ACCSU
!        LPEC    : : CLE ACTIVANT LE CALCUL DE PEC AU LIEU DE CAPE
!                  DANS LA FERMETURE CAPE.
!                : KEY FOR COMPUTING PEC (POTENTIAL ENERGY CONVERTIBILITY)
!                  INSTEAD OF CAPE IN A CAPE CLOSURE.
!        LCVGQ   : CLE ACTIVANT LA FERMETURE EN CVGQ
!                : KEY ACTIVATING THE CVGQ CLOSURE.
!        LUDEVOL : CLE POUR UTILSER UNE EQUATION PROGNOSTQUE POUR LA VITESSE
!                  VERTICALE DE L'UPDRAFT DANS LE SCHEMA CSU
!                : KEY FOR ACTIVATING PROGNOSTIC VERTICAL VELOCITY IN CSU SCHEME
!        LUSL    : CLE ACTIVANT LE DECLENCHEMENT DE LA CONVECTION DANS LA 
!                  COUCHE SOURCE DE  L'UPDRAFT DANS LE SCHEMA CSU
!                : KEY ACTIVATING THE UPDRAFT SOURCE LAYER TRIGERING ( WITH
!                  LCVCSD=.T.)
!--------------------------
!        LCDDPRO : CLE D'APPEL DU DOWNDRAFT PRONOSTIQUE.
!                  KEY FOR CALLING PROGNOSTIC DOWNDRAFT.
!                  ( ACMODO  ).
!        LNSDO   : CLE D'APPEL DU DOWNDRAFT PRONOSTIQUE NONSATURE
!                : KEY FOR CALLING PROGNOSTIC NONSATURATED DOWNDRAFT
!                  LNSDO=.T. => ACNSDO; LNSDO=.F. => ACMODO
!        LCDDCSD : CLE D'APPEL DU DOWNDRAFT NON SATURE COMPLEMENTAIRE
!                  SOUS-MAILLE
!                  (AVEC LCDDPRO=.T. et LNSDO-.T.)
!                  KEY FOR CALLING THE NON SATURATED COMPLEMENTARY SUBGRID
!                  DOWNDRAFT
!        LGWD    : CLE D'APPEL DU "GRAVITY WAVE DRAG".
!                : KEY FOR CALLING THE "GRAVITY WAVE DRAG".
!                  ( ACDRAG ).
!        LGWDC   : CLE D'APPEL DU "GRAVITY WAVE DRAG" CONVECTIF.
!                : KEY FOR CALLING THE CONVECTIVE "GRAVITY WAVE DRAG".
!                  ( ACDRAC ).
!        LHMTO   : CLE D'APPEL DES CALCULS AUX HAUTEURS METEO.
!                : KEY FOR INTERPOLATIONS AT SCREEN AND "WIND" HEIGHTS.
!                  ( ACHMT ).
!        LNEBCO  : CLE D'APPEL DE LA NEBULOSITE CONVECTIVE.
!                : KEY FOR SWITCHING ON THE USE OF CONV. CLOUDINESS.
!                  ( ACNEBC ).
!        LNEBN   : CLE D'APPEL DE LA NEBULOSITE "STRA + PREC. CONVECTIVES"
!                : KEY FOR CALLING THE "STRATIFORM + CONV. PRECIP" CLOUDINESS SCHEME.
!                  ( ACNEBN ).
!        LNEBR   : CLE D'APPEL DU SCHEMA STAT. DE GENERATION DES NUAGES.
!                : KEY FOR CALLING THE STAT. SCHEME FOR CLOUDINESS.
!                  ( ACNEBR ).
!        LOZONE  : CLE D'APPEL A LA PHYSIQUE DE L'OZONE.
!                : KEY FOR CALLING THE OZONE'S PHYSICS.
!                  ( ACOZONE ).
!        LRAY    : CLE D'APPEL DU RAYONNEMENT EMERAUDE/PERIDOT.
!                : KEY FOR CALLING THE EMERAUDE/PERIDOT RAD. SCHEME.
!                  ( ACRANEB ).
!        LRAYFM  : CLE D'APPEL DU RAYONNEMENT FMR CEPMMT (PHYSIQUE M-F)
!                : KEY FOR CALLING ECMWF FMR RAD. SCHEME IN M-F PHYSICS
!                  ( RADINT ).
!        LRMU0M  : CLE DE CALCUL DU  MU0M
!                : KEY FOR MU0M FORMULATION
!        NCALLRAD: Meteo-France control (ARPEGE and AROME) of call to radiation scheme
!                  at first and last time step
!                  NCALLRAD=0 <== Default, no control (as previously)
!                  NCALLRAD=1 <== No call if LCALLSFX=.FALSE. (diagnostic time step)  (not yet)
!                  NCALLRAD=2 <== No call at last time step (NSTEP=NSTOP)
!                  NCALLRAD=3 <== (1) AND (2)                                         (not yet)
!        LRAYFM15: CLE D'APPEL DU RAYONNEMENT FMR CEPMMT (PHYSIQUE M-F)
!                : KEY FOR CALLING ECMWF FMR RAD. SCHEME IN M-F PHYSICS
!                : VERSION GELEE - FROZEN VERSION - PhD 96/11 ~CYCLE 15
!                  ( RADINT15 ).
!        LRRMES  : CLE D'APPEL AU DRAG MESOSPHERIQUE "NEWTONIEN".
!                  KEY FOR CALLING THE MESOSPHERIC NEWTONIAN DRAG.
!                  ( ACDRME ).
!        LSFHYD  : CLE D'APPEL DU BILAN HYDRIQUE DU SOL "HYPER-SIMPL.".
!                : KEY FOR HYPER-SIMPLIFIED SOIL HYDROLOGY.
!                  ( ACDRO ).
!        LSNV    : CLE D'APPEL DU NOUVEAU SCHEMA DE NEIGE.
!                : KEY FOR THE NEW SNOW SCHEME.
!                  ( ACHMT,ACSOL,ACDROV,ACVEG ).
!        LSOLV   : CLE D'APPEL DE LA NOUVELLE PHYS. DU SOL (VEGET.).
!                : KEY FOR NOILHAN-PLANTON SOIL AND VEGETATION SCHEME.
!                  ( ACSOL,ACDROV,ACVEG ).
!        LFGEL   : CLE D'APPEL DU GEL DE L'EAU DU SOL AVEC ISBA (LSOLV)
!                : KEY FOR SOIL FREEZING WITH ISBA (LSOLV)
!                  ( ACSOL, ACDROV)
!        LVGSN   : CLE POUR COMBINER VEGETATION ET NEIGE
!                : KEY FOR COMBINING VEGETATION AND SNOW
!                  ( ACHMT,ACSOL,ACDROV,ACVEG ).
!        LSTRA   : CLE D'APPEL DES PLUIES STRATIFORMES "CLASSIQUES".
!                  KEY FOR CLASSICAL STRATIFORM PRECIPITATIONS.
!                  ( ACPLUIE ).
!        LSTRAS  : CLE D'APPEL DU SCHEMA DE STAT. DE PRECIPITATION
!                : KEY FOR CALLING THE STAT. SCHEME FOR PRECIPITATION.
!                  ( ACPLUIS ).
!       LSTRAPRO : KEY FOR CALLING ACPLUIE_PROG
!        LTHERMO : CLE D'APPEL DES CALCULS THERMODYNAMIQUES.
!                  KEY FOR CALLING MOIST THERMODYNAMIC CALCULATIONS.
!                  ( ACTQSAT ).
!        LVDIF   : CLE D'APPEL DE LA DIFFUSION VERTICALE "CLASSIQUE".
!                  KEY FOR CALLING THE VERTICAL TURBULENT EXCHANGE.
!                  ( ACHMT,ACCOEFK,ACDIFUS ).
!        LBLVAR  : KEY FOR CALLING SPECIFIC 2M OBS OPERATOR FROM
!                  LAST LEVEL (USED FOR VARPACK)
!        LPBLE   : Top PBL Entrainment
!       LPHCDPI  : Common dynamisc physics interfase is used if it is TRUE
!        LCAMOD  : KEY FOR SCALING RTCAPE IN FUNCTION OF GRID SPACING
!        LCOMOD  : KEY FOR SCALING MOISTURE CONVERGENCE WITH GRID SPACING
!       LPHSPSH  : KEY FOR PSEUDO HISTORIC SURFACE PRECIP SENSIBLE HEAT
!       LSMNIMBT : NO ICE MELTING BELOW TRIPLE POINT TEMPERATURE (ACNEBCOND)
!       LSMTPS   : TRIPLE POINT SMOOTHING (ACNEBCOND)
!       LSMGCDEV : SMITH-GERARD CONDENSATION/EVAPORATION SCHEME
!       LXRCDEV  : XU-RANDALL STYLE OF CONDENSATION/EVAPORATION SCHEME
!       LRKCDEV  : RASCH-KRISTJANSSON CONDENSATION/EVAPORATION SCHEME
!       LSMITH_CDEV : SMITH CONDENSATION/EVAPORATION SCHEME
!       LRCVOTT  : PROTECTION OF THE CLEAR-SKY CONVECTIVE RAIN AGAINST EVAP.
!       LNEBCV   : PROTECTION OF THE CONVECTIVE CLOUD IN ADJUSTMENT.
!       LNEBINS  : 3MT: CONVECTIVE CLOUDINESS INSTANTANEOUS VALUE OTHERWISE 
!                  WITH TIME RELAXATION.
!       LACDIFUS : USE OLD ACDIFUS INSTEAD OF NEW ACDIFV1/ACDIFV2
!       LHLRADUPD: (TEMPORARY SWITCH) USE RADIATION UPDATES BY HIRLAM 2016
!       LWINDFARM : ENABLE WIND FARM PARAMETERISATION
!       NWINDFARM : ENABLED TYPE OF WIND FARM PARAMETERISATION
!       NDIFFNEB : OPTION FOR USE OF CLOUDINESS IN ACDIFUS (LDIFCONS):
!                  0: zero value
!                  1: one uses the cloudiness from the cond./evap. scheme
!                  2: one uses the total "radiative" cloudiness (ACNEBN)
!                  3: one uses the total "moist" cloudiness
!       NIMELIT  : OPTION TO INCLUDE MELTING/FREEZING EFFECT TO PROGNOSTIC
!                  UPDRAUGHT:
!                  1: no effect
!                  > 1: number of iterations to include the effect.
!       NRAY      : VERSION OF ACRANEB (LRAY=.T.)
!                     1 - UNMODULARIZED
!                     2 - MODULARIZED, NEW GASEOUS TRANSMISSIONS,
!                         LINEARIZED T_e DEPENDENCY, INTERMITTENCY
!       NSORAYFR  : CALL FREQUENCY OF GASEOUS TRANSMISSIONS IN SOLAR BAND:
!                     NSORAYFR > 0 => timesteps
!                     NSORAYFR < 0 => hours
!       NTHRAYFR  : CALL FREQUENCY OF GASEOUS TRANSMISSIONS IN THERMAL BAND:
!                     NTHRAYFR > 0 => timesteps
!                     NTHRAYFR < 0 => hours
!       NRAUTOEV  : FREQUENCY OF EXACT COMPUTATION OF NON-STATISTICAL WEIGHTS
!                   FOR BRACKETING:
!                     NRAUTOEV = 0 => none
!                     NRAUTOEV = 1 => at every full radiation timestep
!                     NRAUTOEV > 1 => at every n-th full radiation timestep
!       NCLOMIX: FORMULATION OF MIXED CLOSURE (1,2,3,4)
!       NFSIG   : VERTICAL VARIATION OF UPDRAUGHT MESH FRACTION
!       CGTRG   : CHOICE OF TRIGGERING METHOD

! * GROUPE DES INDICES DE CALCUL.
!        NBITER : NOMBRE D'ITERATIONS DANS LES BOUCLES DE NEWTON.
!               : NUMBER OF ITERATIONS IN THE NEWTON LOOPS.
!       NITERFL : NOMBRE D'ITERATIONS DANS LE SCHEMA "ECUME"
!               : NUMBER OF ITERATIONS IN "ECUME" SCHEME
!        NDPSFI : INDICATEUR BINAIRE : NDPSFI=1 SI LES VARIATIONS DE LA
!                 MASSE DE L'ATMOSPHERE DUES AU CYCLE HYDROLOGIQUE SONT
!                 MODELISEES, NDPSFI=0 SINON.
!               : BINARY INDICATOR : NDPSFI=1 IF THE VARIATION OF THE
!                 ATMOSPHERIC MASS DUE TO THE HYDROLOGICAL CYCLE HAVE TO
!                 BE TAKEN INTO ACCOUNT, NDPSFI=0 OTHERWISE.
!        NPHYREP: REPRODUCTIBILITE DES CALCULS PHYSIQUES EN MODE MULTI-PROCESSEURS:
!                   1 REPRODUCTIBILITE ASSUREE DANS TOUTE LA PHYSIQUE.
!                   0 REPRODUCTIBILITE NON ASSUREE.
!                  -1 REPRODUCTIBILITE ASSUREE PARTOUT SAUF ACCVIMP ET ACCVIMPD.
!                  -2 REPRODUCTIBILITE ASSUREE PARTOUT SAUF ACDRAG.
!                  -3 REPRODUCTIBILITE ASSUREE PARTOUT SAUF ACPLUI.
!                  -4 REPRODUCTIBILITE ASSUREE PARTOUT SAUF ACRANEB.
!               : REPRODUCTIBILITY OF PHYSICAL COMPUTATIONS IN MULTI-PROCESSORS MODE:
!                   1 REPRODUCTIBILITY ENSURED IN THE WHOLE PHYSICS.
!                   0 REPRODUCTIBILITY NOT ENSURED.
!                  -1 REPRODUCTIBILITY ENSURED EXCEPT IN ACCVIMP ET ACCVIMPD.
!                  OTHER ITEMS: SEE ABOVE THE FRENCH PART OF THE DOC.!...
!        NOIR   : ECLIPSE OU NON? (SOLEIL NOIR!)
!                 NOIR=1 ECLIPSE DU 11.8.1999.
!                 NOIR=0 PAS D'ECLIPSE.
!                 NOIR=-999 ECLIPSE TOUS LES JOURS!... (POUR TESTS D'IMPACT).

!   NPHY :  Number indicating the kind of physics, for DDH

!       NSMTBOT : Temperature to use for qsat at the bottom (acsmi1)
!                     0=interpolate Ts and T_L
!                     1=use T_L
!       NSMDNEB : Cloudiness gradient attenuation mode (acsmi1)
!                     0= no action
!                     1=smoothing
!                     2=gradient limitation with RSMDNEBX
!       NPRAC   : 1 to activate accretion in ACPREC
!       NPRRI   : 1 to activate riming in ACPREC

! * GROUPE DES CLES COMMANDANT L'APPEL AUX ROUTINES AM-----.
!       LNEBGR  : Schema de Turb/(N,RR)stra de Herve GRENIER  (ACNEBGR)
!       LNEBGY  : Schema de Turb/(N,RR)stra de J.F. GUEREMY   (ACNEBGY)
!       LCVRAV3 : Schema de convect. profonde Bougeault-V3 (ACCVIMP_V3)
!       L2MICRO : Switch for 2 micro-physics

! * GROUPE DES INDICES DE CALCUL.
INTEGER(KIND=JPIM) :: NBITER
INTEGER(KIND=JPIM) :: NITERFL
INTEGER(KIND=JPIM) :: NDPSFI
! * GROUPE DES CLES GENERALES.
LOGICAL :: LMPHYS
LOGICAL :: LREASUR
! * GROUPE DES CLES NE COMMANDANT PAS L'APPEL AUX ROUTINES AM-----.
LOGICAL :: LCAPE
LOGICAL :: LCVGQD
LOGICAL :: LCVGQM
LOGICAL :: LCVGQP
LOGICAL :: LCONDWT
LOGICAL :: LCVDD
LOGICAL :: LCVPGY
LOGICAL :: LCVPP
LOGICAL :: LDIFCEXP
LOGICAL :: LDIFCONS
LOGICAL :: LNEIGE
LOGICAL :: LRNUMX
LOGICAL :: LRNUEXP
LOGICAL :: LRTRUEBBC
LOGICAL :: LRTRUEDIR
LOGICAL :: LACPANMX
LOGICAL :: LCLSATUR
LOGICAL :: LVOIGT
LOGICAL :: LGLACIERS
LOGICAL :: LVFULL
LOGICAL :: LSLC
LOGICAL :: LRAYLU
LOGICAL :: LREWS
LOGICAL :: LRPROX
LOGICAL :: LRMIX
LOGICAL :: LRSTAB
LOGICAL :: LRSTAER
LOGICAL :: LRTPP
LOGICAL :: LRTDL
LOGICAL :: LRAYPL
LOGICAL :: LRRGUST
LOGICAL :: LO3ABC
LOGICAL :: LO3FL
LOGICAL :: LECSHAL
LOGICAL :: LECDEEP
LOGICAL :: LNEBNXR
LOGICAL :: LNEB_FP
LOGICAL :: LQXRTGH
LOGICAL :: LHUCN
LOGICAL :: LFPCOR
LOGICAL :: LNOIAS
LOGICAL :: LGLT
LOGICAL :: LNEWD
LOGICAL :: LPROCLD
LOGICAL :: LEVAPP
LOGICAL :: LCOLLEC
LOGICAL :: LADJCLD
LOGICAL :: LSEDSTA
LOGICAL :: LSEDLAG
LOGICAL :: LSEDCL
LOGICAL :: LFSVAR
LOGICAL :: LFSFIX
LOGICAL :: LA0MPS
LOGICAL :: LARPMPS
LOGICAL :: L3MT
LOGICAL :: LGPCMT
LOGICAL :: LENTCH
LOGICAL :: LCDDEVPRO
LOGICAL :: LAEROSEA
LOGICAL :: LAEROLAN
LOGICAL :: LAEROSOO
LOGICAL :: LAERODES
LOGICAL :: LAEROVOL
LOGICAL :: LAEROSUL
LOGICAL :: LRELAXT
LOGICAL :: LRELAXW
LOGICAL :: LSSD
LOGICAL :: LPBLE
LOGICAL :: LBLVAR
LOGICAL :: LZ0HSREL
LOGICAL :: LMLH
LOGICAL :: LNODIFQC
LOGICAL :: LNCVPGY
LOGICAL :: LSQRML
LOGICAL :: LAB12
LOGICAL :: LCVSHCU
LOGICAL :: LCVGQ
LOGICAL :: LPEC
LOGICAL :: LUDEVOL
LOGICAL :: LCDDCSD
INTEGER(KIND=JPIM) :: NCLOMIX
INTEGER(KIND=JPIM) :: NFSIG
LOGICAL :: LHLRADUPD
LOGICAL :: LWINDFARM
INTEGER(KIND=JPIM) :: NWINDFARM


! * GROUPE DES CLES COMMANDANT L'APPEL AUX ROUTINES AM-----.
CHARACTER (LEN = 20) ::  CGMIXLEN
CHARACTER (LEN = 20) ::  CGTURS
CHARACTER (LEN = 20) ::  CGTRG
LOGICAL :: LPRGML
LOGICAL :: LCVRA
LOGICAL :: LDAYD
LOGICAL :: LCVPRO
LOGICAL :: LCDDPRO
LOGICAL :: LCVCSD
LOGICAL :: LUSL
LOGICAL :: LNSDO
LOGICAL :: LECT
LOGICAL :: LEFB
LOGICAL :: LFLUSO
LOGICAL :: LECTQ1
LOGICAL :: LECTREP
LOGICAL :: LPTKE
LOGICAL :: LCOEFKTKE
LOGICAL :: LCOEFKSURF
LOGICAL :: LCOEFK_MSC
LOGICAL :: LCOEFK_F1
LOGICAL :: LCOEFK_TOMS
LOGICAL :: LCOEFK_THS1
LOGICAL :: LCOEFK_RIS
LOGICAL :: LCOEFK_RIH
LOGICAL :: LCOEFK_PL
LOGICAL :: LCOEFK_ML
LOGICAL :: LCOEFK_PTTE
LOGICAL :: LCOEFK_FLX
LOGICAL :: LCOEFK_SCQ
LOGICAL :: LAFGD_A
LOGICAL :: LGWD
LOGICAL :: LGWDC
LOGICAL :: LHMTO
LOGICAL :: LNEBCO
LOGICAL :: LNEBN
LOGICAL :: LNEBR
LOGICAL :: LOZONE
LOGICAL :: LRAY
LOGICAL :: LRAYFM
LOGICAL :: LRMU0M
LOGICAL :: LRAYFM15
LOGICAL :: LRRMES
LOGICAL :: LSFHYD
LOGICAL :: LSNV
LOGICAL :: LSOLV
LOGICAL :: LFGEL
LOGICAL :: LSTRA
LOGICAL :: LSTRAS
LOGICAL :: LSTRAPRO
LOGICAL :: LNEWSTAT
LOGICAL :: LTHERMO
LOGICAL :: LVDIF
LOGICAL :: LCVLIS
LOGICAL :: LCVCAS
LOGICAL :: LSCMF
LOGICAL :: LVGSN
LOGICAL :: LPHCDPI
LOGICAL :: LNEBGR
LOGICAL :: LNEBGY
LOGICAL :: LCVRAV3
LOGICAL :: LCVPPKF
LOGICAL :: LEDKF
LOGICAL :: LEDMFI
LOGICAL :: LEDMFS 
LOGICAL :: LECTFL
LOGICAL :: LECTFL0
INTEGER(KIND=JPIM) :: NPHYREP
INTEGER(KIND=JPIM) :: NOIR
LOGICAL :: LCAMOD
LOGICAL :: LCOMOD
LOGICAL :: LPHSPSH
LOGICAL :: LSMNIMBT
LOGICAL :: LSMTPS
LOGICAL :: LSMGCDEV
LOGICAL :: LXRCDEV
LOGICAL :: LRKCDEV
LOGICAL :: LSMITH_CDEV
LOGICAL :: LRCVOTT
LOGICAL :: LNEBCV
LOGICAL :: LNEBINS
INTEGER (KIND=JPIM) :: NDIFFNEB
INTEGER (KIND=JPIM) :: NIMELIT
INTEGER (KIND=JPIM) :: NRAY
INTEGER (KIND=JPIM) :: NSORAYFR
INTEGER (KIND=JPIM) :: NTHRAYFR
INTEGER (KIND=JPIM) :: NRAUTOEV
INTEGER (KIND=JPIM) :: NSMTBOT
INTEGER (KIND=JPIM) :: NSMDNEB
INTEGER (KIND=JPIM) :: NPRAC, NPRRI
INTEGER (KIND=JPIM) :: NPHY
INTEGER (KIND=JPIM) :: NCALLRAD
INTEGER (KIND=JPIM) :: NLEND  
INTEGER (KIND=JPIM) :: NTEND_DIAG_POS
INTEGER (KIND=JPIM) :: NTEND_DIAG_FREQ_RESET
LOGICAL :: LNEBECT
LOGICAL :: LCVGQKF
LOGICAL :: LACDIFUS
LOGICAL :: L2MICRO
!       LAJUCV  : CLE D'APPEL DE L'AJUSTEMENT CONVECTIF SEC
!                  KEY FOR CALLING THE DRY CONVECTIVE ADJUSTMENT.
!                  ( ACAJUCV ).
LOGICAL :: LAJUCV

LOGICAL :: LSMOOTHMELT
LOGICAL :: LGCHECKMV ! activates the CHECK of Model Variables.
LOGICAL :: LEDR ! key to activate EDR (3D) diagnostic

END TYPE TPHY

TYPE(TPHY), POINTER :: YRPHY => NULL()


!     ------------------------------------------------------------------
END MODULE YOMPHY
