SUBROUTINE SU0PHY(KULOUT)

!**** *SU0PHY*   - Initialize common YOxPHY controlling physics

!     Purpose.
!     --------
!           Initialize YOxPHY, the common that includes the
!           basic switches for the physics of the model.

!**   Interface.
!     ----------
!        *CALL* *SU0PHY(...) from SU0YOMA

!        Explicit arguments :
!        --------------------
!        KULOUT : Logical unit for the output

!        Implicit arguments :
!        --------------------

!     Method.
!     -------
!        See documentation

!     Externals.
!     ----------

!     Reference.
!     ----------
!        ECMWF Research Department documentation of the IFS

!        or

!        Documentation ARPEGE (depending on which physics will be used)

!     Author.
!     -------
!      J.-J. Morcrette                    *ECMWF*
!      J.-F. Geleyn for the ARPEGE rewriting.
!      Original : 91-11-12

!     Modifications.
!     --------------
!      Modified by F. Bouyssel  : 2001-03-03 LRRMESSP
!      Modified by J.M. Piriou  : 2001-11-27 LSRCONT
!      Modified by J.M. Piriou  : 2002-11-15 LNEBNXR
!      Modified by F. Bouyssel  : 2002-06-25 LCVPPLIS and LRRGUST
!      R. El Khatib : 2001-08-07 Pruning options
!      P. Marquet  : 02-02-14 YOMPHY
!      P. Marquet  : 02-06-18 LBCCOND (Becht/Chab ACCOND)
!      P. Marquet  : 02-08-30 LCVRAV3    (old ACCVIMP_V3)
!      J.M. Piriou  : 2002-01-10 set default values to operational ones.
!      Modified by A.Beljaars   : 2002-11-12 LECURR (Ocean current)
!      Modified by Y. Bouteloup : 2002-03-05 LO3ABC
!      Modified 08-2002 C. Smith : use "w" as prognostic variable in the
!       semi-lag advection of vertical divergence in the NH model.
!      Modified by F. Bouyssel  : 2002-12-18 Cleaning of LCVPPLIS
!      Modified by E. Bazile      : 2003-02-13 LFPCOR
!      Modified by E. Bazile      : 2003-02-18 LNOIAS
!      Modified by M. Janiskova : 2003-05 set-up for ECMWF stat.cloud scheme
!      M.Hamrud      01-Oct-2003 CY28 Cleaning
!      P. Viterbo   ECMWF   03-12-2004  Include user-defined RTHRFRTI
!      Modified by Y Seity      : 2004-11-16 For AROME setup, default values
!          for namarphy keys,read namarphy, switch off arp/ald physics keys
!      Modified by R. Brozkova : 2004-11 modifs for Xu-Randall cloud. scheme
!      P. Marquet and F. Bouyssel : 2004-08-18 (Lopez)
!      G. Hello : 2005-04-25 Lground initialization (surfex and arome)
!      Y. Seity : 2005-09-25 LRDUST, LORILAM and LUSECHEM initialisation for AROME
!      T. Kovacic : 2006-03-17 LPHCDPI, NPHY, LBUFLUX; for DDH and BUDGET
!      Modified by F. Bouyssel  : 2005-01-25 Change default of LNSMLIS
!      D.Salmond     22-Nov-2005 Mods for coarser/finer physics
!      P. Lopez      14-02-2006  Added switch LTRACLNPH for including
!                                tracers in linearized physics
!      R.Brozkova : pre ALARO 0 modset: mixing lengths computation
!      Modified by GMGEC/EAC   : 2006-03 list of modif.
!                   and new cloud model : 2006-03-03
!      Modified by E. Bazile    : 2006-04-11 Add LPBLE in case of LECT
!      Modified by E. Bazile    : 2006-04-20 Add LADJCLD,LCVPPKF, LECTFL
!      JF. Gueremy : LZ0HSREL initialised (used in ACHMT)
!      Modified by F. Bouyssel  : 2006-10-30 Add LAUTONEB, LSSD
!      Modified by F. Vana     : 2006-01-30 LPTKE
!      Modifed by D. Banciu    : 2006-08-31 LND2DIFF
!      M. Bellus : 28-Sep-2006 ALARO-0 phasing: L3MT,LCVPRO,LCDDPRO,LSCMF,
!                  LVOIGT,LVFULL,LPIL,LPHSPSH,LSMROT,LSMNIMBT,LSMTPS,
!                  L1DRHCRI,LGWRHCRI,NSMTBOT,NSMDNEB,NPRAG,NPRAC,NPRRI,
!                  LSTRAPRO,LNEWSTAT ; removed duplicity in LPBLE
!      JJMorcrette 20060721 MODIS albedo
!      G. Balsamo  20070115 New Hydrology (Van Genuchten+Orog. runoff)
!      M. Drusch   20070925 Wave model re-initialization
!      R. Brozkova: 20070219   : Cleaning cond./evap. switches.
!      E. Bazile :  20070510   : New logical LNEBECT, LEDMF
!      Modified by A.Alias : 2007/03 LMLH/LNODIFQC added
!                              P. Marquet : ACNEBR,ACDIFUS
!      R. El Khatib: 31-Aug-2007 Initialise uninitialised variable
!      Modified by P. Tulet    : add LRCO2
!      E. Bazile : 20080221    : New logical LCVGQKF
!      Y. Seity: 10-02-2008 Put LSOLV and LFGEL T for AROME Assim with LAROME T
!      S. Malardel : Feb 2008 add switch for MFSHAL in NAMARPHY/YOMARPHY
!      F. Bouyssel : Mars 2008 add LACDIFUS
!      Modified by A.Alias : 2008/04 Printing LZ0HSREL added
!      F. Bouyssel : May 2008 add LFLUSO, LFLCHCE, LFLWEG, NITERFL
!      F. Bouyssel : June 2008 add LO3FL
!      Y. Bouteloup : Juil 2008 add LECSHAL and LECDEEP
!      F. Bouyssel : Sept 2008 remove LFLCHCE, LFLWEG
!      F. Bouyssel : Oct 2008 removal of abort linked with ozone
!      D. Banciu   : Oct 2008 Additional checking for LENTCH
!      M. Janiskova: 2008-05-01 switches for new TL/AD lw radiation
!      S. Boussetta/G.Balsamo May 2009 Add variable LAI
!      C. Wittmann : 2009-03 add LACPANMX
!      E. Bazile   : July 2009 Switch for 2 microphysics
!      JF. Gueremy  : Aug 2009 New logical LNCVPGY,LDIFCEP,LSQRML
!      M. Leutbecher: 20081009 clipping of humidity at initial time (LECLIP*T0 )
!      I. Bastak Duran, F. Vana : 12-Oct-2009 p/eTKE switches update
!      K. Yessad (Jan 2010): remove useless variables.
!      I. Bastak Duran, F. Vana : 22-Feb-2011 TOUCANS switches update
!      P. Marguinaud : 29-Jun-2010 Add KSURFEXCTL flag (disable SURFEX surface scheme)
!      S. Boussetta/G.Balsamo Nov 2010 Add CTESSEL and RLAIINT
!      Y. Bouteloup  : 4-jan-2011 Add LEDKF
!      A. Alias  (Feb 2011) : test on LSFXLSM and LMSE use
!      M. Mokhtari (Feb 2011): add the key LMDUST
!      I. Bastak Duran, F. Vana : 15-Mar-2011 TOUCANS switches update
!      F. Bouyssel : Dec 2010 Modification of LADJCLD default
!      Y. Bouteloup : Feb 2011 add LRMU0M
!      Y. Boutelooup 01/04/2001 : NCALLRAD no call to radiation scheme at last time step
!      O.Riviere June 2011: New options for MF simplified physics
!      N.Semane+P.Bechtold 04-10-2012 LREASUR RESET TO .TRUE. FOR LAQUA
!      JF. Gueremy : Nov 2011 Dry Conv. Adj. (LAJUCV)
!      R. El Khatib : 01-Mar-2012 LFPSPEC => NFPOS
!      I. Bastak Duran, F. Vana : 26-Jan-2012 : LCOEFK_RIM for Ri_moist/Ri_s1
!      R. Brozkova 02/2012      : options for microphysics and cloudiness.
!      R. El Khatib : 26-Jul-2012 NFPOS==927 replaced by NFPOS/10==92
!      JJMorcrette 20110726 AEROU9
!      E. Bazile 12/2012      : LGLACIERS for soil inertia of ice cap.
!      F. Vana  15-Mar-2013  Removed NEPHYS_PCFULL, fix for lin. phys used in c001.
!      2013-11, J. Masek: Introduction of ACRANEB2 scheme.
!      Y. Bouteloup 28-11-2013 LEFB for EFB parameterization
!      Y. Bouteloup (January 2014) : change initialization of LEDKFI from .TRUE. to .FALSE.
!      M. Janiskova : May 2013 Set-up for ECMWF simplified surface scheme
!      K. Yessad (July 2013): move YOMRCOEF setup in SU0PHY (formerly in SUDIM2).
!      T. Wilhelmsson and K. Yessad (Oct 2013) Geometry and setup refactoring.
!      JJMorcrette 20130709 AEROU17
!      F. Vana & M. Kharoutdinov 09-Feb-2015: Setup for super-parametrization scheme.
!      A. Agusti-Panareda   09-08-2013  Add LBFASCO2 flag for GPP/REC flux adjustment
!      R. El Khatib 24-Apr-2015 Reset LRAY=.FALSE. if the atmosphere is
!      adiabatic => enable the surface to be unconditionally initialized.
!      L. Gerard (Mar 2016) non saturated downdraft, CSD updraft+ triggering, 
!                           LCOMOD/LCAMOD replace GCOMOD of yomphy0
!      J. Masek, Apr-2016: Exponential-random overlap and true direct flux
!      for ACRANEB2 radiation.
!      N. Gustafsson 13 Apr 2016: Add LOBSC1 to Minim and screening
!             to enable surfex in trajectory run for 4D-Var
!      2016-09, M. Mokhtari & A. Ambar: add the key LMDUST as LOGICAL POINTER
! End Modifications
!-------------------------------------------------------------------------------

USE PARKIND1  ,ONLY : JPIM     ,JPRB
USE YOMHOOK   ,ONLY : LHOOK,   DR_HOOK

USE YOMLUN   , ONLY : NULOUT   ,NULNAM
USE YOMPHY   , ONLY : YRPHY, JPHYEC, JPHYMF, JPHYARO, JPBP002
USE YOMARPHY , ONLY : YRARPHY
USE YOMMSE   , ONLY : YRMSE
USE YOEPHY   , ONLY : YREPHY
USE YOEWCOU  , ONLY : YREWCOU
USE YOECLDP  , ONLY : YRECLDP
USE YOPHLC   , ONLY : YRPHLC
USE YOMCT0   , ONLY : LECMWF    ,NCONF    ,LR3D     ,LR2D     ,&
 & LRETCFOU ,LWRTCFOU, LAROME,LOBSC1,LSCREEN,LSFXLSM ,LSLPHY, CNMEXP
USE YOMVRTL  , ONLY : L131TL
USE YOPHNC   , ONLY : YRPHNC
USE YOEPHLI  , ONLY : YREPHLI
USE YOMNCL   , ONLY : YRNCL
USE YOELWRAD , ONLY : YRELWRAD
USE YOEGWDWMS, ONLY : YREGWDWMS
USE YOMSRFTLAD, ONLY : YRSRFTLAD
USE YOMVAR   , ONLY : LREPRO4DVAR
USE YOMSIMPHL, ONLY : YRSIMPHL
USE YOMRCOEF , ONLY : YRRCOEF
USE YOMDYNA  , ONLY : LGWADV
USE YOMDYNCORE,ONLY : LAQUA, LHELDSUAREZ
USE YOMCOAPHY, ONLY : YRCOAPHY
USE YOM_YGFL , ONLY : YGFL
USE CRMDIMS  , ONLY : CRMBUFSIZE

!     ------------------------------------------------------------------

IMPLICIT NONE

INTEGER(KIND=JPIM),INTENT(IN)    :: KULOUT

!     ------------------------------------------------------------------

INTEGER(KIND=JPIM) :: IERR
REAL(KIND=JPRB) :: ZHOOK_HANDLE

!     ------------------------------------------------------------------

#include "abor1.intfb.h"
#include "posnam.intfb.h"
#include "suscm.intfb.h"

!     ------------------------------------------------------------------
LOGICAL , POINTER ::  LSTRA
LOGICAL , POINTER ::  LEFB
LOGICAL , POINTER ::  LNEBECT
LOGICAL , POINTER ::  LRRMES
INTEGER (KIND=JPIM) , POINTER :: NPRRI
INTEGER (KIND=JPIM) , POINTER :: NPRAC
LOGICAL , POINTER ::  LPTKE
LOGICAL , POINTER ::  LCOEFK_PTTE
LOGICAL , POINTER ::  LCVRA
LOGICAL , POINTER ::  LSEDLAG
LOGICAL , POINTER ::  LNEBNXR
LOGICAL , POINTER ::  LSEDCL
LOGICAL , POINTER ::  LPHSPSH
LOGICAL , POINTER ::  LCAMOD
LOGICAL , POINTER ::  LCOMOD
LOGICAL , POINTER ::  LACDIFUS
LOGICAL , POINTER ::  LAFGD_A
INTEGER (KIND=JPIM) , POINTER ::  NRAUTOEV
LOGICAL , POINTER ::  LRELAXW
LOGICAL , POINTER ::  LCVPGY
LOGICAL , POINTER ::  LO3ABC
LOGICAL , POINTER ::  LRSTAB
LOGICAL , POINTER ::  LCVDD
INTEGER (KIND=JPIM) , POINTER ::  NDIFFNEB
LOGICAL , POINTER ::  LRAY
LOGICAL , POINTER ::  LMLH
INTEGER(KIND=JPIM) , POINTER ::  NOIR
LOGICAL , POINTER ::  LRAYPL
INTEGER (KIND=JPIM) , POINTER ::  NSORAYFR
LOGICAL , POINTER ::  LCLSATUR
LOGICAL , POINTER ::  LCVCAS
LOGICAL , POINTER ::  LFSFIX
LOGICAL , POINTER ::  LCOEFK_RIH
LOGICAL , POINTER ::  LHUCN
LOGICAL , POINTER ::  LNEWD
LOGICAL , POINTER ::  LNEBCV
LOGICAL , POINTER ::  LGWD
LOGICAL , POINTER ::  LAEROVOL
LOGICAL , POINTER ::  LCVPRO
LOGICAL , POINTER ::  LCAPE
LOGICAL , POINTER ::  LCVGQ
LOGICAL , POINTER ::  LRCVOTT
LOGICAL , POINTER ::  LSMITH_CDEV
LOGICAL , POINTER ::  LCONDWT
LOGICAL , POINTER ::  LSTRAS
LOGICAL , POINTER ::  LRAYLU
LOGICAL , POINTER ::  LMPHYS
LOGICAL , POINTER ::  LCOEFK_THS1
LOGICAL , POINTER ::  LSMTPS
LOGICAL , POINTER ::  LCOLLEC
LOGICAL , POINTER ::  LCOEFK_PL
LOGICAL , POINTER ::  LGWDC
LOGICAL , POINTER ::  LSMGCDEV
LOGICAL , POINTER ::  LRAYFM
LOGICAL , POINTER ::  LNEWSTAT
CHARACTER (LEN = 20) ::   CGMIXLEN
INTEGER (KIND=JPIM) , POINTER ::  NIMELIT
LOGICAL , POINTER ::  LNEBN
LOGICAL , POINTER ::  LCVPPKF
LOGICAL , POINTER ::  LECTREP
LOGICAL , POINTER ::  LACPANMX
LOGICAL , POINTER ::  LRPROX
LOGICAL , POINTER ::  LCVGQM
LOGICAL , POINTER ::  LCVGQD
LOGICAL , POINTER ::  LCVRAV3
LOGICAL , POINTER ::  LSNV
LOGICAL , POINTER ::  LARPMPS
LOGICAL , POINTER ::  LECTFL0
LOGICAL , POINTER ::  LNODIFQC
LOGICAL , POINTER ::  LSQRML
LOGICAL , POINTER ::  LGLACIERS
LOGICAL , POINTER ::  LPRGML
LOGICAL , POINTER ::  LECSHAL
LOGICAL , POINTER ::  LRSTAER
LOGICAL , POINTER ::  LCOEFKSURF
LOGICAL , POINTER ::  LCVLIS
LOGICAL , POINTER ::  LA0MPS
LOGICAL , POINTER ::  LCOEFK_RIS
LOGICAL , POINTER ::  LAEROSEA
LOGICAL , POINTER ::  LSOLV
LOGICAL , POINTER ::  LEDMFI
LOGICAL , POINTER ::  LEDMFS
LOGICAL , POINTER ::  LSMOOTHMELT
LOGICAL , POINTER ::  LAEROSOO
LOGICAL , POINTER ::  LSEDSTA
LOGICAL , POINTER ::  LFLUSO
LOGICAL , POINTER ::  LRKCDEV
LOGICAL , POINTER ::  LNEBCO
LOGICAL , POINTER ::  LNEIGE
LOGICAL , POINTER ::  LQXRTGH
LOGICAL , POINTER ::  LCOEFK_SCQ
LOGICAL , POINTER ::  LZ0HSREL
LOGICAL , POINTER ::  LVGSN
LOGICAL , POINTER ::  LCOEFK_MSC
LOGICAL , POINTER ::  LRRGUST
LOGICAL , POINTER ::  LRAYFM15
LOGICAL , POINTER ::  LDAYD
LOGICAL , POINTER ::  LEDKF
LOGICAL , POINTER ::  LNEBINS
LOGICAL , POINTER ::  LPHCDPI
LOGICAL , POINTER ::  LECTFL
LOGICAL , POINTER ::  LVOIGT
LOGICAL , POINTER ::  LSCMF
LOGICAL , POINTER ::  LVFULL
LOGICAL , POINTER ::  LO3FL
LOGICAL , POINTER ::  LSMNIMBT
LOGICAL , POINTER ::  LNOIAS
LOGICAL , POINTER ::  LCVPP
LOGICAL , POINTER ::  LNCVPGY
LOGICAL , POINTER ::  LECDEEP
LOGICAL , POINTER ::  LCOEFK_F1
LOGICAL , POINTER ::  LAERODES
LOGICAL , POINTER ::  LECTQ1
INTEGER (KIND=JPIM) , POINTER ::  NTHRAYFR
LOGICAL , POINTER ::  LADJCLD
LOGICAL , POINTER ::  LGCHECKMV
LOGICAL , POINTER ::  LRTPP
LOGICAL , POINTER ::  L3MT
LOGICAL , POINTER ::  LDIFCONS
LOGICAL , POINTER ::  LAEROSUL
INTEGER(KIND=JPIM) , POINTER ::  NBITER
LOGICAL , POINTER ::  LGPCMT
LOGICAL , POINTER ::  LPROCLD
LOGICAL , POINTER ::  LFGEL
LOGICAL , POINTER ::  LXRCDEV
LOGICAL , POINTER ::  LENTCH
INTEGER (KIND=JPIM) , POINTER ::  NCALLRAD
LOGICAL , POINTER ::  LCOEFKTKE
LOGICAL , POINTER ::  LFSVAR
LOGICAL , POINTER ::  LSTRAPRO
LOGICAL , POINTER ::  LFPCOR
LOGICAL , POINTER ::  LRELAXT
LOGICAL , POINTER ::  LAEROLAN
LOGICAL , POINTER ::  L2MICRO
LOGICAL , POINTER ::  LCDDEVPRO
LOGICAL , POINTER ::  LVDIF
LOGICAL , POINTER ::  LDIFCEXP
LOGICAL , POINTER ::  LNEBR
LOGICAL , POINTER ::  LCVGQKF
LOGICAL , POINTER ::  LREWS
LOGICAL , POINTER ::  LPBLE
INTEGER(KIND=JPIM) , POINTER ::  NDPSFI
LOGICAL , POINTER ::  LCDDPRO
LOGICAL , POINTER ::  LRMIX
LOGICAL , POINTER ::  LOZONE
LOGICAL , POINTER ::  LECT
INTEGER (KIND=JPIM) , POINTER ::  NSMTBOT
INTEGER(KIND=JPIM) , POINTER ::  NPHYREP
LOGICAL , POINTER ::  LSSD
INTEGER(KIND=JPIM) , POINTER ::  NITERFL
LOGICAL , POINTER ::  LNEBGY
LOGICAL , POINTER ::  LAB12
LOGICAL , POINTER ::  LEVAPP
LOGICAL , POINTER ::  LRMU0M
LOGICAL , POINTER ::  LNEBGR
LOGICAL , POINTER ::  LAJUCV
LOGICAL , POINTER ::  LBLVAR
INTEGER (KIND=JPIM) , POINTER ::  NSMDNEB
INTEGER (KIND=JPIM) , POINTER ::  NRAY
CHARACTER (LEN = 20) ::   CGTURS
CHARACTER (LEN = 20) ::   CGTRG
LOGICAL , POINTER ::  LCDDCSD
LOGICAL , POINTER ::  LCVCSD
LOGICAL , POINTER ::  LCVSHCU
LOGICAL , POINTER ::  LNSDO
LOGICAL , POINTER ::  LPEC
LOGICAL , POINTER ::  LUDEVOL
LOGICAL , POINTER ::  LUSL
INTEGER (KIND=JPIM) , POINTER ::  NCLOMIX
INTEGER (KIND=JPIM) , POINTER ::  NFSIG
LOGICAL , POINTER ::  LCOEFK_FLX
LOGICAL , POINTER ::  LREASUR
LOGICAL , POINTER ::  LSLC
LOGICAL , POINTER ::  LCOEFK_TOMS
LOGICAL , POINTER ::  LCOEFK_ML
LOGICAL , POINTER ::  LCVGQP
LOGICAL , POINTER ::  LSFHYD
LOGICAL , POINTER ::  LRTDL
LOGICAL , POINTER ::  LNEB_FP
LOGICAL , POINTER ::  LRNUMX
LOGICAL , POINTER ::  LRNUEXP
LOGICAL , POINTER ::  LRTRUEBBC
LOGICAL , POINTER ::  LRTRUEDIR
LOGICAL , POINTER ::  LGLT
LOGICAL , POINTER ::  LEDR
LOGICAL , POINTER ::  LHLRADUPD
LOGICAL , POINTER ::  LWINDFARM
INTEGER (KIND=JPIM) , POINTER ::  NWINDFARM
INTEGER (KIND=JPIM) , POINTER ::  NLEND

INTEGER(KIND=JPIM), POINTER :: NLWFR, NLOOPLW, NCO2CLIMYY1, NCO2CLIMYY2, &
 & NCO2CLIMN1, NCO2CLIMN2, NCO2CLIMFRQ, NSTPW, NPRACCL, NPHYINT, &
   NTEND_DIAG_POS, NTEND_DIAG_FREQ_RESET

LOGICAL, POINTER :: LWLCLHR, LOPTLWPR, LETRAJP, LETRAJPT, LERADI2, LERADS2, &
 & LERADSW2, LERADLW2, LERADN2, LERADFL2, LEDCLD2, LENCLD2, LEVAPLS2, &
 & LEVDIF2, LEGWDG2, LECUMF2, LECOND2, LEGWWMS2, LEQNGT2, LESURF2, &
 & LEKPERT, LEKPERTS, LENOPERT, LTRACLNPH, LEPHYS, LECOND, LECUMF, LEDCLD, &
 & LEEVAP, LEGWDG, LEOZOC, LEQNGT, LERADI, LERADS, LESICE, LESURF, LEGWWMS, &
 & LEVDIF, LE4ALB, LEVGEN, LESSRO, LELAIV, LESN09, LECTESSEL, LEAGS, LEFLAKE, &
 & LEPCLD, LAGPHY, LEO3CH, LO3CH_OLDVER, LO3CH_BMS, LECO2DIU, LNEEONLINE, LBFASCO2, LWCOU, LWCOU2W, &
 & LWCUR, LWSTOKES, LBUD23, LBUDCYCLE, LEMETHOX, LERAIN, LVDFTRAC, LMFTRAC, & 
 & LMFSCAV, LEOCWA, LEOCCO, LEOCML, LEOCLAKE, LEOBC, LEOBCICE, LEOLAKESST, &
 & LOCMLTKE, LEOCSA, LEOCLA, LECURR, LESMOSS, LEMWAVE, &
 & LECLIPQT0, LECLIPCLDT0, LDUCTDIA, LEGBRAD, LERAINGG, LESMOS, INVML, &
 & LSPHLC, LVDFLC, LSDRLC, LZMCON, LKEXP, LVDFDS, LSDRDS, LREGWWMS, LREGSF, &
 & LNCLIN, LREGCL, LRCOEF, LTLADDIA, LGLOBRAD, LSPCRM

REAL(KIND=JPRB), POINTER :: RLAIINT, RSOUTW, RNORTW, RDEGREW, RTHRFRTI, RCIMIN, &
 & RCLDTOPP, RNORTHML, RSOUTHML, REASTML, RWESTML, ALPHA, AH0, USTARL, USTARS, &
 & ALANDZ0, ASEAZ0

#include "namtrajp.nam.h"
#include "namphy.nam.h"

LOGICAL , POINTER ::  LMFSHAL
LOGICAL , POINTER ::  LMSE
LOGICAL , POINTER ::  LINITCHEM
LOGICAL , POINTER ::  LORILAM
LOGICAL , POINTER ::  LUSECHEM
LOGICAL , POINTER ::  LMPA
LOGICAL , POINTER ::  LKFBCONV
LOGICAL , POINTER ::  LINITORILAM
LOGICAL , POINTER ::  LRCO2
LOGICAL , POINTER ::  LBUFLUX
LOGICAL , POINTER ::  LSURFEX_KFROM
LOGICAL , POINTER ::  LRDUST
LOGICAL , POINTER ::  LINITDUST
LOGICAL , POINTER ::  LRDEPOS
LOGICAL , POINTER ::  LMDUST
LOGICAL , POINTER ::  LMICRO
INTEGER(KIND=JPIM) , POINTER ::  NSURFEX_ITER
LOGICAL , POINTER ::  LTURB
LOGICAL , POINTER ::  LSURFEX_CRITICAL
LOGICAL , POINTER ::  LKFBD
LOGICAL , POINTER ::  LKFBS
LOGICAL , POINTER ::  LCVRASBM,LCONSENTH,LAPPROXCONV
REAL(KIND=JPRB) , POINTER :: RHCRIT1S,RHCRIT2S,TADJ,RMINEVP,DELTAH
CHARACTER(LEN=1) ::  CCOUPLING
#include "namarphy.nam.h"

#include "naephy.nam.h"
#include "naphlc.nam.h"

LOGICAL , POINTER ::  LVDIFSP
LOGICAL , POINTER ::  LNEBCVPPKF
LOGICAL , POINTER ::  LCVRASP
LOGICAL , POINTER ::  LSMOOTHB
LOGICAL , POINTER ::  LRAYSP
LOGICAL , POINTER ::  LGWDSP
LOGICAL , POINTER ::  LMICROTL
LOGICAL , POINTER ::  LSMOOTHD
LOGICAL , POINTER ::  LSTRASPN
REAL(KIND=JPRB), POINTER ::  RMODULQCPROG
LOGICAL , POINTER ::  LSTRASP
LOGICAL , POINTER ::  LTRAJRAIN
LOGICAL , POINTER ::  LMELTTL
LOGICAL , POINTER ::  LMELTNL
LOGICAL , POINTER ::  LEVAPTL
LOGICAL , POINTER ::  LCOLLECTL
LOGICAL , POINTER ::  LTRAJPST
LOGICAL , POINTER ::  LPROCLDTL
LOGICAL , POINTER ::  LGWDSPNL
LOGICAL , POINTER ::  LIGELREPRO
LOGICAL , POINTER ::  LSMOOTHA
LOGICAL , POINTER ::  LTRAJCOND
LOGICAL , POINTER ::  LSMOOTHEVP
LOGICAL , POINTER ::  LVDIFSPNL
LOGICAL , POINTER ::  LCLOUDS
LOGICAL , POINTER ::  LRRMESSP
LOGICAL , POINTER ::  LSIMPH
LOGICAL , POINTER ::  LTRAJPS
#include "namsimphl.nam.h"

#include "namrcoef.nam.h"

!     ------------------------------------------------------------------

IF (LHOOK) CALL DR_HOOK('SU0PHY',0,ZHOOK_HANDLE)

ASSOCIATE( &
 & NSURFEXCTLMAX=>YRMSE%NSURFEXCTLMAX, NSURFEXCTL=>YRMSE%NSURFEXCTL, &
 & NNOGW=>YGFL%NNOGW, LUVPOUT=>YGFL%LUVPOUT, LAEROUT=>YGFL%LAEROUT, &
 & NUVP=>YGFL%NUVP, NAEROUT=>YGFL%NAEROUT, &
 & LHMTO=>YRPHY%LHMTO, NPHY=>YRPHY%NPHY, LTHERMO=>YRPHY%LTHERMO, &
 & LWFLUX=>YREWCOU%LWFLUX, LWFRSTIME=>YREWCOU%LWFRSTIME, &
 & NADV_WAVE=>YREWCOU%NADV_WAVE, NG3SR=>YRRCOEF%NG3SR, &
 & NGMTR=>YRRCOEF%NGMTR, NLATRD=>YRRCOEF%NLATRD, &
 & NLATWR=>YRRCOEF%NLATWR)

NTEND_DIAG_FREQ_RESET=>YRPHY%NTEND_DIAG_FREQ_RESET
NTEND_DIAG_POS=>YRPHY%NTEND_DIAG_POS
NSMDNEB => YRPHY%NSMDNEB
LSTRA => YRPHY%LSTRA
LEVAPP => YRPHY%LEVAPP
LAEROSOO => YRPHY%LAEROSOO
LCDDPRO => YRPHY%LCDDPRO
LRKCDEV => YRPHY%LRKCDEV
L2MICRO => YRPHY%L2MICRO
LNEBINS => YRPHY%LNEBINS
LHUCN => YRPHY%LHUCN
LCOEFK_TOMS => YRPHY%LCOEFK_TOMS
LRRMES => YRPHY%LRRMES
LCDDEVPRO => YRPHY%LCDDEVPRO
LECTFL0 => YRPHY%LECTFL0
NLEND => YRPHY%NLEND
LCOLLEC => YRPHY%LCOLLEC
LRSTAB => YRPHY%LRSTAB
LPTKE => YRPHY%LPTKE
LREASUR => YRPHY%LREASUR
LPBLE => YRPHY%LPBLE
LCOEFK_RIS => YRPHY%LCOEFK_RIS
LVOIGT => YRPHY%LVOIGT
LSEDLAG => YRPHY%LSEDLAG
LAEROLAN => YRPHY%LAEROLAN
LNEBECT => YRPHY%LNEBECT
LCOEFK_RIH => YRPHY%LCOEFK_RIH
NOIR => YRPHY%NOIR
LCVPGY => YRPHY%LCVPGY
LCOEFK_SCQ => YRPHY%LCOEFK_SCQ
LRMU0M => YRPHY%LRMU0M
NBITER => YRPHY%NBITER
LAERODES => YRPHY%LAERODES
LCVLIS => YRPHY%LCVLIS
LMLH => YRPHY%LMLH
LECT => YRPHY%LECT
LRSTAER => YRPHY%LRSTAER
LO3FL => YRPHY%LO3FL
LRRGUST => YRPHY%LRRGUST
LGLT => YRPHY%LGLT
LEDR => YRPHY%LEDR
LSLC => YRPHY%LSLC
LSEDSTA => YRPHY%LSEDSTA
NPHYREP => YRPHY%NPHYREP
LPHSPSH => YRPHY%LPHSPSH
LCAMOD => YRPHY%LCAMOD
LCOMOD => YRPHY%LCOMOD
LECTFL => YRPHY%LECTFL
LNEBGY => YRPHY%LNEBGY
LCVDD => YRPHY%LCVDD
LSEDCL => YRPHY%LSEDCL
LNEBGR => YRPHY%LNEBGR
LSNV => YRPHY%LSNV
LCVGQM => YRPHY%LCVGQM
LECSHAL => YRPHY%LECSHAL
LNEWSTAT => YRPHY%LNEWSTAT
LCVCAS => YRPHY%LCVCAS
LNODIFQC => YRPHY%LNODIFQC
LREWS => YRPHY%LREWS
LSTRAPRO => YRPHY%LSTRAPRO
LNOIAS => YRPHY%LNOIAS
LAEROVOL => YRPHY%LAEROVOL
NDPSFI => YRPHY%NDPSFI
LVDIF => YRPHY%LVDIF
LOZONE => YRPHY%LOZONE
NCALLRAD => YRPHY%NCALLRAD
LNCVPGY => YRPHY%LNCVPGY
LRAYLU => YRPHY%LRAYLU
LCVPRO => YRPHY%LCVPRO
LNEIGE => YRPHY%LNEIGE
LAEROSUL => YRPHY%LAEROSUL
LO3ABC => YRPHY%LO3ABC
LXRCDEV => YRPHY%LXRCDEV
LCLSATUR => YRPHY%LCLSATUR
LSTRAS => YRPHY%LSTRAS
NIMELIT => YRPHY%NIMELIT
LEDMFI => YRPHY%LEDMFI
LEDMFS => YRPHY%LEDMFS
LDIFCEXP => YRPHY%LDIFCEXP
LACPANMX => YRPHY%LACPANMX
LCOEFK_PTTE => YRPHY%LCOEFK_PTTE
LSFHYD => YRPHY%LSFHYD
NTHRAYFR => YRPHY%NTHRAYFR
LAEROSEA => YRPHY%LAEROSEA
NDIFFNEB => YRPHY%NDIFFNEB
LRCVOTT => YRPHY%LRCVOTT
LCOEFK_MSC => YRPHY%LCOEFK_MSC
LEDKF => YRPHY%LEDKF
LFLUSO => YRPHY%LFLUSO
LNEBNXR => YRPHY%LNEBNXR
LAFGD_A => YRPHY%LAFGD_A
LCVGQP => YRPHY%LCVGQP
LSMGCDEV => YRPHY%LSMGCDEV
LRAYPL => YRPHY%LRAYPL
LAJUCV => YRPHY%LAJUCV
LNEBR => YRPHY%LNEBR
LRMIX => YRPHY%LRMIX
LNEBN => YRPHY%LNEBN
LMPHYS => YRPHY%LMPHYS
NITERFL => YRPHY%NITERFL
LFSFIX => YRPHY%LFSFIX
LFSVAR => YRPHY%LFSVAR
LBLVAR => YRPHY%LBLVAR
NSORAYFR => YRPHY%NSORAYFR
LCONDWT => YRPHY%LCONDWT
LVFULL => YRPHY%LVFULL
LEFB => YRPHY%LEFB
LNEB_FP => YRPHY%LNEB_FP
LSMITH_CDEV => YRPHY%LSMITH_CDEV
LRAY => YRPHY%LRAY
LZ0HSREL => YRPHY%LZ0HSREL
NPRRI => YRPHY%NPRRI
LGWD => YRPHY%LGWD
LGLACIERS => YRPHY%LGLACIERS
LSCMF => YRPHY%LSCMF
LCVCSD => YRPHY%LCVCSD
LCVSHCU => YRPHY%LCVSHCU
NCLOMIX => YRPHY%NCLOMIX
NFSIG => YRPHY%NFSIG
LPEC => YRPHY%LPEC
LUDEVOL => YRPHY%LUDEVOL
LNSDO => YRPHY%LNSDO
LCDDCSD => YRPHY%LCDDCSD
LUSL => YRPHY%LUSL
LCVRA => YRPHY%LCVRA
LPHCDPI => YRPHY%LPHCDPI
LRTPP => YRPHY%LRTPP
LSOLV => YRPHY%LSOLV
L3MT => YRPHY%L3MT
LRAYFM => YRPHY%LRAYFM
LECTQ1 => YRPHY%LECTQ1
LPRGML => YRPHY%LPRGML
LCOEFK_FLX => YRPHY%LCOEFK_FLX
LCOEFK_PL => YRPHY%LCOEFK_PL
LCAPE => YRPHY%LCAPE
LCVGQ => YRPHY%LCVGQ
LCOEFK_F1 => YRPHY%LCOEFK_F1
LECDEEP => YRPHY%LECDEEP
LCOEFK_THS1 => YRPHY%LCOEFK_THS1
LCVGQD => YRPHY%LCVGQD
LDIFCONS => YRPHY%LDIFCONS
LFGEL => YRPHY%LFGEL
LGWDC => YRPHY%LGWDC
LSQRML => YRPHY%LSQRML
LNEBCO => YRPHY%LNEBCO
NSMTBOT => YRPHY%NSMTBOT
LQXRTGH => YRPHY%LQXRTGH
LAB12 => YRPHY%LAB12
NPRAC => YRPHY%NPRAC
LNEBCV => YRPHY%LNEBCV
LENTCH => YRPHY%LENTCH
LRELAXT => YRPHY%LRELAXT
LRELAXW => YRPHY%LRELAXW
LCOEFKSURF => YRPHY%LCOEFKSURF
LDAYD => YRPHY%LDAYD
NRAY => YRPHY%NRAY
LSMTPS => YRPHY%LSMTPS
LSMNIMBT => YRPHY%LSMNIMBT
LCOEFKTKE => YRPHY%LCOEFKTKE
NRAUTOEV => YRPHY%NRAUTOEV
LNEWD => YRPHY%LNEWD
LA0MPS => YRPHY%LA0MPS
LRTDL => YRPHY%LRTDL
LCVPP => YRPHY%LCVPP
LCOEFK_ML => YRPHY%LCOEFK_ML
LGPCMT => YRPHY%LGPCMT
LFPCOR => YRPHY%LFPCOR
LRPROX => YRPHY%LRPROX
LCVGQKF => YRPHY%LCVGQKF
LECTREP => YRPHY%LECTREP
LPROCLD => YRPHY%LPROCLD
LACDIFUS => YRPHY%LACDIFUS
LSSD => YRPHY%LSSD
LARPMPS => YRPHY%LARPMPS
LRNUMX => YRPHY%LRNUMX
LRNUEXP => YRPHY%LRNUEXP
LRTRUEBBC => YRPHY%LRTRUEBBC
LRTRUEDIR => YRPHY%LRTRUEDIR
LCVRAV3 => YRPHY%LCVRAV3
LRAYFM15 => YRPHY%LRAYFM15
LVGSN => YRPHY%LVGSN
LCVPPKF => YRPHY%LCVPPKF
LSMOOTHMELT => YRPHY%LSMOOTHMELT
LADJCLD => YRPHY%LADJCLD
LGCHECKMV => YRPHY%LGCHECKMV
LHLRADUPD => YRPHY%LHLRADUPD
LWINDFARM => YRPHY%LWINDFARM
NWINDFARM => YRPHY%NWINDFARM

LRDUST => YRARPHY%LRDUST
LBUFLUX => YRARPHY%LBUFLUX
LINITDUST => YRARPHY%LINITDUST
LMPA => YRARPHY%LMPA
LUSECHEM => YRARPHY%LUSECHEM
LRDEPOS => YRARPHY%LRDEPOS
LKFBD => YRARPHY%LKFBD
LKFBCONV => YRARPHY%LKFBCONV
LINITORILAM => YRARPHY%LINITORILAM
LMFSHAL => YRARPHY%LMFSHAL
LMICRO => YRARPHY%LMICRO
LTURB => YRARPHY%LTURB
LRCO2 => YRARPHY%LRCO2
LINITCHEM => YRARPHY%LINITCHEM
LORILAM => YRARPHY%LORILAM
NSURFEX_ITER => YRARPHY%NSURFEX_ITER
LSURFEX_CRITICAL => YRARPHY%LSURFEX_CRITICAL
LMSE => YRARPHY%LMSE
LSURFEX_KFROM => YRARPHY%LSURFEX_KFROM
LKFBS => YRARPHY%LKFBS
LMDUST => YRARPHY%LMDUST

LTRAJPST => YRSIMPHL%LTRAJPST
LVDIFSPNL => YRSIMPHL%LVDIFSPNL
LCOLLECTL => YRSIMPHL%LCOLLECTL
LPROCLDTL => YRSIMPHL%LPROCLDTL
LIGELREPRO => YRSIMPHL%LIGELREPRO
LCONSENTH => YRSIMPHL%LCONSENTH
TADJ => YRSIMPHL%TADJ
DELTAH => YRSIMPHL%DELTAH
RMODULQCPROG => YRSIMPHL%RMODULQCPROG
LNEBCVPPKF => YRSIMPHL%LNEBCVPPKF
LMICROTL => YRSIMPHL%LMICROTL
LGWDSPNL => YRSIMPHL%LGWDSPNL
LRRMESSP => YRSIMPHL%LRRMESSP
LGWDSP => YRSIMPHL%LGWDSP
RHCRIT1S => YRSIMPHL%RHCRIT1S
LVDIFSP => YRSIMPHL%LVDIFSP
LSMOOTHEVP => YRSIMPHL%LSMOOTHEVP
LTRAJCOND => YRSIMPHL%LTRAJCOND
LTRAJRAIN => YRSIMPHL%LTRAJRAIN
LSTRASPN => YRSIMPHL%LSTRASPN
RMINEVP => YRSIMPHL%RMINEVP
LMELTNL => YRSIMPHL%LMELTNL
LEVAPTL => YRSIMPHL%LEVAPTL
LCLOUDS => YRSIMPHL%LCLOUDS
LCVRASP => YRSIMPHL%LCVRASP
LRAYSP => YRSIMPHL%LRAYSP
LAPPROXCONV => YRSIMPHL%LAPPROXCONV
LCVRASBM => YRSIMPHL%LCVRASBM
LSMOOTHB => YRSIMPHL%LSMOOTHB
LMELTTL => YRSIMPHL%LMELTTL
LSMOOTHA => YRSIMPHL%LSMOOTHA
LSMOOTHD => YRSIMPHL%LSMOOTHD
LSIMPH => YRSIMPHL%LSIMPH
LSTRASP => YRSIMPHL%LSTRASP
LTRAJPS => YRSIMPHL%LTRAJPS
RHCRIT2S => YRSIMPHL%RHCRIT2S

! Associate pointers for variables in namelist NAMTRAJP
LETRAJP         => YRPHNC%LETRAJP
LETRAJPT        => YRPHNC%LETRAJPT
NLWFR           => YRELWRAD%NLWFR
NLOOPLW         => YRELWRAD%NLOOPLW
LERADI2         => YRPHNC%LERADI2
LERADS2         => YRPHNC%LERADS2
LERADSW2        => YRPHNC%LERADSW2
LERADLW2        => YRPHNC%LERADLW2
LERADN2         => YRPHNC%LERADN2
LERADFL2        => YRPHNC%LERADFL2
LOPTLWPR        => YRELWRAD%LOPTLWPR
LWLCLHR         => YRELWRAD%LWLCLHR
LEDCLD2         => YRPHNC%LEDCLD2
LENCLD2         => YRPHNC%LENCLD2
LEVAPLS2        => YRPHNC%LEVAPLS2
LEVDIF2         => YRPHNC%LEVDIF2
LEGWDG2         => YRPHNC%LEGWDG2
LECUMF2         => YRPHNC%LECUMF2
LECOND2         => YRPHNC%LECOND2
LEGWWMS2        => YRPHNC%LEGWWMS2
LREGWWMS        => YREGWDWMS%LREGWWMS
LEQNGT2         => YRPHNC%LEQNGT2
LESURF2         => YRPHNC%LESURF2
LREGSF          => YRSRFTLAD%LREGSF
LEKPERT         => YRPHNC%LEKPERT
LEKPERTS        => YRPHNC%LEKPERTS
LENOPERT        => YREPHLI%LENOPERT
LNCLIN          => YRNCL%LNCLIN
LREGCL          => YRNCL%LREGCL
LTRACLNPH       => YRPHNC%LTRACLNPH

! Associate pointers for variables in namelist NAEPHY
LEPHYS          => YREPHY%LEPHYS
LECOND          => YREPHY%LECOND
LECUMF          => YREPHY%LECUMF
LEDCLD          => YREPHY%LEDCLD
LEEVAP          => YREPHY%LEEVAP
LEGWDG          => YREPHY%LEGWDG
LEOZOC          => YREPHY%LEOZOC
LEQNGT          => YREPHY%LEQNGT
LERADI          => YREPHY%LERADI
LERADS          => YREPHY%LERADS
LESICE          => YREPHY%LESICE
LESURF          => YREPHY%LESURF
LEGWWMS         => YREPHY%LEGWWMS
LEVDIF          => YREPHY%LEVDIF
LE4ALB          => YREPHY%LE4ALB
LEVGEN          => YREPHY%LEVGEN
LESSRO          => YREPHY%LESSRO
LELAIV          => YREPHY%LELAIV
LESN09          => YREPHY%LESN09
LECTESSEL       => YREPHY%LECTESSEL
LEAGS           => YREPHY%LEAGS
RLAIINT         => YREPHY%RLAIINT
LEFLAKE         => YREPHY%LEFLAKE
LEPCLD          => YREPHY%LEPCLD
LAGPHY          => YREPHY%LAGPHY
LEO3CH          => YREPHY%LEO3CH
LO3CH_OLDVER    => YREPHY%LO3CH_OLDVER
LO3CH_BMS       => YREPHY%LO3CH_BMS
LECO2DIU        => YREPHY%LECO2DIU
LNEEONLINE      => YREPHY%LNEEONLINE
LBFASCO2        => YREPHY%LBFASCO2
NCO2CLIMYY1     => YREPHY%NCO2CLIMYY1
NCO2CLIMYY2     => YREPHY%NCO2CLIMYY2
NCO2CLIMN1      => YREPHY%NCO2CLIMN1
NCO2CLIMN2      => YREPHY%NCO2CLIMN2
NCO2CLIMFRQ     => YREPHY%NCO2CLIMFRQ
LWCOU           => YREWCOU%LWCOU
LWCOU2W         => YREWCOU%LWCOU2W
LWCUR           => YREWCOU%LWCUR
LWSTOKES        => YREWCOU%LWSTOKES
LBUD23          => YREPHY%LBUD23
LBUDCYCLE       => YREPHY%LBUDCYCLE
LEMETHOX        => YREPHY%LEMETHOX
LERAIN          => YREPHY%LERAIN
LVDFTRAC        => YREPHY%LVDFTRAC
LMFTRAC         => YREPHY%LMFTRAC
LMFSCAV         => YREPHY%LMFSCAV
LEOCWA          => YREPHY%LEOCWA
LEOCCO          => YREPHY%LEOCCO
LEOCML          => YREPHY%LEOCML
LEOCLAKE        => YREPHY%LEOCLAKE
LEOBC           => YREPHY%LEOBC
LEOBCICE        => YREPHY%LEOBCICE
LEOLAKESST      => YREPHY%LEOLAKESST
LOCMLTKE        => YREPHY%LOCMLTKE
LEOCSA          => YREPHY%LEOCSA
LEOCLA          => YREPHY%LEOCLA
NSTPW           => YREWCOU%NSTPW
RSOUTW          => YREWCOU%RSOUTW
RNORTW          => YREWCOU%RNORTW
RDEGREW         => YREWCOU%RDEGREW
LECURR          => YREPHY%LECURR
LESMOSS         => YREPHY%LESMOSS
RTHRFRTI        => YREPHY%RTHRFRTI
RCIMIN          => YREPHY%RCIMIN
RCLDTOPP        => YRECLDP%RCLDTOPP
NPHYINT         => YRCOAPHY%NPHYINT
LEMWAVE         => YREPHY%LEMWAVE
LECLIPQT0       => YREPHY%LECLIPQT0
LECLIPCLDT0     => YREPHY%LECLIPCLDT0
LDUCTDIA        => YREPHY%LDUCTDIA
LEGBRAD         => YREPHY%LEGBRAD
NPRACCL         => YREPHY%NPRACCL
LERAINGG        => YREPHY%LERAINGG
LSPCRM          => YREPHY%LSPCRM
LESMOS          => YREPHY%LESMOS
RNORTHML        => YREPHY%RNORTHML
RSOUTHML        => YREPHY%RSOUTHML
REASTML         => YREPHY%REASTML
RWESTML         => YREPHY%RWESTML
INVML        => YREPHY%INVML

! Associate pointers for variables in namelist NAPHLC
LSPHLC          => YRPHLC%LSPHLC
LVDFLC          => YRPHLC%LVDFLC
LSDRLC          => YRPHLC%LSDRLC
LZMCON          => YRPHLC%LZMCON
LKEXP           => YRPHLC%LKEXP
LVDFDS          => YRPHLC%LVDFDS
LSDRDS          => YRPHLC%LSDRDS
ALPHA           => YRPHLC%ALPHA
AH0             => YRPHLC%AH0
USTARL          => YRPHLC%USTARL
USTARS          => YRPHLC%USTARS
ALANDZ0         => YRPHLC%ALANDZ0
ASEAZ0          => YRPHLC%ASEAZ0

! Associate pointers for variables in namelist NAPHLC
LRCOEF          => YRRCOEF%LRCOEF
LTLADDIA        => YRRCOEF%LTLADDIA
LGLOBRAD        => YRRCOEF%LGLOBRAD


!     ------------------------------------------------------------------

!*       1.    Set default values.
!              -------------------

LECO2DIU=.FALSE.
LNEEONLINE=.TRUE.
LBFASCO2=.FALSE.
LEO3CH=.FALSE.
LO3CH_OLDVER=.FALSE.
LO3CH_BMS=.FALSE.

!*       1.1.1 Set default values for Meteo-France physics
!              -------------------------------------------

LMPHYS=.FALSE.
LREASUR=.TRUE.
LSMOOTHMELT=.FALSE.
CGMIXLEN='Z'
CGTURS='MD2'
LPRGML=.FALSE.
LCAPE=.FALSE.
LCVGQ=.TRUE.
LCVGQD=.FALSE.
LCVGQM=.FALSE.
LCVGQP=.FALSE.
LCOMOD=.TRUE.
LCONDWT=.FALSE.
LCVCAS=.FALSE.
LCVLIS=.FALSE.
LCVPP=.FALSE.
LCVPPKF=.FALSE.
LEDKF=.FALSE.
LEDMFI=.FALSE.
LCVGQKF=.TRUE.
LCVDD=.FALSE.
LNEIGE=.TRUE.
LRNUMX=.FALSE.
LRNUEXP=.FALSE.
LACPANMX=.FALSE.
LRTRUEBBC=.FALSE.
LRTRUEDIR=.FALSE.
LCLSATUR=.FALSE.
LGLACIERS=.FALSE.
LRRGUST=.FALSE.
LO3ABC=.FALSE.
LO3FL=.FALSE.
LECSHAL=.FALSE.
LECDEEP=.FALSE.
LAEROSEA=.FALSE.
LAEROLAN=.FALSE.
LAEROSOO=.FALSE.
LAERODES=.FALSE.
LAEROVOL=.FALSE.
LAEROSUL=.FALSE.
LRELAXT=.FALSE.
LRELAXW=.FALSE.
LE4ALB=.FALSE.
LEVGEN=.FALSE.
LESSRO=.FALSE.
LELAIV=.FALSE.
LECTESSEL=.FALSE.
RLAIINT=0.0_JPRB
LEFLAKE=.FALSE.
LEOCML=.FALSE.
LEOBC=.FALSE.
LEOBCICE=.FALSE.
LEOCLAKE=.FALSE.
LEOLAKESST=.FALSE.
LOCMLTKE=.FALSE.
LESMOSS=.FALSE.
LESN09=.FALSE.
LGLT=.FALSE.
LNEWD=.FALSE.
LDIFCONS=.FALSE.
LECT=.FALSE.
LEFB=.FALSE.
LECTQ1=.FALSE.
LECTREP=.TRUE.
LECTFL=.FALSE.
LECTFL0=.FALSE.
LPBLE=.FALSE.
LCVPGY=.FALSE.
L3MT=.FALSE.
LGPCMT=.FALSE.
LRCVOTT=.FALSE.

LCVRA=.FALSE.
LDAYD=.FALSE.
LGWDC=.FALSE.
LGWD=.FALSE.
LHMTO=.FALSE.
LNEBCO=.FALSE.
LNEBN=.FALSE.
LNEBNXR=.FALSE.
LNEBR=.FALSE.
LNEBECT=.FALSE.
LNEB_FP=.FALSE.
LQXRTGH=.FALSE.
LHUCN=.FALSE.
LOZONE=.FALSE.
LRAYFM=.FALSE.
LRMU0M=.FALSE.
LRAYFM15=.FALSE.
LRRMES=.FALSE.
LSFHYD=.FALSE.
LSNV=.FALSE.
LSOLV=.FALSE.
LFGEL=.FALSE.
LSLC=.FALSE.
LSTRA=.FALSE.
LSTRAS=.FALSE.
LTHERMO=.FALSE.
LVDIF=.FALSE.
LVGSN=.FALSE.
LFPCOR=.FALSE.
LNOIAS=.FALSE.
LPHCDPI=.FALSE.
LBLVAR=.FALSE.
LACDIFUS=.FALSE.
LFLUSO=.FALSE.
L2MICRO=.FALSE.

!HIRLAM RADIATION SUGGESTIONS (SWITCH IN YOMPHY, NAMPHY)
LHLRADUPD=.FALSE.
LZ0HSREL=.FALSE.

! Wind farm parameterisation
LWINDFARM = .FALSE.
NWINDFARM=0

NBITER=2
NITERFL=6
NDPSFI=0
NPHYREP=1
NOIR=0
NCALLRAD=0
LGCHECKMV=.TRUE.

! ---------------------------------------------------
! ACRANEB radiation
! ---------------------------------------------------
LRAY=.FALSE.
LRAYLU=.FALSE.
LREWS=.FALSE.
LRPROX=.FALSE.
LRMIX=.FALSE.
LRSTAB=.FALSE.
LRSTAER=.TRUE.
LRTPP=.FALSE.
LRTDL=.FALSE.
LRAYPL=.FALSE.
LVOIGT=.FALSE.
LVFULL=.FALSE.
NRAY=1
NRAUTOEV=0
NSORAYFR=1
NTHRAYFR=-1

! ---------------------------------------------------
! ALARO turbulence (TOUCANS)
! ---------------------------------------------------
LPTKE      =.FALSE.
LCOEFKTKE  =.FALSE.
LCOEFKSURF =.FALSE.
LCOEFK_F1  =.TRUE.
LCOEFK_TOMS=.FALSE.
LCOEFK_THS1=.FALSE.
LCOEFK_RIS=.TRUE.
LCOEFK_RIH=.FALSE.
LCOEFK_PL=.FALSE.
LCOEFK_ML=.FALSE.
LCOEFK_PTTE=.FALSE.
LCOEFK_FLX=.FALSE.
LCOEFK_SCQ=.FALSE.
LCOEFK_MSC=.FALSE.
LAFGD_A    =.TRUE.

! ---------------------------------------------------
! ALARO-0 (cloud)
! ---------------------------------------------------
LSTRAPRO=.FALSE.
LNEWSTAT=.TRUE.
LPHSPSH=.FALSE. ! Pseudo Historic Surface Precip Sensible Heat Flux
LCAMOD=.FALSE.
LSMTPS=.FALSE.
LSMGCDEV=.FALSE.
LXRCDEV=.FALSE.
LRKCDEV=.FALSE.
LNEBCV=.FALSE.
LNEBINS=.FALSE.
LSMNIMBT=.FALSE.
NSMTBOT=0 ! interpolate
NSMDNEB=2 ! gradient limitation
NDIFFNEB=0
NIMELIT=1
NPRAC=1
NPRRI=1

! ---------------------------------------------------
! ALARO-0 (microphysics)
! ---------------------------------------------------
LSEDSTA=.TRUE.
LSEDLAG=.FALSE.
LSEDCL=.FALSE.
LFSVAR=.TRUE.
LFSFIX=.FALSE.
LA0MPS=.TRUE.
LARPMPS=.FALSE.
LAB12=.FALSE.
! ---------------------------------------------------
! ALARO-0 (prognostic convection)
! ---------------------------------------------------
LCVPRO=.FALSE.
LCDDPRO=.FALSE.
LENTCH=.FALSE.
LCDDEVPRO=.TRUE.
LSCMF=.FALSE.

! ---------------------------------------------------
! ALARO-1 (prognostic convection)
! ---------------------------------------------------
LCVCSD=.FALSE.
LNSDO=.FALSE.
LCDDCSD=.TRUE.
LCVSHCU=.TRUE.
LPEC=.FALSE.
LUDEVOL=.TRUE.
NCLOMIX=4_JPIM
NFSIG=2_JPIM
LUSL=.TRUE.
CGTRG='RC'

! - - - - - - - - - - - - - - - - - - - - - - - - - -
! Cloud and precipitation prognostic scheme (Lopez) :
! - - - - - - - - - - - - - - - - - - - - - - - - - -

LPROCLD=.FALSE.
LSMITH_CDEV=.FALSE.
LEVAPP=.TRUE.
LCOLLEC=.TRUE.
LADJCLD=.FALSE.
LSSD=.FALSE.

!AROME physics
LMPA=.FALSE.
LMICRO=.FALSE.
LTURB=.FALSE.
LMSE=.FALSE.
NSURFEXCTL=NSURFEXCTLMAX
NSURFEX_ITER=1
LKFBCONV=.FALSE.
LKFBD=.FALSE.
LKFBS=.FALSE.
LMFSHAL=.FALSE.
LUSECHEM=.FALSE.
LINITCHEM=.FALSE.
LINITDUST=.FALSE.
LINITORILAM=.FALSE.
LORILAM=.FALSE.
LRDUST=.FALSE.
LRDEPOS=.FALSE.
LRCO2=.FALSE.
LBUFLUX=.TRUE.
CCOUPLING='E'
LSURFEX_CRITICAL=.FALSE.
LSURFEX_KFROM=.FALSE.
LMDUST=.FALSE.
! - - - - - - - - - - -
! Module YOMPHY :
! - - - - - - - - - - -

LAJUCV=.FALSE.
LNEBGR=.FALSE.
LNEBGY=.FALSE.

LCVRAV3=.FALSE.

LMLH=.FALSE.
LNODIFQC=.FALSE.
LDIFCEXP=.FALSE.
LSQRML=.FALSE.
LNCVPGY=.FALSE.

!*    1.1.2  Set default values for simplified physical parametrization
!            of Meteo-France
!     -----------------------------------------------------------------

LSIMPH=.FALSE.
LTRAJPS=.FALSE.
LTRAJPST=.FALSE.
LSMOOTHD=.FALSE.
LSMOOTHA=.FALSE.
LSMOOTHB=.FALSE.
LCLOUDS=.FALSE.

LCVRASP=.FALSE.
LGWDSP=.FALSE.
LGWDSPNL=.FALSE.
LRAYSP=.FALSE.
LSTRASP=.FALSE.
LSTRASPN=.FALSE.
LVDIFSP=.FALSE.
LVDIFSPNL=.FALSE.
LRRMESSP=.FALSE.
LMELTTL=.FALSE.
LMELTNL=.FALSE.
LEVAPTL=.FALSE.
LTRAJRAIN=.FALSE.
LTRAJCOND=.FALSE.
LNEBCVPPKF=.FALSE.
DELTAH=0.3_JPRB
LCOLLECTL=.FALSE.
RMINEVP=10.0E-15
LSMOOTHEVP=.TRUE.
LPROCLDTL=.FALSE.
RHCRIT1S=0.7_JPRB
RHCRIT2S=0.7_JPRB
LPROCLDTL=.FALSE.
LMICROTL=.FALSE.
LCVRASBM=.FALSE.
TADJ=70.0_JPRB
LCONSENTH=.FALSE.
LAPPROXCONV=.TRUE.
LRCOEF=.FALSE.
LTLADDIA=.FALSE.
LGLOBRAD=.FALSE.
RMODULQCPROG=0.75_JPRB
LIGELREPRO=.TRUE.

!*    1.2.1  Set default values for ECMWF physics package
!            --------------------------------------------

LEPHYS=.FALSE.
LAGPHY=.TRUE.

LECOND=.FALSE.
LEPCLD=.FALSE.
LECUMF=.FALSE.
LEDCLD=.FALSE.
LEEVAP=.TRUE.
LEGWDG=.FALSE.
LEGWWMS=.FALSE.
LEOZOC=.FALSE.
LEQNGT=.FALSE.
LERADI=.FALSE.
LERADS=.FALSE.
LESICE=.TRUE.
LESURF=.FALSE.
LEVDIF=.FALSE.
LEOCWA=.FALSE.
LEOCCO=.FALSE.
LEOCSA=.FALSE.
LEOCLA=.FALSE.
LEMETHOX=.FALSE.
LBUD23=.FALSE.
LBUDCYCLE=.FALSE.
LECURR=.FALSE.
LVDFTRAC=.TRUE.
LMFTRAC=.TRUE.
LMFSCAV=.FALSE.
LERAIN=.FALSE.
LEMWAVE=.FALSE.
LEGBRAD=.FALSE.
LECLIPQT0=.FALSE.
LECLIPCLDT0=.FALSE.
LE4ALB=.FALSE.
LEVGEN=.FALSE.
LESSRO=.FALSE.
LELAIV=.TRUE.
LECTESSEL=.FALSE.
RLAIINT=0.0_JPRB
LEFLAKE=.FALSE.
LEOCML=.FALSE.
LEOBC=.FALSE.
LEOBCICE=.FALSE.
LOCMLTKE=.FALSE.
LESMOSS=.FALSE.
LESN09=.FALSE.
LDUCTDIA=.FALSE.
RTHRFRTI=0.0_JPRB
RCIMIN=-1.0_JPRB
NPHYINT=0
LESMOS=.FALSE.
NPRACCL=21600
LERAINGG=.FALSE.
LSPCRM=.FALSE.

!-------------------------------------------------------
! pressure above which cloud scheme is not called
RCLDTOPP=100.0_JPRB

!--------------------------------------------------------

!*     1.2.2  Set-up linearized physical parametrization of ECMWF
!             ---------------------------------------------------

LETRAJP = .FALSE.
LETRAJPT= .FALSE.
LERADI2 = .FALSE.
LERADS2 = .FALSE.
LERADSW2= .FALSE.
LERADLW2= .FALSE.
LERADN2 = .FALSE.
LERADFL2= .FALSE.
LEDCLD2 = .FALSE.
LENCLD2 = .FALSE.
LEVAPLS2= .FALSE.
LEVDIF2 = .FALSE.
LEGWDG2 = .FALSE.
LECUMF2 = .FALSE.
LECOND2 = .FALSE.
LEGWWMS2= .FALSE.
LEQNGT2 = .FALSE.
LESURF2 = .FALSE.

LEKPERT = .FALSE.
LEKPERTS= .FALSE. 
LNCLIN  = .FALSE.
LREGCL  = .FALSE.
LREGWWMS = .FALSE.
LREGSF  = .FALSE.
LWLCLHR = .FALSE.
LTRACLNPH = .TRUE.

! No perturbation of surface arrays
LENOPERT = .TRUE.

! Frequency of calling TL/AD of LW radiation
NLWFR = 4

! Using few shorter loops inside of nproma-loop for TL/AD of LW radiation
LOPTLWPR = .FALSE.
NLOOPLW  = 3

!     LOGICAL FOR THE VERT DIFF SCHEME VDIFLCZ USED IN CONF 601

LSPHLC  = .FALSE.
LVDFLC  = .FALSE.
LVDFDS  = .TRUE.
LSDRLC  = .TRUE.
LSDRDS  = .FALSE.
LZMCON  = .TRUE.
LKEXP   = .TRUE.
ALPHA   = 3._JPRB
AH0     = 1000.0_JPRB
USTARL  = 0.5_JPRB
USTARS  = 0.2_JPRB
ALANDZ0 = 0.05_JPRB
ASEAZ0  = 0.0005_JPRB

NSTPW=2
!     NSTPW=30

LWCOU=.FALSE.
LWCOU2W=.FALSE.
LWCUR=.FALSE.
LWSTOKES=.FALSE.
LWFLUX=.FALSE.

!  Setup for 1.5 degree resolution wave model
!  This is obsolete since the introduction of wvwaminit
!  in suwcou (RNORTW,RSOUTW,RDEGREW should be removed from namelist
!  naephy but they are still produced by prepIFS when generating
!  ifsnam.fc.h for a forecast run).

RNORTW= 81.0_JPRB
RSOUTW=-81.0_JPRB
RDEGREW=1.5_JPRB

! Boundaries of the ocean mixed layer domain

RSOUTHML=-40.0_JPRB
RNORTHML=40.0_JPRB
RWESTML=0.0_JPRB
REASTML=360.0_JPRB

INVML=.FALSE.

!  Default setup for wave model
LWFRSTIME=.TRUE.
NADV_WAVE=0

! 3D diagnostics
LEDR=.FALSE.

! Pointer for tendency diagnostics 
NTEND_DIAG_POS=-1
NTEND_DIAG_FREQ_RESET=10800

!        1.3 Modify default values according to LECMWF

IF (LECMWF) THEN
  LEPCLD=.TRUE.
  LEVDIF=.TRUE.
  LEOCWA=.TRUE.
  LEOCCO=.TRUE.
  LEOCSA=.TRUE.
  LEOCLA=.TRUE.
  LESURF=.TRUE.
  LECOND=.FALSE.
  LECUMF=.TRUE.
  LMFSCAV=.TRUE.
  LEEVAP=.TRUE.
  LEGWDG=.TRUE.
  LEGWWMS=.TRUE.
  LEOZOC=.TRUE.
  LEQNGT=.TRUE.
  LERADI=.TRUE.
  LERADS=.TRUE.
  LESICE=.TRUE.
  LEDCLD=.TRUE.
  NCO2CLIMYY1=0_JPIM
  NCO2CLIMYY2=0_JPIM
  NCO2CLIMN1=0_JPIM
  NCO2CLIMN2=0_JPIM
  NCO2CLIMFRQ=0_JPIM
  LEMETHOX=.TRUE.
  LE4ALB=.TRUE.
  LEVGEN=.TRUE.
  LESSRO=.TRUE.
  LELAIV=.TRUE.
  LECTESSEL=.TRUE.
  LEAGS=.FALSE.
  RLAIINT=0.0_JPRB
  LEFLAKE=.TRUE.
  LEOCML=.FALSE.
  LEOBC=.FALSE.
  LEOBCICE=.FALSE.
  LEOCLAKE=.FALSE.
  LEOLAKESST=.TRUE.
  LOCMLTKE=.FALSE.
  IF (LOCMLTKE) THEN
    LEOCWA=.FALSE.
    LEOCML=.FALSE.
  ENDIF
  LESMOSS=.FALSE.
  LESN09=.TRUE.
  RSOUTHML=-40._JPRB
  RNORTHML=40._JPRB
  RWESTML=0._JPRB
  REASTML=360._JPRB
  INVML=.FALSE.
  IF(NCONF == 1.OR.NCONF == 302) THEN
    LEPHYS=.TRUE.
  ENDIF
  IF(NCONF == 131) THEN
    LERADI2 = .TRUE.
    LERADS2 = .TRUE.
    LEVDIF2 = .TRUE.
    LEGWDG2 = .TRUE.
    LECUMF2 = .TRUE.
    LECOND2 = .TRUE.
    IF(L131TL) THEN
      LEPHYS=.TRUE.
      LECOND=.TRUE.
      LEPCLD=.FALSE.
    ENDIF
    LSPHLC=.TRUE.
    LVDFLC=.TRUE.
    LSDRLC=.TRUE.
    LZMCON=.TRUE.
    LKEXP =.TRUE.
  ENDIF
  IF (NCONF == 401 .OR. NCONF == 501) THEN
    LEPHYS = .TRUE.
    LECOND = .TRUE.
    LEPCLD = .FALSE.

    LETRAJP = .TRUE.
    LERADI2 = .TRUE.
    LERADS2 = .TRUE.
    LEVDIF2 = .TRUE.
    LEGWDG2 = .TRUE.
    LECUMF2 = .TRUE.
    LECOND2 = .TRUE.
  ENDIF

  IF(NCONF == 601.OR.NCONF == 801) THEN

!      Full physics when computing the trajectory

    LEPHYS=.TRUE.

!      Simple scheme for TL and ADJ

    LSPHLC  = .TRUE.
    LVDFLC  = .TRUE.
    LVDFDS  = .TRUE.
    LSDRLC  = .TRUE.
    LSDRDS  = .TRUE.
    LZMCON  = .TRUE.
    LKEXP   = .TRUE.
    ALPHA   = 3._JPRB
    AH0     = 1000.0_JPRB
    USTARL  = 0.5_JPRB
    USTARS  = 0.2_JPRB
    ALANDZ0 = 0.05_JPRB
    ASEAZ0  = 0.0005_JPRB

  ENDIF
  NPHY = JPHYEC
ELSE
  IF (LR3D.OR.(NCONF == 701)) THEN
    LAGPHY=.FALSE.
    LCVCAS=.TRUE.
    LCVDD=.TRUE.
    LCVLIS=.TRUE.
    LCVPP=.TRUE.
    LCVRA=.TRUE.
    LFGEL=.TRUE.
    LGWD=.TRUE.
    LHMTO=.TRUE.
    LMPHYS=.TRUE.
    LNEBN=.TRUE.
    LNEBNXR=.FALSE.
    LNEIGE=.TRUE.
    LRAY=.TRUE.
    LRAYLU=.TRUE.
    LRAYPL=.TRUE.
    LRRMES=.TRUE.
    LSFHYD=.TRUE.
    LSOLV=.TRUE.
    LSTRA=.TRUE.
    LTHERMO=.TRUE.
    LVDIF=.TRUE.
    NPHY = JPHYMF
    IF ( L3MT.OR.LGPCMT.OR.LSTRAPRO ) NPHY = JPBP002
    IF(LAROME) THEN
!     Switch off MF physics in AROME forecast:
      LCVRA=.FALSE.
      LGWD=.FALSE.
      LGWDC=.FALSE.
      LNEBCO=.FALSE.
      LNEBN=.FALSE.
      LNEBR=.FALSE.
      LOZONE=.FALSE.
      LRAY=.FALSE.
      LRAYLU=.FALSE.
      LRAYPL=.FALSE.
      LRAYFM=.FALSE.
      LRAYFM15=.FALSE.
      LRRMES=.FALSE.
      LSFHYD=.FALSE.
      LSNV=.FALSE.
      LSOLV=.FALSE.
      LFGEL=.FALSE.
      LSTRA=.FALSE.
      LSTRAS=.FALSE.
      LVDIF=.FALSE.
      !initialisation of AROME's physic ones
      LMPA=.TRUE.
      LMICRO=.FALSE.
      LTURB=.FALSE.
      LMSE=.FALSE.
      LKFBCONV=.FALSE.
      LUSECHEM=.FALSE.
      LKFBD=.FALSE.
      LKFBS=.FALSE.
      LMFSHAL=.FALSE.
      LUSECHEM=.FALSE.
      LORILAM=.FALSE.
      LRDUST=.FALSE.
      LINITCHEM=.FALSE.
      LINITDUST=.FALSE.
      LINITORILAM=.FALSE.
      LRDEPOS=.FALSE.
      LRCO2=.FALSE.
      NPHY = JPHYARO
      IF (LSCREEN .OR. (NCONF == 131) .OR. LOBSC1 .OR. &
          & ((NCONF == 001) .AND. (CNMEXP(1:4) == 'TRAJ')) ) THEN
        LSOLV=.TRUE.
        LFGEL=.TRUE.
      ENDIF
    ENDIF
  ENDIF
ENDIF

!     ------------------------------------------------------------------

!*       2.    Modify default values.
!              ----------------------

CALL POSNAM(NULNAM,'NAMPHY')
READ(NULNAM,NAMPHY)
! Work-around for PGI compiler bug
YRPHY%CGMIXLEN=CGMIXLEN
YRPHY%CGTURS=CGTURS
YRPHY%CGTRG=CGTRG

!  Control of NCALLRAD
IF ((NCALLRAD /= 0).AND.(NCALLRAD /= 2)) THEN
  WRITE(NULOUT,'("SU0PHY: NCALLRAD MUST BE 0 OR 2")')
  WRITE(NULOUT,'("SU0PHY: NCALLRAD=",I2)')NCALLRAD
  CALL ABOR1('SUECRAD: NCALLRAD MUST BE 0 OR 2')
ENDIF

CALL POSNAM(NULNAM,'NAMARPHY')
READ(NULNAM,NAMARPHY)
! Work-around for PGI compiler bug
YRARPHY%CCOUPLING=CCOUPLING
IF(LMSE .AND. .NOT.(LSCREEN .OR. (NCONF == 131) .OR. LOBSC1 .OR. &
          & ((NCONF == 001) .AND. (CNMEXP(1:4) == 'TRAJ')) )  ) THEN 
  LSOLV=.FALSE.
  LFGEL=.FALSE.
  LSNV=.FALSE.
  LVGSN=.FALSE.
  WRITE(NULOUT,'('' INFO -old isba-lsolv,lfgel,lsnv,lvgsn- reset to .F. '', &
                 &'' when using lground i.e. surfex '')')
ENDIF

IF(LSFXLSM.AND..NOT.LMSE) THEN
  WRITE(NULOUT,FMT='('' LMSE/LSFXLSM switches not COHERENT : LMSE='',L5,&
   & '' LSFLSM='',L5)') LMSE,LSFXLSM
    CALL ABOR1(' SU0PHY: LSFXLSM/LMSE')
ENDIF

CALL POSNAM(NULNAM,'NAEPHY')
READ(NULNAM,NAEPHY)

! Make sure the adiabatic model will initialize the surface.
! Indeed, there can be a surface scheme in the adiabatic atmospheric model.
IF (.NOT.(LMPHYS.OR.LEPHYS)) LRAY=.FALSE.

NNOGW=0
IF(LEGWWMS) NNOGW=2
NUVP=0
IF(LUVPOUT) NUVP=2
NAEROUT=0
IF(LAEROUT) NAEROUT=17
IF(LR2D) THEN
  LREASUR=.FALSE.
ENDIF
IF(LAQUA) THEN
  LREASUR=.TRUE. 
  WRITE(NULOUT,'('' INFO - LREASUR RESET TO .TRUE. FOR LAQUA '')')
ENDIF
IF(.NOT.(LEPHYS.OR.LMPHYS.OR.LHELDSUAREZ.OR.LAQUA)) THEN
  LAGPHY=.FALSE.
  LSLPHY=.FALSE.
  WRITE(NULOUT,'('' INFO - LSLPHY RESET TO .FALSE. '')')
ENDIF
IF((.NOT.LEPHYS).AND.LEPCLD) THEN
  ! LEPCLD must be off when LEPHYS=.F. 
  ! (to set properly thermodynamic activity for GFL fields)
  LEPCLD=.FALSE.
  WRITE(NULOUT,'('' WARNING - LEPCLD RESET TO .FALSE. '')')
ENDIF
IF(LEPCLD) THEN
  LECOND=.FALSE.
ENDIF
IF(LAGPHY.AND.NDPSFI /= 0) THEN
  NDPSFI=0
  WRITE(NULOUT,'('' WARNING - NDPSFI RESET TO 0 '')')
ENDIF

IF(LWCOU2W .AND. LWCOU) THEN
  LWSTOKES=.TRUE.
  IF(LOCMLTKE) LWFLUX=.TRUE.  ! currently the only reason to return the wave fluxes is if LOCMLTKE is true
ENDIF

IF(.NOT. LWSTOKES) THEN
  LEOCLA=.FALSE.
ENDIF

CALL POSNAM(NULNAM,'NAPHLC')
READ(NULNAM,NAPHLC)

CALL POSNAM (NULNAM,'NAMTRAJP')
READ (NULNAM,NAMTRAJP)

! To run 4D-Var in bit reproducible mode, computation of cloudy
! effects on LW radiation must be done for all levels, i.e.
! re-setting LWLCLHR to false
IF (LREPRO4DVAR) THEN
  LWLCLHR = .FALSE.
ENDIF

CALL POSNAM(NULNAM,'NAMSIMPHL')
READ(NULNAM,NAMSIMPHL)

CALL POSNAM(NULNAM,'NAMRCOEF')
READ(NULNAM,NAMRCOEF)

!-------------------------------------------------
! Initialize profile extractions for the Single Column Model .
!-------------------------------------------------

CALL SUSCM(KULOUT)

!     ------------------------------------------------------------------

!*       3.    Do tests of consistency.
!              ------------------------

IERR=0

! * Test that adequate physics is activated when at least one of the
!   options LRETCFOU, LWRTCFOU, LRCOEF,is set to .TRUE.
IF( LWRTCFOU .AND. ((.NOT.LMPHYS).OR.LEPHYS.OR.LAGPHY) ) THEN
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: options ',&
   & 'LWRTC, LWRTCFOU ',&
   & 'require the following options for physics:'
  WRITE(KULOUT,'(1X,A)') '         - LMPHYS=.TRUE. '
  WRITE(KULOUT,'(1X,A)') '         - LEPHYS=.FALSE. '
  WRITE(KULOUT,'(1X,A)') '         - LAGPHY=.FALSE. '
  IF(.NOT.LRAYSP) THEN
    WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: option ',&
     & ' LWRTCFOU ',&
     & 'require the following option for simplified physics:'
    WRITE(KULOUT,'(1X,A)') '         - LRAYSP=.TRUE. '
  ENDIF
ENDIF
IF( LRETCFOU .AND. ((.NOT.(LMPHYS.OR.LSIMPH)).OR.LEPHYS.OR.LAGPHY) ) THEN
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: option ',&
   & ' LRETCFOU ',&
   & 'require the following options for physics:'
  WRITE(KULOUT,'(1X,A)') '         - LMPHYS=.TRUE. or LSIMPH=.TRUE.'
  WRITE(KULOUT,'(1X,A)') '         - LEPHYS=.FALSE. '
  WRITE(KULOUT,'(1X,A)') '         - LAGPHY=.FALSE. '
ENDIF
IF( LRCOEF .AND. ((.NOT.LMPHYS).OR.LEPHYS.OR.LAGPHY) ) THEN
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: options ',&
   & 'LRCOEF ',&
   & 'require the following options for physics:'
  WRITE(KULOUT,'(1X,A)') '         - LMPHYS=.TRUE. '
  WRITE(KULOUT,'(1X,A)') '         - LEPHYS=.FALSE. '
  WRITE(KULOUT,'(1X,A)') '         - LAGPHY=.FALSE. '
  IF(.NOT.LRAYSP) THEN
    WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: options ',&
     & 'LRCOEF ',&
     & 'require the following option for simplified physics:'
    WRITE(KULOUT,'(1X,A)') '         - LRAYSP=.TRUE. '
  ENDIF
ENDIF

! * Test that options LRETCFOU, LWRTCFOU are set to .FALSE.
!   when at least LRCOEF=.TRUE.
IF( (LRCOEF) .AND. (LRETCFOU.OR.LWRTCFOU) ) THEN
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: options ',&
   & 'LRCOEF ',&
   & 'require that:'
  WRITE(KULOUT,'(1X,A)') '         - LRETCFOU=.FALSE. '
  WRITE(KULOUT,'(1X,A)') '         - LWRTCFOU=.FALSE. '
ENDIF

! * Use NDPSFI=1 when not available or inconsistent with some other options?
IF(LGWADV .AND. (NDPSFI==1)) THEN
  ! * these two options actually can run together on an informatic
  !   point of view, but the current assumptions done with LGWADV=T
  !   are that a particle which is on the Earth surface remains
  !   on the Earth surface; this is equivalent to assume that "etadot_surf"
  !   is always zero. This condition is satisfied when NDPSFI=0
  !   but not when NDPSFI=1 which gives a non-zero value to "etadot_surf".
  !   So one forbids combination "LGWADV .AND. (NDPSFI==1)" which leads
  !   to inconsistencies in the model at the surface.
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A,A,A)') ' SU0PHY: options ',&
   & 'NDPSFI=1 ',&
   & 'require that:'
  WRITE(KULOUT,'(1X,A)') '         - LGWADV=.FALSE. '
ENDIF

! Test for Super-Parametrization scheme
IF (LSPCRM) THEN
  IF (CRMBUFSIZE == 0) THEN
    IERR=IERR+1
    WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
    WRITE(KULOUT,'(1X,A,A,A)') ' When asking for super-parametrization ', &
   &  'make sure your code is compilled ', &
   &  'with SPCRM option for cpp pre-processing. '
  ENDIF
  IF (.NOT. LEPHYS) THEN
    IERR=IERR+1
    WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
    WRITE(KULOUT,'(1X,A,A)') ' The super-parametrization package ', &
   &  'is only available for ECMWF physics so far!'
  ENDIF
  WRITE(KULOUT,'(1X,A,A)') '*** SUPER-PARAMETRIZATION CRM ',&
   & 'SCHEME IS ACTIVATED. *** '
  WRITE(KULOUT,'(1X,A)') &
   & 'NOTE: All the other moist processes are turned off then.'
ENDIF


! TESTS FOR ALARO-0 (prognostic convection)
IF (LCVPRO) THEN
  LCDDPRO=.TRUE.
  IF (NCONF /= 1)THEN
    WRITE(KULOUT,'(1X, A)') 'WARNING: LCVPRO requires NCONF=1'
    LCVPRO=.FALSE.
    LCDDPRO=.FALSE.
  ENDIF
ENDIF
IF (LENTCH.AND.((.NOT.LCVPRO).OR.(.NOT.LCDDPRO))) THEN
  LENTCH=.FALSE.
  WRITE(KULOUT,'(1X, A)') 'WARNING: LENTCH requires BOTH LCVPRO AND LCDDPRO TRUE'
ENDIF
IF (L3MT.AND.LCOMOD) THEN
    WRITE(UNIT=KULOUT,FMT='(A)') 'IF L3MT REQUIRES LCOMOD=F'
    CALL ABOR1('3MT && LCOMOD settings inconsistency')
ENDIF

! TESTS FOR ALARO (TKE scheme)
IF (LCOEFKTKE.AND.(.NOT.LPTKE)) THEN
  ! * When emulated TKE is required, the (TKE) solver must be active too
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: LCOEFKTKE=.T. has only meaning when LPTKE=.T.'
ENDIF
IF (LCOEFK_TOMS.AND.(.NOT.LCOEFKTKE)) THEN
  ! * TOM terms can be computed only with full TKE scheme
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: TOMs can be activated only in TOUCANS (LCOEFKTKE=.T.)'
ENDIF
IF (LCOEFK_PTTE.AND.(.NOT.LCOEFKTKE)) THEN
  ! * Prognostic TTE scheme only in TOUCANS
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: PTTE can be activated only in TOUCANS (LCOEFKTKE=.T.)'
ENDIF
IF (LCOEFK_TOMS.AND.( (TRIM(CGMIXLEN) /= 'EL0').AND. &
   & (TRIM(CGMIXLEN) /= 'EL1').AND.(TRIM(CGMIXLEN) /= 'EL2').AND. &
   & (TRIM(CGMIXLEN) /= 'EL3').AND.(TRIM(CGMIXLEN) /= 'EL4').AND. &
   & (TRIM(CGMIXLEN) /= 'EL5') )) THEN
  ! * TOM terms can be computed only with a TKE mixing length
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: TOMs can be activated only with TKE-type mixing lengths or EL0 '
ENDIF

IF (LCOEFKTKE.AND.LCOEFK_PTTE.AND.(.NOT.LCOEFK_FLX)) THEN
  ! * When prognostic TTE source terms must be computed from Fluxes
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: LCOEFK_PTTE=.T. needs LCOEFK_FLX=.T.'
ENDIF

IF (LCOEFK_RIS.AND.LCOEFK_MSC) THEN
  ! * non precipitating convection should be computed by one method only
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') &
   & ' SU0PHY: LCOEFK_RIS=.T. needs LCOEFK_MSC=.F. or the opposite'
ENDIF

! * Use simplified physics with LMPA=T?
IF(LMPA.AND.LSIMPH) THEN
  ! * Simplified physics is not consistent with AROME physics
  !   concerning most of the physical parameterizations.
!  IERR=IERR+1
!  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') ' SU0PHY: LMPA and LSIMPH both set to T.'
ENDIF

! * Choice for shallow convection in Arome
IF(LMPA.AND.LKFBCONV.AND.LKFBS.AND.LMFSHAL) THEN
  ! * Only one shallow convection scheme should be switch on
  IERR=IERR+1
  WRITE(KULOUT,'(1X,A,I3,A)') ' ! SU0PHY: ERROR NR ',IERR,' !!!'
  WRITE(KULOUT,'(1X,A)') ' SU0PHY: LKFBS and LMFSHAL cannot be both to T.'
ENDIF

IF (IERR >= 1) THEN
  CALL FLUSH(KULOUT)
  CALL ABOR1(' SU0PHY: ABOR1 CALLED')
ENDIF

!     ------------------------------------------------------------------

!*       4.    Compute some YOMRCOEF dimensions.
!              ---------------------------------

IF (LRCOEF) THEN
  NG3SR=17
  NGMTR=1
ELSE
  NG3SR=0
  NGMTR=0
ENDIF

NLATWR=0
NLATRD=0

!     ------------------------------------------------------------------

!*       5.    Print final values.
!              -------------------

WRITE(UNIT=KULOUT,FMT='('' COMMON YOMPHY '')')
WRITE(UNIT=KULOUT,FMT='('' LMPHYS= '',L5,'' LREASUR = '',L5)')LMPHYS,LREASUR
WRITE(UNIT=KULOUT,FMT='('' LCONDWT='',L5,'' LCVPP = '',L5,&
 & '' LCVPPKF = '',L5,'' LEDKF = '',L5,'' LEDMFI = '',L5,'' LCVGQKF = '',L5,&
 & '' LNEIGE = '',L5,'' LRNUMX = '',L5,'' LRNUEXP = '',L5,'' LACPANMX = '',L5,&
 & '' LCLSATUR = '',L5,'' LVOIGT = '',L5,'' LVFULL = '',L5,&
 & '' LCVDD = '',L5,'' LCAPE= '',L5,'' LCVGQ= '',L5,&
 & '' LCVGQD= '',L5,'' LCVGQM= '',L5,'' LCVGQP= '',L5,&
 & '' LCVLIS = '',L5,'' LCVCAS= '',L5,'' LO3ABC= '',L5,'' LO3FL= '',L5,  &
 & '' LECSHAL = '',L5,'' LECDEEP= '',L5, &
 & '' LAEROSEA = '',L5,'' LAEROLAN = '',L5,'' LAEROSOO = '',L5, &
 & '' LAERODES = '',L5,'' LAEROVOL = '',L5,'' LAEROSUL = '',L5, &
 & '' LRELAXT  = '',L5,'' LRELAXW  = '',L5,&
 & '' LSLC = '',L5,'' LRRGUST= '',L5, &
 & '' LNEWD = '',L5,'' LGLT= '',L5,'' LDIFCONS= '',L5, &
 & '' LECT = '',L5,'' LEFB = '',L5,'' LECTFL = '',L5,'' LECTFL0 = '',L5,&
 & '' LPBLE = '',L5,'' LCVPGY= '',L5, &
 & '' LPTKE= '',L5,'' L3MT= '',L5 ,'' LGPCMT= '',L5 ,'' LACDIFUS = '',L5,'' LZ0HSREL= '',L5, &
 & '' LFLUSO= '',L5, '' L2MICRO= '',L5 ,&
 & '' LECTQ1= '',L5,'' LECTREP= '',L5, &
 & '' LPROCLDTL= '',L5, '' LGLACIERS= '',L5, &
 & '' LCOEFKTKE= '',L5,'' LAFGD_A= '',L5, &
 & '' LCOEFK_TOMS= '',L5,'' LCOEFK_THS1= '',L5, '' LCOEFKSURF= '',L5, &
 & '' LCOEFK_PL= '',L5,'' LCOEFK_PTTE= '',L5,'' LCOEFK_MSC= '',L5,&
 & '' LCOEFK_RIS= '',L5,'' LCOEFK_RIH= '',L5,'' LCOEFK_F1= '',L5,&
 & '' LCOEFK_FLX= '',L5,'' LCOEFK_SCQ= '',L5,'' LCOEFK_ML= '',L5)')&
 & LCONDWT,LCVPP,LCVPPKF,LEDKF,LEDMFI,LCVGQKF,LNEIGE,&
 & LRNUMX,LRNUEXP,LACPANMX,LCLSATUR,LVOIGT,LVFULL,LCVDD,&
 & LCAPE,LCVGQ,LCVGQD,LCVGQM,LCVGQP,LCVLIS,LCVCAS,LO3ABC,LO3FL, &
 & LECSHAL,LECDEEP,LAEROSEA,LAEROLAN,LAEROSOO, &
 & LAERODES,LAEROVOL,LAEROSUL,LRELAXT,LRELAXW,LSLC,LRRGUST,LNEWD,LGLT,&
 & LDIFCONS,LECT,LEFB,LECTFL,LECTFL0,LPBLE,LCVPGY,LPTKE,L3MT,LGPCMT,&
 & LACDIFUS,LZ0HSREL,LFLUSO, L2MICRO,&
 & LECTQ1,LECTREP,LPROCLDTL,LGLACIERS,LCOEFKTKE,LAFGD_A,&
 & LCOEFK_TOMS,LCOEFK_THS1,LCOEFKSURF,LCOEFK_PL,&
 & LCOEFK_PTTE,LCOEFK_MSC,LCOEFK_RIS, LCOEFK_RIH,LCOEFK_F1,LCOEFK_FLX,&
 & LCOEFK_SCQ,LCOEFK_ML
WRITE(UNIT=KULOUT,FMT='('' LCVRA = '',L5 ,'' LFPCOR = '',L5&
 & ,'' LNOIAS = '',L5 &
 & ,'' LGWD = '',L5,'' LHMTO = '',L5,'' LRAY = '',L5 &
 & ,'' LSFHYD = '',L5,'' LSTRA = '',L5,'' LTHERMO = '',L5,/&
 & ,'' LVDIF = '',L5,'' LNEBCO = '',L5,'' LNEBECT = '',L5,'' LNEB_FP = '',L5,/&
 & ,'' LRRMES = '',L5,'' LOZONE = '',L5,'' LNEBR = '',L5,/&
 & ,'' LSNV = '',L5,'' LSOLV = '',L5,'' LFGEL = '',L5,/&
 & ,'' LVGSN ='',L5,/&
 & ,'' LNEBN = '',L5,'' LNEBNXR = '',L5,'' LQXRTGH = '',L5,'' LSTRAS = '',L5,/&
 & ,'' LHUCN = '',L5,'' LGWDC = '',L5,'' LRAYFM = '',L5,'' LRAYFM15 = '',L5,/&
 & ,'' LRMU0M = '',L5,'' LRAYLU = '',L5,'' LRPROX = '',L5 /&
 & ,'' LRSTAER = '',L5,'' LRTPP = '',L5,'' LRAYPL = '',L5 &
 & )')&
 & LCVRA,LFPCOR,LNOIAS,LGWD,LHMTO,LRAY,LSFHYD,LSTRA,LTHERMO,LVDIF,LNEBCO,&
 & LNEBECT,LNEB_FP,LRRMES,LOZONE,LNEBR,LSNV,LSOLV,LFGEL,LVGSN,&
 & LNEBN,LNEBNXR,LQXRTGH,LSTRAS,LHUCN,LGWDC,&
 & LRAYFM,LRAYFM15,LRMU0M,LRAYLU,LRPROX,LRSTAER,LRTPP,LRAYPL
IF ( NRAY == 1 ) THEN
  WRITE(UNIT=KULOUT,FMT='('' LREWS  = '',L5,'' LRSTAB = '',L5)') LREWS,LRSTAB
  WRITE(UNIT=KULOUT,FMT='('' LRMIX  = '',L5,'' LRTDL  = '',L5)') LRMIX,LRTDL
ELSE
  WRITE(UNIT=KULOUT,FMT='('' LRTRUEBBC = '',L5,'' LRTRUEDIR = '',L5)') LRTRUEBBC,LRTRUEDIR
  IF ( NSORAYFR < 0 ) THEN
    WRITE(KULOUT,'('' NSORAYFR (to be modified in SUDYN) = '',I5)') &
     & NSORAYFR   
  ELSE 
    WRITE(KULOUT,'('' NSORAYFR = '',I5)') NSORAYFR
  ENDIF
  IF ( NTHRAYFR < 0 ) THEN
    WRITE(KULOUT,'('' NTHRAYFR (to be modified in SUDYN) = '',I5)') &
     & NTHRAYFR
  ELSE
    WRITE(KULOUT,'('' NTHRAYFR = '',I5)') NTHRAYFR
  ENDIF
ENDIF
WRITE(UNIT=KULOUT,FMT='('' NBITER = '',I2,'' NDPSFI = '',I2,'' NPHYREP = '',I2)') &
 & NBITER,NDPSFI,NPHYREP
WRITE(UNIT=KULOUT,FMT='('' NOIR = '',I2,'' NRAY = '',I1)') NOIR,NRAY
WRITE(UNIT=KULOUT,FMT='('' NRAUTOEV= '',I2)') NRAUTOEV
WRITE(UNIT=KULOUT,FMT='('' NPHYINT = '',I2)') NPHYINT
WRITE(UNIT=KULOUT,FMT='('' NITERFL = '',I2)') NITERFL
WRITE(UNIT=KULOUT,FMT='('' NCALLRAD= '',I2)') NCALLRAD
WRITE(UNIT=KULOUT,FMT='('' LWINDFARM  = '',L5)') LWINDFARM
WRITE(UNIT=KULOUT,FMT='('' NWINDFARM  = '',I2)') NWINDFARM
WRITE(UNIT=KULOUT,FMT=*) 'LDAYD=',LDAYD

WRITE(UNIT=KULOUT,FMT='('' - - - - - - - - - -'')')
WRITE(UNIT=KULOUT,FMT='('' COMMON YOMPHY'')')
WRITE(UNIT=KULOUT,FMT='('' - - - - - - - - - -'')')
WRITE(UNIT=KULOUT,FMT='(&
 & '' LAJUCV  = '',L5,'' LCVRAV3 = '',L5, &
 & '' LNEBGR  = '',L5,'' LNEBGY  = '',L5 &
 & )') LAJUCV,LCVRAV3, LNEBGR, LNEBGY
WRITE(UNIT=KULOUT,FMT='(&
 & '' LMLH    = '',L5,'' LNODIFQC= '',L5,'' LDIFCEXP= '',L5, &
 & '' LSQRML  = '',L5,'' LNCVPGY = '',L5 &
 & )') LMLH, LNODIFQC, LDIFCEXP, LSQRML, LNCVPGY

WRITE(UNIT=KULOUT,FMT='('' - - - - - - - - -'')')
WRITE(UNIT=KULOUT,FMT='('' MICROPHYSICS KEY '')')
WRITE(UNIT=KULOUT,FMT='('' - - - - - - - - -'')')
WRITE(UNIT=KULOUT,FMT='(  '' LPROCLD = '',L5 &
 &,'' LEVAPP  = '',L5,'' LCOLLEC = '',L5,'' LSMITH_CDEV = '',L5 &
 &,'' LADJCLD  = '',L5,'' LSSD = '',L5,'' LSMOOTHMELT='',L5)')&
 &LPROCLD,LEVAPP,LCOLLEC,LSMITH_CDEV,LADJCLD,LSSD,LSMOOTHMELT

WRITE(UNIT=KULOUT,FMT='(  '' LSEDSTA = '',L5 &
 &,'' LSEDLAG  = '',L5,'' LSEDCL = '',L5,'' LFSVAR = '',L5 &
 &,'' LFSFIX  = '',L5,'' LA0MPS = '',L5,'' LARPMPS ='',L5)')&
 &LSEDSTA,LSEDLAG,LSEDCL,LFSVAR,LFSFIX,LA0MPS,LARPMPS

WRITE(UNIT=KULOUT,FMT='('' ALARO-0 cloud '')')
WRITE(UNIT=KULOUT,FMT='('' LSTRAPRO = '',L5 &
  &,'' LNEWSTAT = '',L5,'' LPHSPSH = '',L5  &
  &,'' LCAMOD = '',L5,'' LCOMOD = '',L5  &
  &,'' LSMTPS = '',L5 ,'' LSMNIMBT = '',L5 &
  &,'' LSMGCDEV = '',L5 ,'' LXRCDEV = '',L5,'' LRKCDEV = '',L5 &
  &,'' LNEBCV = '',L5 ,'' LNEBINS = '',L5  &
  &,'' NSMTBOT = '',I2,'' NSMDNEB = '',I2,'' NDIFFNEB = '',I2 &
  &,'' NPRAC = '',I2,'' NPRRI = '',I2 &
  &) ')LSTRAPRO,LNEWSTAT,LPHSPSH,LCAMOD,LCOMOD,LSMTPS, LSMNIMBT,&
  &    LSMGCDEV,LXRCDEV, &
  &    LRKCDEV,LNEBCV,LNEBINS,NSMTBOT,NSMDNEB,NDIFFNEB,NPRAC,NPRRI

WRITE(UNIT=KULOUT,FMT='('' ALARO-0 prognostic convection  '')')
WRITE(UNIT=KULOUT,&
  &FMT='('' LCVPRO ='',L1,'' LCDDPRO ='',L1,'' LSCMF ='',L1, &
      & '' LCDDEVPRO ='',L1,'' LENTCH ='',L1, &
      & '' LRCVOTT ='',L1,'' NIMELIT ='',I2)') &
  &    LCVPRO,LCDDPRO,LSCMF,LCDDEVPRO,LENTCH,LRCVOTT,NIMELIT

WRITE(UNIT=KULOUT,FMT='('' ALARO-1 prognostic convection  '')')
WRITE(UNIT=KULOUT,&
  &FMT='('' LCVCSD ='',L1,'' LNSDO ='',L1,'' LCDDCSD ='',L1, &
      & '' LCVSHCU, ='',L1,'' LUDEVOL ='',L1,'' LPEC ='',L1, &
      & '' NCLOMIX, ='',I2,'' NFSIG ='',I2)') &
  & LCVCSD,LNSDO,LCDDCSD,LCVSHCU,LUDEVOL,LPEC,NCLOMIX,NFSIG
WRITE(KULOUT,'('' LUSL='',L1,'' CGTRG='',A8)') &
   & LUSL,  TRIM(CGTRG)

WRITE(UNIT=KULOUT,FMT='('' COMMON YOMSIMPHL '')')
WRITE(UNIT=KULOUT,FMT='('' LSIMPH= '',L5,'' LTRAJPS = '',L5 &
 & ,'' LTRAJPST = '',L5 &
 & ,'' LSMOOTHD = '',L5,'' LSMOOTHA = '',L5,'' LSMOOTHB = '',L5 &
 & ,'' LCLOUDS = '',L5 )')&
 & LSIMPH,LTRAJPS,LTRAJPST,LSMOOTHD,LSMOOTHA, &
 & LSMOOTHB,LCLOUDS
WRITE(UNIT=KULOUT,FMT='('' LCVRASP = '',L5,'' LGWDSP = '',L5 &
 & ,'' LRAYSP = '',L5,'' LSTRASP = '',L5,'' LVDIFSP = '',L5 &
 & ,'' LVDIFSPNL = '',L5,'' LRRMESSP = '',L5,'' LSTRASPN = '',L5&
 & ,'' LPROCLDTL = '',L5,'' LMICROTL = '',L5,''LCOLLECTL = '',L5&
 & ,'' LEVAPTL   = '',L5,'' LMELTNL  = '',L5,''LMELTTL   = '',L5&
 & ,'' LSMOOTHEVP= '',L5,'' LTRAJRAIN= '',L5,''LTRAJCOND = '',L5&
 & ,'' LNEBCVPPKF= '',L5)')&
 & LCVRASP,LGWDSP,LRAYSP,LSTRASP,LVDIFSP,LVDIFSPNL,LRRMESSP,&
 & LSTRASPN, LPROCLDTL,LMICROTL,LCOLLECTL,LEVAPTL,LMELTNL,&
 & LMELTTL,LSMOOTHEVP,LTRAJRAIN,LTRAJCOND,LNEBCVPPKF
WRITE(UNIT=KULOUT,FMT='('' COMMON YOMRCOEF '')')
WRITE(UNIT=KULOUT,FMT='('' LRCOEF= '',L5 &
 & ,'' LTLADDIA = '',L5,'' LGLOBRAD = '',L5)')&
 & LRCOEF,LTLADDIA,LGLOBRAD
WRITE(UNIT=KULOUT,FMT=*) 'LGCHECKMV=',LGCHECKMV

! TEST OF CONSISTENCY FOR RADIATION SCHEMES

IF (LMPHYS) THEN
  IF((LRAY.AND.LRAYFM).OR.(LRAY.AND.LRAYFM15).OR.(LRAYFM15.AND.LRAYFM)) THEN
    WRITE(NULOUT,'('' WARNING - 2 RADIATION SCHEMES... '')')
    CALL ABOR1('SU0PHY: ABOR1 CALLED')
  ENDIF
  IF ( LRAY ) THEN
    IF ( NRAY < 1.OR.NRAY > 2 ) THEN
      WRITE(NULOUT,'(A)') 'NRAY must be 1 or 2!'
      CALL ABOR1(' SU0PHY: ABOR1 CALLED')
    ENDIF
    IF ( NRAY == 1.AND.LMPA ) THEN
      WRITE(NULOUT,'(A)') 'Old ACRANEB radiation not available in AROME!'
      WRITE(NULOUT,'(A)') 'Set NRAY=2 to use ACRANEB2 instead.'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF
    IF ( NRAY == 2.AND.LMPA.AND.(.NOT.LMSE) ) THEN
      WRITE(NULOUT,'(A)') &
       & 'ACRANEB2 radiation in AROME cannot run without LMSE!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF
    IF ( NRAY > 1.AND.NSORAYFR == 0 ) THEN
      WRITE(NULOUT,'(A)') 'NSORAYFR must not be 0!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF
    IF ( NRAY > 1.AND.LRAYLU.AND.NSORAYFR /= 1 ) THEN
      WRITE(NULOUT,'(A)') 'Solar intermittency not implemented for LRAYLU!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED') 
    ENDIF
    IF ( NRAY > 1.AND.NTHRAYFR == 0 ) THEN
      WRITE(NULOUT,'(A)') 'NTHRAYFR must not be 0!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF 
    IF ( NRAUTOEV < 0 ) THEN
      WRITE(NULOUT,'(A)') 'NRAUTOEV must not be negative!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ELSEIF ( NRAY == 1.AND.NRAUTOEV > 1 ) THEN
      WRITE(NULOUT,'(A)') 'For NRAY=1, NRAUTOEV must be 0 or 1!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF
    IF ( NRAY > 1.AND.NRAUTOEV == 0.AND.(.NOT.LRPROX) ) THEN
      WRITE(NULOUT,'(A)') 'ACRANEB2 statistical model (NRAY>1, NRAUTOEV=0)'
      WRITE(NULOUT,'(A)') 'must be used with LRPROX=.T.!'
      CALL ABOR1('SU0PHY: ABOR1 CALLED')
    ENDIF
  ENDIF
ENDIF

!     TESTS OF CONSISTENCY INSIDE YOMPHY

IF(LSTRAS.AND.LRNUMX)THEN
  WRITE(NULOUT,FMT='('' ACPLUIS AND LRNUMX ARE NOT COMPATIBLE''&
   & ,''      FOR THE MOMENT'')')
  CALL ABOR1('SU0PHY: ABOR1 CALLED')
ENDIF

IF((LSMGCDEV.AND.LXRCDEV).OR.(LSMGCDEV.AND.LRKCDEV).OR.&
 &(LXRCDEV.AND.LRKCDEV))THEN
  WRITE(NULOUT,FMT='('' WARNING - 2 CONDENSATION SCHEMES ...''&
   & ,'' Choose Smith-Gerard OR Xu-Randall-type OR Rasch-Kristjansson! '')')
  CALL ABOR1('SU0PHY: ABOR1 CALLED')
ENDIF

IF(LACPANMX.AND.(.NOT.LRNUMX))THEN
  WRITE(NULOUT,FMT='('' LACPANMX MUST BE USED WITH LRNUMX!'')')
  CALL ABOR1('SU0PHY: ABOR1 CALLED')
ENDIF

IF(LRNUEXP.AND.(.NOT.LRNUMX))THEN
  WRITE(NULOUT,FMT='('' LRNUEXP MUST BE USED WITH LRNUMX!'')')
  CALL ABOR1('SU0PHY: ABOR1 CALLED')
ENDIF

IF(LACPANMX.AND.LRNUEXP)THEN
  WRITE(NULOUT,FMT='('' LACPANMX AND LRNUEXP ARE MUTUALLY EXCLUSIVE!'')')
  CALL ABOR1('SU0PHY: ABOR1 CALLED')
ENDIF

!     RESULTING CLOUD OVERLAP MODE
IF (LMPHYS) THEN
  IF (LACPANMX) THEN
    WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACNPART : NEARLY MAXIMUM-RANDOM'
  ELSEIF (LRNUEXP) THEN
    WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACNPART : EXPONENTIAL-RANDOM'
  ELSEIF (LRNUMX) THEN
    WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACNPART : MAXIMUM-RANDOM'
  ELSE
    WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACNPART : RANDOM'
  ENDIF
  IF (LRAY.AND.NRAY==1) THEN
    IF (LRNUMX) THEN
      WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACRANEB : MAXIMUM-RANDOM'
    ELSE
      WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACRANEB : RANDOM'
    ENDIF
  ELSEIF (LRAY.AND.NRAY==2) THEN
    IF (LRNUEXP) THEN
      WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACRANEB2: EXPONENTIAL-RANDOM'
    ELSEIF (LRNUMX) THEN
      WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACRANEB2: MAXIMUM-RANDOM'
    ELSE
      WRITE(NULOUT,'(A)') 'CLOUD OVERLAP IN ACRANEB2: RANDOM'
    ENDIF
  ENDIF
ENDIF

WRITE(UNIT=KULOUT,FMT='('' COMMON YOMARPHY '')')
WRITE(UNIT=KULOUT,FMT='('' LMPA = '',L5, &
 & '' LMICRO = '',L5,'' LTURB = '',L5, &
 & '' LMSE = '',L5,'' NSURFEXCTL = '',I5,'' NSURFEX_ITER = '',I5,'' LKFBCONV = '',L5,&
 & '' LKFBD = '',L5,'' LKFBS = '',L5,&
 & '' LMFSHAL = '',L5,&
 & '' LUSECHEM = '',L5,'' LORILAM = '',L5,'' LRDUST = '',L5,&
 & '' LINITCHEM = '',L5,'' LINITORILAM = '',L5,'' LINITDUST = '',L5,&
 & '' LRDEPOS = '',L5,'' LRCO2 = '',L5,'' LMDUST = '',L5)')&
 & LMPA,LMICRO,LTURB,LMSE,NSURFEXCTL,NSURFEX_ITER,LKFBCONV,LKFBD,LKFBS,LMFSHAL,LUSECHEM,&
 & LORILAM,LRDUST,LINITCHEM,LINITORILAM,LINITDUST,LRDEPOS,LRCO2,LMDUST


WRITE(UNIT=KULOUT,FMT='('' COMMON YOEPHY '')')
WRITE(UNIT=KULOUT,FMT='('' LEPHYS = '',L5, &
 & '' LECOND = '',L5,'' LECUMF = '',L5 &
 & )')&
 & LEPHYS,LECOND,LECUMF
WRITE(UNIT=KULOUT,FMT='('' LECLIPQT0 = '',L5,'' LECLIPCLDT0 = '',L5)')&
 & LECLIPQT0, LECLIPCLDT0
WRITE(NULOUT,'("RCLDTOPP=",F10.2)') RCLDTOPP
WRITE(UNIT=KULOUT,FMT='('' LEDCLD = '',L5,'' LEGWDG = '',L5 &
 & ,'' LEGWWMS = '',L5,'' LEOZOC = '',L5,'' LEQNGT = '',L5 &
 & ,'' LBUDCYCLE = '',L5,'' LMFSCAV = '',L5,'' LNEEONLINE = '',L5 &
 & ,'' LBFASCO2 = '',L5 &
 & ,'' LEO3CH = '',L5,'' LO3CH_OLDVER = '',L5,'' LECO2DIU = '',L5)')&
 & LEDCLD,LEGWDG,LEGWWMS,LEOZOC,LEQNGT,LBUDCYCLE,LMFSCAV,LNEEONLINE,&
 & LBFASCO2,LEO3CH,LO3CH_OLDVER,LECO2DIU
WRITE(UNIT=KULOUT,FMT='('' LERADI = '',L5 &
 & ,'' LESURF = '',L5,'' LEVDIF = '',L5 &
 & ,'' LEOCWA = '',L5,'' LEOCCO = '',L5,'' LEOCSA = '',L5 &
 & ,'' LEOCLA = '',L5,'' LECURR = '',L5,'' RTHRFRTI = '',F7.2 &
 & ,'' RCIMIN = '',F7.2 &
 & )')&
 & LERADI,LESURF,LEVDIF,LEOCWA,LEOCCO,LEOCSA,LEOCLA,LECURR,RTHRFRTI,RCIMIN
WRITE(UNIT=KULOUT,FMT='('' LEPCLD = '',L5,'' LEMETHOX= '',L5 &
 & ,'' LE4ALB = '',L5,'' LEVGEN = '',L5,'' LESSRO = '',L5 &
 & ,'' LELAIV = '',L5,'' LECTESSEL = '',L5 &
 & ,'' LEFLAKE = '',L5,'' LEOCML = '',L5,''LEOBC = '',L5 &
 & ,'' LEOBCICE = '',L5,'' LOCMLTKE = '',L5 &
 & ,'' LESMOSS = '',L5,'' LSPCRM = '',L5  &
 & ,'' LESN09 = '',L5,'' LDUCTDIA = '',L5,'' RLAIINT = '',F7.2 &
 & ,'' LEOCLAKE = '',L5,'' LEOLAKESST= '',L5 &
 & )') &
 & LEPCLD,LEMETHOX,LE4ALB,LEVGEN,LESSRO,LELAIV,LECTESSEL,&
 & LEFLAKE,LEOCML,LEOBC,LEOBCICE,LOCMLTKE,LESMOSS,LSPCRM,&
 & LESN09,LDUCTDIA,RLAIINT,LEOCLAKE,LEOLAKESST

IF (LECMWF .AND. .NOT.LEFLAKE .AND. NCONF /=903) THEN
  WRITE(NULOUT,'("SU0PHY: AT ECMWF LEFLAKE is a MUST")')
  CALL ABOR1('SU0PHY: LEFLAKE MUST BE TRUE')
ENDIF

WRITE(UNIT=KULOUT,FMT='('' LERAIN = '',L5,'' LEMWAVE = '',L5)') &
  & LERAIN,LEMWAVE
WRITE(UNIT=KULOUT,FMT='('' LEGBRAD = '',L5,'' NPRACCL = '',I5,''s'')') LEGBRAD,NPRACCL
WRITE(UNIT=KULOUT,FMT='('' LERAINGG = '',L5)') LERAINGG 

! Do not allow storage of trajectory in TL physics if tracers
! are to be included in linearized physics (temporary)
IF (LETRAJP .AND. LETRAJPT .AND. LTRACLNPH) THEN
  WRITE(UNIT=KULOUT,FMT='('' CAUTION : STORAGE OF TRAJECTORY IN LINEAR. PHYSICS NOT YET '')')
  WRITE(UNIT=KULOUT,FMT='('' IMPLEMENTED FOR TRACERS: LETRAJPT WILL BE RESET TO .FALSE. '')')
ENDIF

IF (LETRAJP) THEN
  WRITE(UNIT=KULOUT,FMT='('' ======================== '')')
  WRITE(UNIT=KULOUT,FMT='('' LINEAR PHYSICS ACTIVATED '')')
  WRITE(UNIT=KULOUT,FMT='('' ======================== '')')
  WRITE(UNIT=KULOUT,FMT='('' LERADI2 = '',L4 &
   & ,'' LERADS2 = '',L4 &
   & )')&
   & LERADI2,LERADS2
  WRITE(UNIT=KULOUT,FMT='('' LERADSW2='',L4 &
   & ,'' LERADLW2= '',L4 &
   & ,'' LERADN2 = '',L4 &
   & ,'' LERADFL2= '',L4 &
   & )')&
   & LERADSW2,LERADLW2,LERADN2,LERADFL2
  WRITE(UNIT=KULOUT,FMT='('' NLWFR   = '',I4 &
   & ,'' NLOOPLW = '',I4 &
   & ,'' LOPTLWPR= '',L4 &
   & ,'' LWLCLHR = '',L4 &
   & )')&
   & NLWFR,NLOOPLW,LOPTLWPR,LWLCLHR
  WRITE(UNIT=KULOUT,FMT='('' LEDCLD2 = '',L4 &
   & ,'' LENCLD2 = '',L4 &
   & ,'' LEVAPLS2= '',L4 &
   & ,'' LREGCL  = '',L4 &
   & ,'' LNCLIN  = '',L4 &
   & )')&
   & LEDCLD2,LENCLD2,LEVAPLS2,LREGCL,LNCLIN
  WRITE(UNIT=KULOUT,FMT='('' LECUMF2 = '',L4 &
   & ,'' LECOND2 = '',L4    &
   & )')&
   & LECUMF2,LECOND2
  WRITE(UNIT=KULOUT,FMT='('' LEVDIF2 = '',L4 &
   & ,'' LEGWDG2 = '',L4 &
   & ,'' LEGWWMS2= '',L4 &
   & ,'' LREGWWMS= '',L4 &
   & ,'' LEQNGT2 = '',L4 &
   & )')&
   & LEVDIF2,LEGWDG2,LEGWWMS2,LREGWWMS,LEQNGT2
  WRITE(UNIT=KULOUT,FMT='('' LESURF2 = '',L4 &
   & ,'' LREGSF  = '',L4 &
   & ,'' LEKPERT = '',L4 &
   & ,'' LEKPERTS = '',L4 &
   & ,'' LENOPERT = '',L4 &
   & )')&
   & LESURF2,LREGSF,LEKPERT,LEKPERTS,LENOPERT
  WRITE(UNIT=KULOUT,FMT='('' ======================== '')')
  WRITE(UNIT=KULOUT,FMT='('' LETRAJPT = '',L4)')LETRAJPT
  WRITE(UNIT=KULOUT,FMT='('' ======================== '')')
  WRITE(UNIT=KULOUT,FMT='('' LTRACLNPH = '',L4)')LTRACLNPH
  WRITE(UNIT=KULOUT,FMT='('' ======================== '')')
ELSE
  WRITE(UNIT=KULOUT,FMT='('' ============================ '')')
  WRITE(UNIT=KULOUT,FMT='('' LINEAR PHYSICS NOT ACTIVATED '')')
  WRITE(UNIT=KULOUT,FMT='('' ============================ '')')
  WRITE(UNIT=KULOUT,FMT='('' LENCLD2 = '',L4)')LENCLD2
  WRITE(UNIT=KULOUT,FMT='('' LEVAPLS2= '',L4)')LEVAPLS2
ENDIF

WRITE(UNIT=KULOUT,FMT='('' LSPHLC = '',L5,'' LVDFLC = '',L5 &
 & ,'' LVDFDS = '',L5,'' LSDRLC = '',L5,'' LSDRDS = '',L5)')&
 & LSPHLC,LVDFLC,LVDFDS,LSDRLC,LSDRDS
WRITE(UNIT=KULOUT,FMT='('' LZMCON = '',L5,'' LKEXP  = '',L5)')&
 & LZMCON,LKEXP
WRITE(UNIT=KULOUT,FMT='('' ALPHA  = '',E16.6)') ALPHA
WRITE(UNIT=KULOUT,FMT='('' AH0    = '',E16.6,''m'')') AH0
WRITE(UNIT=KULOUT,FMT='('' USTARL = '',E16.6,''m s-1'')') USTARL
WRITE(UNIT=KULOUT,FMT='('' USTARS = '',E16.6,''m s-1'')') USTARS
WRITE(UNIT=KULOUT,FMT='('' ALANDZ0= '',E16.6,''m'')') ALANDZ0
WRITE(UNIT=KULOUT,FMT='('' ASEAZ0 = '',E16.6,''m'')') ASEAZ0

IF (LAGPHY) THEN
  WRITE(UNIT=KULOUT,FMT='('' LAGPHY = '',L5,'' THE PHYSICS PAC&
   & KAGE IS CALLED AFTER THE DYNAMICS IN LAGGED MODE'')')LAGPHY
ELSE
  WRITE(UNIT=KULOUT,FMT='('' LAGPHY = '',L5,'' THE PHYSICS PAC&
   & KAGE IS CALLED BEFORE THE DYNAMICS '')')LAGPHY
ENDIF
WRITE(UNIT=KULOUT,FMT=*) 'CGMIXLEN=',TRIM(CGMIXLEN)
WRITE(UNIT=KULOUT,FMT=*) 'CGTURS=',TRIM(CGTURS)
WRITE(UNIT=KULOUT,FMT='('' LPRGML = '',L4)') LPRGML

IF (LGPCMT .AND. .NOT.LNCVPGY) THEN
  WRITE(NULOUT,'("SU0PHY: IF LGPCMT=T, LNCVPGY MUST BE T")')
  CALL ABOR1('SU0PHY: IF LGPCMT=T, LNCVPGY MUST BE T')
ENDIF

WRITE(KULOUT,'('' YOMRCOEF DIMENSIONS '')')
WRITE(UNIT=KULOUT,FMT='('' NG3SR = '',I6,'' NGMTR = '',I6)') NG3SR,NGMTR

WRITE(UNIT=KULOUT,FMT='('' LEDR = '',L2)') LEDR

!     ------------------------------------------------------------------

END ASSOCIATE
IF (LHOOK) CALL DR_HOOK('SU0PHY',1,ZHOOK_HANDLE)
END SUBROUTINE SU0PHY
