SUBROUTINE SUWFP(YDGEOMETRY)
!
! 4/12/2020 : update so that hub height and radius are read from the coordinates
! file
!

USE GEOMETRY_MOD,    ONLY : GEOMETRY
USE PARKIND1,        ONLY : JPIM,JPRB
USE YOMLUN,          ONLY : NULOUT
USE YOMCST,          ONLY : RA, RPI
USE MPL_MODULE,      ONLY : MPL_ALLREDUCE, MPL_MYRANK, MPL_BROADCAST
USE WINDFARM_MOD,    ONLY : WT_LAT_GLOB,WT_LON_GLOB,MWT_TYPE,MGPBLK_WT, &
                            & MPROMA_WT,N_WT, WT_LAT,WT_LON,MWT_TYPE_GLOB, & 
                            & WTT_HUBHEIGHT_GLOB, WTT_RADIUS_GLOB,&
                            & N_WT_GLOB, N_WT_TYPES, MAX_WT_TYPE,WTT_HUBHEIGHT, &
                            & WTT_RADIUS, WTT_CUTIN, WTT_CUTOUT,WTT_CT_CUTIN,&
                            & WTT_CT_CUTOUT, WTT_N_WSPEEDS, TYPE_LOOKUP, &
                            & TBL_WSPEED, TBL_CP, TBL_CT, N_MAX_WSPEEDS


IMPLICIT NONE

! Properties (coordinates, type) of all wind turbines, including 
! turbines located at other MPI tasks
INTEGER(KIND=JPIM), ALLOCATABLE :: IGPBLK_WT_GLOB(:), IPROMA_WT_GLOB(:)
INTEGER(KIND=JPIM) :: IN_WT_GLOB

! Distances each turbine to nearest grid point
REAL(KIND=JPRB), ALLOCATABLE    :: ZDIST_LOC(:), ZDIST_GLOB(:)

INTEGER(KIND=JPIM) :: JROF, JKGLO, JWT, JWTL, IEND, IBL, ICOUNT, MPIID, ITAG, &
                    & IGP, IGX, IGY
REAL(KIND=JPRB) :: ZDIST, ZDX, ZDY, ZLON

! small number of floating point comparison of distances (m)
REAL(KIND=JPRB), PARAMETER :: EPS = 0.001_JPRB

! NT: 
TYPE(GEOMETRY), INTENT(INOUT) :: YDGEOMETRY

! -------------------

#include "suwfp_rt.intfb.h"
#include "suwfp_rc.intfb.h" 
#include "suwfp_sk.intfb.h"

!--------------------

ASSOCIATE(NPROMA=>YDGEOMETRY%YRDIM%NPROMA, NGPBLKS=>YDGEOMETRY%YRDIM%NGPBLKS, & 
    & NDLON=>YDGEOMETRY%YRDIM%NDLON, NDLUXG=>YDGEOMETRY%YRDIM%NDLUXG, & 
    & NDGUXG=>YDGEOMETRY%YRDIM%NDGUXG, YRGSGEOM=>YDGEOMETRY%YRGSGEOM, & 
    & NGPTOT=>YDGEOMETRY%YRGEM%NGPTOT) 
    
    
WRITE(NULOUT,*) 'BvS: Initialising wind turbine code'

!
! -------------------------------
! Read all wind turbine locations (Lat/Lon),
! determine which turbines are on this MPI task,
! and link Lat/Lon to local i,j index
! -------------------------------
!

CALL SUWFP_RC
IN_WT_GLOB = SIZE(WT_LAT_GLOB)
WRITE(NULOUT,*) 'NT: IN_WT_GLOB = ', IN_WT_GLOB

!STOP ! NT: check

! 
! Find grid point nearest to each wind turbine 
!

ALLOCATE( ZDIST_LOC(IN_WT_GLOB), ZDIST_GLOB(IN_WT_GLOB) )
ALLOCATE( IGPBLK_WT_GLOB(IN_WT_GLOB), IPROMA_WT_GLOB(IN_WT_GLOB) )
!STOP ! NT check: DOESN't WORK
ZDIST_LOC(:) = 1E9

DO JWT=1,IN_WT_GLOB
    DO JKGLO=1, NGPTOT, NPROMA
        IEND = MIN(NPROMA, NGPTOT-JKGLO+1)
        IBL  = (JKGLO-1)/NPROMA+1

        DO JROF=1,IEND

            ! HARMONIE longitude = 0->2*PI (0->360 degrees), shift to do -PI->PI (-180->180 degrees)
            IF (YRGSGEOM(IBL)%GELAM(JROF) > RPI) THEN
                ZLON = YRGSGEOM(IBL)%GELAM(JROF)-2_JPRB*RPI
            ELSE
                ZLON = YRGSGEOM(IBL)%GELAM(JROF)
            END IF

            ! Distance grid point to turbine in spherical coordinates
            IGP = YRGSGEOM(IBL)%NUNIQUEGP(JROF) ! Global 2D index of grid point
            IGY = (IGP-1)/NDLON + 1             ! Global Nort-South index 
            IGX = IGP - (IGY-1)*NDLON           ! Global East-West index

            ! Exclude the extension zone, the internal lat/lon coordinates 
            ! are a bit wonky there, possibly because of the bi-periodization
            IF (IGX <= NDLUXG .AND. IGY <= NDGUXG) THEN
                ZDX   = RA * COS(WT_LAT_GLOB(JWT)) * (WT_LON_GLOB(JWT) - ZLON)
                ZDY   = RA * (WT_LAT_GLOB(JWT) - YRGSGEOM(IBL)%GELAT(JROF))
                ZDIST = SQRT(ZDX**2_JPIM + ZDY**2_JPIM)
            ELSE
                ! Grid point extension zone
                ZDIST = 1E12_JPRB
            END IF

            IF (ZDIST < ZDIST_LOC(JWT)) THEN
                ZDIST_LOC(JWT) = ZDIST
                IGPBLK_WT_GLOB(JWT) = IBL
                IPROMA_WT_GLOB(JWT) = JROF
            END IF

        END DO
    END DO
END DO

! 
! Reduce the minimum distances across all MPI tasks. 
! if ZDIST_LOC == ZDIST_GLOB, the turbine is on the current MPI task
!

ZDIST_GLOB(:) = ZDIST_LOC(:)
CALL MPL_ALLREDUCE(ZDIST_GLOB, 'MIN')
N_WT = COUNT(ABS(ZDIST_GLOB - ZDIST_LOC) < EPS)
!
! Copy data from the global arrays (all turbines) to the local
! arrays (turbines on current MPI task)
!

ALLOCATE( WT_LAT(N_WT), WT_LON(N_WT), MWT_TYPE(N_WT), MGPBLK_WT(N_WT), &
        & MPROMA_WT(N_WT), WTT_HUBHEIGHT(N_WT), WTT_RADIUS(N_WT) )

JWTL = 1
DO JWT=1, IN_WT_GLOB
    IF (ABS(ZDIST_GLOB(JWT) - ZDIST_LOC(JWT)) < EPS) THEN
        WT_LAT(JWTL)        = WT_LAT_GLOB(JWT)
        WT_LON(JWTL)        = WT_LON_GLOB(JWT)
        MWT_TYPE(JWTL)      = MWT_TYPE_GLOB(JWT)
        WTT_RADIUS(JWTL)    = WTT_RADIUS_GLOB(JWT)
        WTT_HUBHEIGHT(JWTL) = WTT_HUBHEIGHT_GLOB(JWT)
        MGPBLK_WT(JWTL)     = IGPBLK_WT_GLOB(JWT)
        MPROMA_WT(JWTL)     = IPROMA_WT_GLOB(JWT)
        JWTL = JWTL + 1
    END IF
END DO

N_WT_TYPES = 0
MAX_WT_TYPE = 0
DO JWT=1, IN_WT_GLOB
    IF (ANY(MWT_TYPE_GLOB == JWT)) THEN
        N_WT_TYPES = N_WT_TYPES + 1
    END IF
    MAX_WT_TYPE = MAX(MAX_WT_TYPE, MWT_TYPE_GLOB(JWT))
END DO

WRITE(NULOUT,*) 'Found ', N_WT_TYPES, ' different turbine types'

DO JWT=1, IN_WT_GLOB
    WRITE(NULOUT,*) 'WINDFARM Turbine #', JWT, &
    & ': Lat, lon = ', WT_LAT_GLOB(JWT) * 180._JPRB / RPI , WT_LON_GLOB(JWT) * 180._JPRB / RPI,&
    & ', i ,j = (', IGPBLK_WT_GLOB(JWT), ',', IPROMA_WT_GLOB(JWT), '); Type = ', MWT_TYPE_GLOB(JWT)
END DO

!
! Create lookup table, linking input wind turbine type to index in the data tables. 
!

ALLOCATE( TYPE_LOOKUP(MAX_WT_TYPE) )
TYPE_LOOKUP(:) = -1

ICOUNT = 1
DO JWT=1, IN_WT_GLOB
    IF (TYPE_LOOKUP(MWT_TYPE_GLOB(JWT)) == -1) THEN
        TYPE_LOOKUP(MWT_TYPE_GLOB(JWT)) = ICOUNT
        WRITE(NULOUT,*) 'Index ', ICOUNT,  ' in "TYPE_LOOKUP" points to type ', MWT_TYPE_GLOB(JWT)
        ICOUNT = ICOUNT+1
    END IF
END DO
!
! Read the turbine characteristics from file
!

ALLOCATE( WTT_CUTIN(N_WT_TYPES), WTT_CUTOUT(N_WT_TYPES), &
    & WTT_CT_CUTIN(N_WT_TYPES), WTT_CT_CUTOUT(N_WT_TYPES), &
    & WTT_N_WSPEEDS(N_WT_TYPES) )

ALLOCATE( TBL_WSPEED(N_MAX_WSPEEDS, N_WT_TYPES), &
    & TBL_CP(N_MAX_WSPEEDS, N_WT_TYPES), &
    & TBL_CT(N_MAX_WSPEEDS, N_WT_TYPES) )

DO JWT=1, MAX_WT_TYPE
    CALL SUWFP_RT(JWT)
END DO

END ASSOCIATE
!
! Cleanup 
! 
DEALLOCATE( WT_LAT_GLOB, WT_LON_GLOB, MWT_TYPE_GLOB, IGPBLK_WT_GLOB, IPROMA_WT_GLOB )
DEALLOCATE( ZDIST_LOC, ZDIST_GLOB )

WRITE(NULOUT,*) 'BvS: initialising wind turbine code - DONE!'

END SUBROUTINE SUWFP
