SUBROUTINE SUWFP_RT(KWTT)
!
! Read the wind turbine characteristics 
! wind_turbine_xxx.tab file for xxx=KWTT
!
USE PARKIND1,     ONLY : JPIM,JPRB
USE YOMLUN,       ONLY : NULOUT
USE WINDFARM_MOD, ONLY : TYPE_LOOKUP, TBL_WSPEED,TBL_CP, & 
                    & TBL_CT, WTT_CT_CUTIN, &
                    & WTT_CT_CUTOUT,WTT_N_WSPEEDS,WTT_CUTIN,WTT_CUTOUT
IMPLICIT NONE

INTEGER(KIND=JPIM), INTENT(IN) :: KWTT   ! wind turbine type number

INTEGER(KIND=JPIM) :: IFILE_UNIT = 666
INTEGER(KIND=JPIM) :: I_WT, I_WS, IERR
LOGICAL            :: LFILE_EXISTS
CHARACTER(20)      :: CFILENAME = 'wind_turbine_xxx.tab'
REAL(KIND=JPRB)    :: WSPEED, CP, CT, DUMMY

#include "suwfp_sk.intfb.h"

! Index in lookup table
I_WT = TYPE_LOOKUP(KWTT)

IF (I_WT /= -1) THEN

    ! Default everything to -1 as the input data tables are variable in 
    ! length, and smaller than the actual arrays
    TBL_WSPEED(:, I_WT) = -1
    TBL_CP(:, I_WT)     = -1
    TBL_CT(:, I_WT)     = -1

    ! Check whether input table exists: 
    WRITE(CFILENAME(14:16), '(I0.3)') KWTT
    INQUIRE(FILE=CFILENAME, EXIST=LFILE_EXISTS)

    IF (LFILE_EXISTS) THEN
        WRITE(NULOUT,*) 'Processing ', CFILENAME
        OPEN (IFILE_UNIT, FILE=CFILENAME)

        ! Skip all comments, and read turbine dimensions
        CALL SUWFP_SK(IFILE_UNIT)

        READ(IFILE_UNIT, *, IOSTAT=IERR) DUMMY, DUMMY, WTT_CT_CUTIN(I_WT), WTT_CT_CUTOUT(I_WT)
        !WRITE(NULOUT, *) 'Radius = ', WTT_RADIUS(I_WT), ' - hub-height = ', WTT_HUBHEIGHT(I_WT)
        WRITE(NULOUT, *) 'cT < cutin = ', WTT_CT_CUTIN(I_WT), ' - cT > cutout = ', WTT_CT_CUTOUT(I_WT)

        ! skip all comments, and read power thrust coefficients
        CALL SUWFP_SK(IFILE_UNIT)

        I_WS = 1
        IERR = 0
        DO WHILE (IERR == 0)
            READ(IFILE_UNIT, *, IOSTAT=IERR) WSPEED, CP, CT

            IF (IERR == 0) THEN
                TBL_WSPEED(I_WS, I_WT) = WSPEED
                TBL_CP    (I_WS, I_WT) = CP
                TBL_CT    (I_WS, I_WT) = CT
                I_WS = I_WS + 1
            END IF
        END DO

        ! Save the number of input wind speeds, and cutin and cutout wind speeds
        WTT_N_WSPEEDS(I_WT) = I_WS-1
        WTT_CUTIN (I_WT)    = TBL_WSPEED(1, I_WT)
        WTT_CUTOUT(I_WT)    = TBL_WSPEED(I_WS-1, I_WT)

        WRITE(NULOUT,*) 'U_cut-in = ', WTT_CUTIN(I_WT), ' - U_cut-out = ', WTT_CUTOUT(I_WT)

        CLOSE(IFILE_UNIT)
    ELSE
        WRITE(NULOUT,*) 'File ', CFILENAME, ' missing'
        CALL ABOR1('Routine READ_TURBINE_TABLE failed')
    END IF

END IF

END SUBROUTINE SUWFP_RT
